#!/usr/bin/env python3

# Simple message relay. 
# Sends all incoming messages to all connected clients, including sender.
# Input and output are line-based.
# NOTE: This does not provide security features. Consider using a firewall
# to block intended clients.

import asyncio

# keep track of all writer streams
clients = []

async def serve_client(reader, writer):
    clients.append(writer)
    print("CLIENT ADD")

    while True:
        try:
            line = await reader.readline()
            # send to all clients. Blocking messages from the sender 
            # to itself is its own responsibility
            dsts = [c for c in clients]

            if not line:
                break;

            print("IN ({} B -> {} clients): {}".format(len(line), len(dsts), line))

            for client in dsts:
                client.write(line)
                await client.drain()
        except Exception as e:
            print("ERROR: {} - dropping client".format(e))
            break

    clients.remove(writer)
    print("CLIENT REMOVE")


async def main():
    server = await asyncio.start_server(serve_client, port=8888, reuse_port=True)

    addrs = ', '.join(str(sock.getsockname()) for sock in server.sockets)
    print(f'Serving on {addrs}')

    async with server:
        await server.serve_forever()


asyncio.run(main())
