<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<!-- 
		Venue Race RAC file for a single competition (only one group per file)
		Concept2 documentation can be found here https://www.concept2.com/files/miscellaneous/venue-racing/VenueRacing_VenueHelp.htm
		but the doc sucks as it notes (in itself) "NOTE: DO NOT RELY ON THIS, I CANNOT VERIFY IT's ACCURACY".
		Very helpful, folks.
	-->
	<xsl:include href="../../../../../Reporting/XSL/CSV/includes/standard.xsl"/>

	<xsl:template name="header">
		<!-- file magic -->
		<xsl:text>RACE</xsl:text>
		<xsl:call-template name="linebreak"/>
		<xsl:text>108</xsl:text>
		<xsl:call-template name="linebreak"/>
		<!-- race info -->
		<!-- team type (sigh, log2 would be nice) -->
		<xsl:choose>
			<xsl:when test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 1">0</xsl:when>
			<xsl:when test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 2">1</xsl:when>
			<xsl:when test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 4">2</xsl:when>
			<xsl:when test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 8">3</xsl:when>
			<xsl:otherwise>invalid race type (only 1, 2, 4, and 8 athletes allowed)</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linebreak"/>
		<!-- 4: race name -->
		<xsl:value-of select="substring(normalize-space(concat(/data/RaceInfo/RaceInfo/Offer_RaceNumber, ' - ', /data/CompInfo/CompInfo/Comp_RoundCode, /data/CompInfo/CompInfo/Comp_Label, ' - ', /data/RaceInfo/RaceInfo/Offer_ShortLabel , ' ', /data/RaceInfo/RaceInfo/Offer_Comment)), 1, 16)"/>
		<xsl:call-template name="linebreak"/>
		<!-- 5: distance -->
		<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_Distance"/>
		<xsl:call-template name="linebreak"/>
		<!-- 6: race type:  0:Distance Race, 1:Time Race, 3:Biathlon Distance 3-Lap, 5: Biathlon Distance 5-Lap -->
		<xsl:text>0</xsl:text>
		<xsl:call-template name="linebreak"/>
		<!-- 7: view mode (legacy value) -->
		<xsl:text>0</xsl:text>
		<xsl:call-template name="linebreak"/>
		<!-- 8: record stroke data (maybe it is useful) -->
		<xsl:text>1</xsl:text>
		<xsl:call-template name="linebreak"/>
		<!-- 9: splits every 500 meters (required for import?!) -->
		<xsl:text>500</xsl:text>
		<xsl:call-template name="linebreak"/>
		<!-- 10: split time (two minutes), may this is ignored -->
		<xsl:text>120</xsl:text>
		<xsl:call-template name="linebreak"/>
		<!-- 11: number of competitors, i.e. occupied lanes -->
		<xsl:value-of select="count(/data/Lanes/Lane)"/>
		<xsl:call-template name="linebreak"/>
	</xsl:template>

	<xsl:template match="/data">
		<xsl:apply-templates select="/data/Lanes/Lane"/>
		<!-- trailing zero -->
		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 1">0</xsl:if>
		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers &gt; 1">
			<xsl:value-of select="count(/data/Lanes/Lane) * /data/RaceInfo/RaceInfo/BoatClass_NumRowers"/>
			<xsl:call-template name="linebreak"/>
			<xsl:apply-templates select="/data/Lanes/Lane" mode="individuals"/>
		</xsl:if>
		<xsl:call-template name="linebreak"/>
	</xsl:template>

	<xsl:template match="Lane">
		<xsl:variable name="entry" select="/data/Entries/Entrie[Entry_ID = current()/CE_Entry_ID_FK]"/>
		<xsl:variable name="short_label">
			<xsl:apply-templates select="$entry" mode="GetLabel">
				<xsl:with-param name="short" select="true()"/>
				<xsl:with-param name="round" select="/data/CompInfo/CompInfo/Comp_Round"/>
			</xsl:apply-templates>
		</xsl:variable>

		<!-- participant name -->
		<xsl:call-template name="odf_latinize">
			<xsl:with-param name="s">
				<xsl:choose>
					<xsl:when test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 1">
						<xsl:apply-templates select="$entry" mode="crewMemberName">
							<xsl:with-param name="is_individual" select="false()"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:otherwise><xsl:value-of select="substring($short_label, 1, 16)"/></xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="linebreak"/>
		<!-- bib -->
		<xsl:value-of select="$entry/Entry_Bib"/>
		<xsl:call-template name="linebreak"/>
		<!-- class (reuse comp id, allows easy merge of multiple RAC files) -->
		<xsl:text>group_</xsl:text>
		<xsl:value-of select="/data/CompInfo/CompInfo/Comp_ID"/>
		<xsl:call-template name="linebreak"/>
		<!-- country code (might not be a valid value for VR) -->
		<xsl:apply-templates select="/data/Entries/Entrie[Entry_ID = current()/CE_Entry_ID_FK]" mode="GetNOCCode">
			<xsl:with-param name="round" select="/data/CompInfo/CompInfo/Comp_Round"/>
		</xsl:apply-templates>
		<xsl:call-template name="linebreak"/>
		<!-- DOB (dummy value) -->
		<xsl:text>01012020</xsl:text>
		<xsl:call-template name="linebreak"/>
	</xsl:template>

	<xsl:template match="Lane" mode="individuals">
		<!-- I'm too lazy to do it the generic way, so hard code the name queries -->
		<xsl:variable name="entry" select="/data/Entries/Entrie[Entry_ID = current()/CE_Entry_ID_FK]"/>
		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 2">
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'1'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'2'"/></xsl:apply-templates>
		</xsl:if>
		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 4">
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'1'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'2'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'3'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'4'"/></xsl:apply-templates>
		</xsl:if>
		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 8">
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'1'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'2'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'3'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'4'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'5'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'6'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'7'"/></xsl:apply-templates>
			<xsl:apply-templates select="$entry" mode="crewMemberName"><xsl:with-param name="position" select="'8'"/></xsl:apply-templates>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Entrie" mode="crewMemberName">
		<xsl:param name="position" select="1"/>
		<xsl:param name="is_individual" select="true()"/>

		<xsl:variable name="seat" select="/data/Crews/Crew[Entry_ID_FK = current()/Entry_ID and Pos = $position]"/>
		<xsl:variable name="ath" select="/data/Athlets/Athlet[ID = $seat/Athlete_ID_FK]"/>

		<xsl:variable name="ath_name">
			<xsl:value-of select="substring($ath/FirstName, 1, 1)"/>
			<xsl:text>. </xsl:text>
			<xsl:apply-templates select="$ath/LastName"/>
		</xsl:variable>

		<xsl:if test="$ath">
			<xsl:call-template name="odf_latinize">
				<xsl:with-param name="s">
					<xsl:value-of select="substring($ath_name, 1, 16)"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>

		<xsl:if test="not($ath)">
			<xsl:text>N.N.</xsl:text>
		</xsl:if>

		<xsl:if test="$is_individual">
			<xsl:call-template name="linebreak"/>
			<!-- invidual bib -->
			<xsl:value-of select="Entry_Bib * 100 + $position"/>
			<xsl:call-template name="linebreak"/>
			<!-- class (as in the race) -->
			<xsl:text>group_</xsl:text>
			<xsl:value-of select="/data/CompInfo/CompInfo/Comp_ID"/>
			<xsl:call-template name="linebreak"/>
		</xsl:if>
	</xsl:template>

	<!-- http://odf.olympictech.org/2020-Tokyo/general/HTML/Names/Names_Policy.htm Section 7 Character Set for Participant Names -->
	<xsl:template name="odf_latinize">
		<xsl:param name="s"/>
		<xsl:value-of select="translate($s, 'ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØÙÚÛÜÝŸÞẞßàáâãäåæçèéêëìíîïðñòóôõöøùúûüýþÿ', 'AAAAAAACEEEEIIIIDNOOOOOOUUUUYYTSsaaaaaaaceeeeiiiidnoooooouuuuyty')"/>
	</xsl:template>

</xsl:stylesheet>
