<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:output method="text" encoding="utf-8"/>

	<xsl:param name="opt_show_athletes_club" select="boolean(number(/data/ReportOptions/ReportOption[Name='show_athletes_club']/Value) != 0)"/>

	<!-- 
		ErgRace Race file (JSON, not beautiful)
	-->

	<xsl:include href="../../../../../Reporting/XSL/INC/rowing_tools.xsl"/>

	<xsl:template match="/">
		<xsl:text>{ "race_definition": </xsl:text>
		<xsl:text>{</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "event_name": "</xsl:text>
		<xsl:value-of select="/data/Event/Event/Title"/>
		<xsl:text>",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "name_short": "Re. </xsl:text>
		<xsl:value-of select="normalize-space(concat(/data/RaceInfo/RaceInfo/Offer_RaceNumber, ', ', /data/CompInfo/CompInfo/Comp_RoundCode, /data/CompInfo/CompInfo/Comp_Label, ', ', /data/RaceInfo/RaceInfo/Offer_ShortLabel, ' ', /data/RaceInfo/RaceInfo/Offer_Comment))"/>
		<xsl:text>",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "name_long": "Rennen </xsl:text>
		<xsl:value-of select="normalize-space(concat(/data/RaceInfo/RaceInfo/Offer_RaceNumber, ', ', /data/CompInfo/CompInfo/Comp_RoundCode, /data/CompInfo/CompInfo/Comp_Label, ', ', /data/RaceInfo/RaceInfo/Offer_LongLabel, ' ', /data/RaceInfo/RaceInfo/Offer_Comment))"/>
		<xsl:text>",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 1"><xsl:text>  "race_type": "individual",</xsl:text></xsl:if>
		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers &gt; 1">
			<xsl:text>  "team_size": </xsl:text>
			<xsl:value-of select="/data/RaceInfo/RaceInfo/BoatClass_NumRowers"/>
			<xsl:text>,</xsl:text>
			<xsl:call-template name="linebreak"/>
			<xsl:text>  "race_type": "relay",</xsl:text>
			<xsl:call-template name="linebreak"/>
			<xsl:text>  "sound_horn_at_splits": true,</xsl:text>
			<xsl:call-template name="linebreak"/>
			<xsl:text>  "display_prompt_at_splits": true,</xsl:text>
		</xsl:if>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "duration_type": "meters",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "duration": </xsl:text>
		<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_Distance"/>
		<xsl:text>,</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "split_type": "even",</xsl:text>
		<xsl:call-template name="linebreak"/>
		<xsl:text>  "split_value": 500,</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "race_id": "</xsl:text>
		<xsl:value-of select="/data/CompInfo/CompInfo/Comp_ID"/>
		<xsl:text>",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "classes": [ { "name": "</xsl:text>
		<xsl:value-of select="normalize-space(concat(/data/RaceInfo/RaceInfo/Offer_ShortLabel, ' ', /data/RaceInfo/RaceInfo/Offer_Comment))"/>
		<!--
			/* use comp id to unique class to facilitate manual merging of comps */
			<xsl:value-of select="concat('class_', /data/CompInfo/CompInfo/Comp_ID)"/>
		-->
		<xsl:text>"} ],</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>  "boats": [</xsl:text>
		<xsl:call-template name="linebreak"/>
		<xsl:apply-templates select="/data/Lanes/Lane"/>
		<xsl:text>  ]</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>}}</xsl:text>
	</xsl:template>

	<xsl:template match="Lane">
		<xsl:variable name="short_label">
			<xsl:apply-templates select="/data/Entries/Entrie[Entry_ID = current()/CE_Entry_ID_FK]" mode="GetLabel">
				<xsl:with-param name="short" select="true()"/>
				<xsl:with-param name="round" select="/data/CompInfo/CompInfo/Comp_Round"/>
			</xsl:apply-templates>
		</xsl:variable>

		<xsl:text>  {</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>    "class_name": "</xsl:text>
		<xsl:value-of select="normalize-space(concat(/data/RaceInfo/RaceInfo/Offer_ShortLabel, ' ', /data/RaceInfo/RaceInfo/Offer_Comment))"/>
		<xsl:text>",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>    "affiliation": "</xsl:text>
		<xsl:apply-templates select="/data/Entries/Entrie[Entry_ID = current()/CE_Entry_ID_FK]" mode="GetNOCCode">
			<xsl:with-param name="round" select="/data/CompInfo/CompInfo/Comp_Round"/>
		</xsl:apply-templates>
		<xsl:text>",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>    "id": "</xsl:text>
		<xsl:value-of select="concat('entry_', current()/CE_Entry_ID_FK)"/>
		<xsl:text>",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>    "lane_number": </xsl:text>
		<xsl:value-of select="CE_Lane"/>
		<xsl:text>,</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>    "machine_type": "row",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>    "name": "</xsl:text>
		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers &gt; 1">
			<xsl:value-of select="normalize-space(translate($short_label, '&quot;', ''))"/>
		</xsl:if>
		<xsl:if test="/data/RaceInfo/RaceInfo/BoatClass_NumRowers = 1">
			<xsl:apply-templates select="/data/Crews/Crew[Entry_ID_FK = current()/CE_Entry_ID_FK and Pos = 1 and RoundFrom &lt;= /data/CompInfo/CompInfo/Comp_Round and RoundTo &gt;= /data/CompInfo/CompInfo/Comp_Round]" mode="single">
				<xsl:sort select="Pos"/>
			</xsl:apply-templates>
			<xsl:if test="$opt_show_athletes_club">
				<xsl:text> (</xsl:text><xsl:apply-templates select="/data/Crews/Crew[Entry_ID_FK = current()/CE_Entry_ID_FK and Pos = 1 and RoundFrom &lt;= /data/CompInfo/CompInfo/Comp_Round and RoundTo &gt;= /data/CompInfo/CompInfo/Comp_Round]" mode="club_abbr"/><xsl:text>)</xsl:text>
			</xsl:if>
		</xsl:if>
		<xsl:text>",</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>    "participants": [</xsl:text>
		<xsl:apply-templates select="/data/Crews/Crew[Entry_ID_FK = current()/CE_Entry_ID_FK and RoundFrom &lt;= /data/CompInfo/CompInfo/Comp_Round and RoundTo &gt;= /data/CompInfo/CompInfo/Comp_Round]">
			<xsl:sort select="Pos"/>
		</xsl:apply-templates>
		<xsl:text>    ]</xsl:text>

		<xsl:call-template name="linebreak"/>
		<xsl:text>  }</xsl:text>
		<xsl:if test="position() != last()">
			<xsl:text>,</xsl:text>
		</xsl:if>
		<xsl:call-template name="linebreak"/>
	</xsl:template>

	<xsl:template match="Crew">
		<xsl:variable name="ath" select="/data/Athlets/Athlet[ID = current()/Athlete_ID_FK]"/>

		<xsl:text>{ "name": "</xsl:text>
		<xsl:value-of select="concat($ath/LastName, ', ', $ath/FirstName)"/>
		<xsl:text>" }</xsl:text>
		<xsl:if test="position() != last()">
			<xsl:text>,</xsl:text>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Crew" mode="single">
		<xsl:variable name="ath" select="/data/Athlets/Athlet[ID = current()/Athlete_ID_FK]"/>
		<xsl:value-of select="concat($ath/LastName, ', ', $ath/FirstName)"/>
	</xsl:template>

	<xsl:template match="Crew" mode="club_abbr">
		<xsl:value-of select="/data/Athlets/Athlet[ID = current()/Athlete_ID_FK]/Club_UltraAbbr"/>
	</xsl:template>

	<xsl:template name="linebreak">
		<xsl:text>&#13;</xsl:text>
	</xsl:template>

</xsl:stylesheet>
