<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:include href="../../../../../Reporting/XSL/FOP/includes/standard.xsl"/>
	
	<xsl:param name="optCupID" select="/data/ReportOptions/ReportOption[Name='CupID']/Value"/>
	<xsl:param name="optDetailedTable" select="/data/ReportOptions/ReportOption[Name='detailed_table']/Value"/>

	<xsl:param name="maxRaceCols" select="number('22')"/>

	<xsl:template match="/data" mode="pageformat" priority="9">
		<xsl:choose>
			<xsl:when test="$optDetailedTable = 0 or count(/data/CupRaces/CupRace) &lt; 8">
				<xsl:text>A4-portrait</xsl:text>
			</xsl:when>
			<xsl:when test="count(/data/CupRaces/CupRace) &lt; 12">
				<xsl:text>A4-landscape</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>A3-landscape</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="/" mode="extra-page-masters" priority="10">
		<xsl:param name="footer_height"/>
		<!-- A3 landscape -->
		<fo:simple-page-master master-name="A3-landscape" page-height="297mm" page-width="420mm" 
			margin-top="1.2cm" margin-bottom="0cm" margin-left="1.4cm" margin-right="1.3cm">
			
			<fo:region-body region-name="page-region-body" margin-top="3cm">
				<xsl:attribute name="margin-bottom">
					<xsl:value-of select="$footer_height"/>
				</xsl:attribute>					
			</fo:region-body>
			<fo:region-before extent="3cm" region-name="page-header"/>
			<fo:region-after region-name="page-footer">
				<xsl:attribute name="extent">
					<xsl:value-of select="$footer_height"/>
				</xsl:attribute>
			</fo:region-after>
		</fo:simple-page-master>	
	</xsl:template>

	<xsl:template name="body">
		<fo:block font-weight="bold" font-size="16pt" text-align="center" margin="4pt">
			<xsl:value-of select="/data/Cup/Cup/Caption"/>
		</fo:block>
		<fo:block font-weight="bold" font-size="10pt" text-align="center" margin-bottom="8pt">
			<xsl:text>nach </xsl:text>
			<xsl:value-of select="/data/Cup/Cup/NumFinishedComps"/>
			<xsl:text> von </xsl:text>
			<xsl:value-of select="/data/Cup/Cup/NumComps"/>
			<xsl:text> Entscheidungen</xsl:text>
		</fo:block>

		<xsl:if test="count(/data/CupRaces/CupRace) &gt; $maxRaceCols and $optDetailedTable = 1">
			<fo:block border="thin solid rect" font-weight="bold" padding="1em" margin-bottom="1em">
				<xsl:text>Warnung: Von den </xsl:text>
				<xsl:value-of select="count(/data/CupRaces/CupRace)"/>
				<xsl:text> </xsl:text>
				<xsl:text> Rennen der Pokalwertung sind in dieser Darstellung nur </xsl:text>
				<xsl:value-of select="$maxRaceCols"/>
				<xsl:text> ausgegeben.</xsl:text>
			</fo:block>
		</xsl:if>

		<fo:table width="100%" table-layout="fixed">
		
			<!-- Tabellenlayout:
				Spalte 1: Rang
				Spalte 2: Verein (dynamisch)
				Spalte 3: Punkte
				Spalte 4: Spacer
				Spalte 5-...: Punkte für Rennen
			 -->
			<fo:table-column column-number="1" column-width="1.5cm"/>
<!--			<fo:table-column column-number="2" column-width="80%"/>-->
			<fo:table-column column-number="3" column-width="5em"/>
			<xsl:if test="$optDetailedTable = 1">
				<fo:table-column column-number="4" column-width=".25em"/>
				<xsl:for-each select="/data/CupRaces/CupRace[position() &lt;= $maxRaceCols]">
					<fo:table-column column-width="1.5cm">
						<xsl:attribute name="column-number">
							<xsl:value-of select="4 + position()"/>
						</xsl:attribute>
					</fo:table-column>
				</xsl:for-each>
			</xsl:if>

			<fo:table-header font-weight="bold">
				<xsl:if test="$optDetailedTable = 1">
					<fo:table-row>
						<fo:table-cell number-columns-spanned="4"><fo:block/></fo:table-cell>
						<xsl:for-each select="/data/CupRaces/CupRace[position() &lt;= $maxRaceCols]">
							<fo:table-cell border="medium solid black" padding=".25em">
								<fo:block-container reference-orientation="90" width="5.5em" display-align="center">
									<fo:block text-align="left">
										<xsl:value-of select="ShortLabel"/>
									</fo:block>
								</fo:block-container>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</xsl:if>
				
				<fo:table-row>
					<fo:table-cell border="medium solid black" padding="0.25em .5em"><fo:block>Rang</fo:block></fo:table-cell>
					<fo:table-cell border="medium solid black" padding="0.25em .5em"><fo:block>Verein</fo:block></fo:table-cell>
					<fo:table-cell border="medium solid black" padding="0.25em .5em"><fo:block text-align="right">Punkte</fo:block></fo:table-cell>
					<xsl:if test="$optDetailedTable = 1">
						<fo:table-cell><fo:block/></fo:table-cell>
						<xsl:for-each select="/data/CupRaces/CupRace[position() &lt;= $maxRaceCols]">
							<fo:table-cell border="medium solid black" padding=".25em">
								<fo:block text-align="center">
									<xsl:value-of select="RaceNumber"/>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</xsl:if>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding=".125em">
						<fo:block></fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			
			<fo:table-body font-size="11pt">
				<xsl:apply-templates select="/data/CupStandings/CupStanding"/>
				<xsl:if test="count(/data/CupStandings/CupStanding) = 0">
					<fo:table-row>
						<fo:table-cell number-columns-spanned="3">
							<fo:block>keine Daten vorhanden. Nur offizielle Läufe werden gewertet.</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:if>
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template match="CupStanding">
		<xsl:variable name="cid" select="Club_ID"/>
		<fo:table-row>
			<fo:table-cell border="medium solid black" padding="0.25em .5em">
				<fo:block text-align="right">
					<xsl:if test="count(../CupStanding[CupRank = current()/CupRank]) &gt; 1">
						<xsl:text>=</xsl:text>
					</xsl:if>
					<xsl:value-of select="CupRank"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell border="medium solid black" padding="0.25em .5em">
				<fo:block-container overflow="hidden">
					<fo:block wrap-option="no-wrap">
						<!-- Nation_Code ? -->
						<xsl:value-of select="Club_Abbr"/>
					</fo:block>
				</fo:block-container>
			</fo:table-cell>
			<fo:table-cell border="medium solid black" padding="0.25em .5em">
				<fo:block text-align="right"><xsl:value-of select="format-number(Points, '0.###')"/></fo:block>
			</fo:table-cell>
			<!-- detailed point matrix -->
			<xsl:if test="$optDetailedTable = 1">
				<fo:table-cell><fo:block/></fo:table-cell>
				<xsl:for-each select="/data/CupRaces/CupRace[position() &lt;= $maxRaceCols]">
					<fo:table-cell border="medium solid black" padding=".25em .5em">
						<fo:block text-align="right">
							<xsl:value-of select="format-number(sum(/data/CupPoints/CupPoint[Race_ID = current()/ID and Club_ID = $cid]/Points), '0.###')"/>
						</fo:block>
					</fo:table-cell>
				</xsl:for-each>
			</xsl:if>
		</fo:table-row>
	</xsl:template>
	
</xsl:stylesheet>
