<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:include href="../../../../../Reporting/XSL/CSV/includes/standard.xsl"/>

    <xsl:key name="clubs" match="/data/Rankings/Ranking" use="Club_ID"/>
    <xsl:variable name="max_rank" select="/data/Rankings/Ranking[position() = last()]/Rank"/>

    <xsl:template name="header">
        <xsl:if test="$show_noc = 1">
            <xsl:text>Nation;</xsl:text>
        </xsl:if>
        <xsl:text>Verein;</xsl:text>
        <xsl:call-template name="add_column_defs">
            <xsl:with-param name="limit" select="$max_rank"/>
        </xsl:call-template>
        <xsl:call-template name="linebreak"/>
    </xsl:template>

    <xsl:template match="data">
        <xsl:for-each select="/data/Rankings/Ranking[generate-id() = generate-id(key('clubs', Club_ID)[1])]">
            <!-- hard coded limit of 9 lanes -->
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 1]/Cnt" data-type="number" order="descending"/>
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 2]/Cnt" data-type="number" order="descending"/>
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 3]/Cnt" data-type="number" order="descending"/>
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 4]/Cnt" data-type="number" order="descending"/>
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 5]/Cnt" data-type="number" order="descending"/>
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 6]/Cnt" data-type="number" order="descending"/>
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 7]/Cnt" data-type="number" order="descending"/>
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 8]/Cnt" data-type="number" order="descending"/>
            <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 9]/Cnt" data-type="number" order="descending"/>
            <xsl:apply-templates select="current()">
                <xsl:with-param name="max_rank" select="$max_rank"/>
            </xsl:apply-templates>
        </xsl:for-each>
    </xsl:template>

    <xsl:template match="Ranking">
        <xsl:if test="$show_noc = 1">
            <xsl:value-of select="/data/Clubs/Club[ID = current()/Club_ID]/Nation_IOC_Code"/>
            <xsl:text>;</xsl:text>
        </xsl:if>
        <xsl:value-of select="/data/Clubs/Club[ID = current()/Club_ID]/Abbr"/>
        <xsl:text>;</xsl:text>
        <xsl:call-template name="rankings"/>
        <xsl:call-template name="linebreak"/>
    </xsl:template>

    <xsl:template name="add_column_defs">
        <xsl:param name="i" select="number('1')"/>

	<xsl:text>Platz </xsl:text>
        <xsl:value-of select="$i"/>
        <xsl:text>;</xsl:text>

        <xsl:if test="$i &lt; $max_rank">
            <xsl:call-template name="add_column_defs">
                <xsl:with-param name="i" select="$i + 1"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="rankings">
        <xsl:param name="i" select="number('1')"/>

        <xsl:value-of select="/data/Rankings/Ranking[current()/Club_ID = Club_ID and Rank = $i]/Cnt"/>
        <xsl:text>;</xsl:text>

        <xsl:if test="$i &lt; $max_rank">
            <xsl:call-template name="rankings">
                <xsl:with-param name="i" select="$i + 1"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>
