<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:include href="../../../../../Reporting/XSL/FOP/includes/standard.xsl"/>

    <xsl:key name="clubs" match="/data/Rankings/Ranking" use="Club_ID"/>

    <xsl:template name="body">
        <xsl:variable name="max_rank" select="/data/Rankings/Ranking[position() = last()]/Rank"/>
        <fo:table width="100%" table-layout="auto" font-size="11pt">

            <!-- Tabellenlayout:
                Spalte 1: Verein
                Spalte ...: Platzierungen/Anzahl
             -->
            <fo:table-column column-number="1" column-width="auto"/>
            <xsl:call-template name="add_column_defs">
                <xsl:with-param name="limit" select="$max_rank"/>
            </xsl:call-template>

            <fo:table-header margin-bottom="1em" font-weight="bold">
                <fo:table-row border="medium solid black">
<!--
                    <fo:table-cell padding-end="6pt"><fo:block text-align="right">Rang</fo:block></fo:table-cell>
-->
                    <fo:table-cell padding="0.25em .5em" number-rows-spanned="2" border-right="medium solid black">
                            <fo:block>Verein</fo:block>
                    </fo:table-cell>
                    <fo:table-cell border-bottom="medium solid black">
                            <xsl:attribute name="number-columns-spanned">
                                    <xsl:value-of select="$max_rank"/>
                            </xsl:attribute>
                            <fo:block vertical-align="middle" text-align="center">Platzierung</fo:block>
                    </fo:table-cell>
                </fo:table-row>
                <fo:table-row border="medium solid black">
                    <xsl:call-template name="add_column_headers">
                        <xsl:with-param name="limit" select="$max_rank"/>
                    </xsl:call-template>
                </fo:table-row>
                <fo:table-row>
                    <fo:table-cell padding=".125em">
                        <fo:block></fo:block>
                    </fo:table-cell>
                </fo:table-row>
            </fo:table-header>

            <fo:table-body font-size="11">
                <xsl:for-each select="/data/Rankings/Ranking[generate-id() = generate-id(key('clubs', Club_ID)[1])]">
                    <!-- hard coded limit of 9 lanes -->
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 1]/Cnt" data-type="number" order="descending"/>
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 2]/Cnt" data-type="number" order="descending"/>
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 3]/Cnt" data-type="number" order="descending"/>
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 4]/Cnt" data-type="number" order="descending"/>
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 5]/Cnt" data-type="number" order="descending"/>
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 6]/Cnt" data-type="number" order="descending"/>
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 7]/Cnt" data-type="number" order="descending"/>
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 8]/Cnt" data-type="number" order="descending"/>
                    <xsl:sort select="/data/Rankings/Ranking[Club_ID = current()/Club_ID and Rank = 9]/Cnt" data-type="number" order="descending"/>
                    <xsl:apply-templates select="current()">
                        <xsl:with-param name="max_rank" select="$max_rank"/>
                    </xsl:apply-templates>
                </xsl:for-each>
            </fo:table-body>
        </fo:table>
    </xsl:template>

    <xsl:template match="Ranking">
        <xsl:param name="max_rank" select="number(6)"/>
        <fo:table-row>
            <fo:table-cell padding="0.25em .5em" border="medium solid black">
                <fo:block>
                    <xsl:if test="$show_noc = 1">
                        <xsl:value-of select="/data/Clubs/Club[ID = current()/Club_ID]/Nation_IOC_Code"/>
                    </xsl:if>
                    <xsl:value-of select="/data/Clubs/Club[ID = current()/Club_ID]/Abbr"/>
                </fo:block>
            </fo:table-cell>
            <xsl:call-template name="rankings">
                <xsl:with-param name="max_rank" select="$max_rank"/>
            </xsl:call-template>
        </fo:table-row>
    </xsl:template>

    <xsl:template name="add_column_defs">
        <xsl:param name="i" select="number(1)"/>
        <xsl:param name="limit" select="number(6)"/>

        <fo:table-column column-width="1.1cm">
            <xsl:attribute name="column-number">
                    <xsl:value-of select="$i + 1"/>
            </xsl:attribute>
        </fo:table-column>

        <xsl:if test="$i &lt; $limit">
            <xsl:call-template name="add_column_defs">
                <xsl:with-param name="limit" select="$limit"/>
                <xsl:with-param name="i" select="$i + 1"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="add_column_headers">
        <xsl:param name="i" select="number(1)"/>
        <xsl:param name="limit" select="number(6)"/>

        <fo:table-cell border="medium solid black">
            <fo:block text-align="center" vertical-align="bottom">
                <!--<xsl:text>Rang </xsl:text>-->
                <xsl:value-of select="$i"/>
            </fo:block>
        </fo:table-cell>

        <xsl:if test="$i &lt; $limit">
            <xsl:call-template name="add_column_headers">
                <xsl:with-param name="limit" select="$limit"/>
                <xsl:with-param name="i" select="$i + 1"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="rankings">
        <xsl:param name="i" select="number(1)"/>
        <xsl:param name="max_rank" select="number(6)"/>

        <xsl:variable name="cnt" select="/data/Rankings/Ranking[current()/Club_ID = Club_ID and Rank = $i]/Cnt"/>

        <fo:table-cell padding="0.25em .5em" border="medium solid black">
            <fo:block text-align="right">
                <xsl:if test="count(/data/Rankings/Ranking[Rank = $i and Cnt = $cnt]) &gt; 1">
                    <xsl:text>=</xsl:text>
                </xsl:if>
                <xsl:value-of select="$cnt"/>
            </fo:block>
        </fo:table-cell>

        <xsl:if test="$i &lt; $max_rank">
            <xsl:call-template name="rankings">
                <xsl:with-param name="max_rank" select="$max_rank"/>
                <xsl:with-param name="i" select="$i + 1"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template match="/data" mode="legend_body" priority="100">
        <xsl:text>
            Gewertet werden die Platzierungen der Boote in A-Finalläufen und Abteilungen.
            Es zählen die Vereine der Ruderer in den jeweiligen Endläufen.
            Steuerleute werden nicht gewertet.
        </xsl:text>
        <fo:block>
            <fo:inline padding="1em">=</fo:inline>
            <fo:inline>mehrere Vereine mit gleicher Anzahl</fo:inline>
        </fo:block>
    </xsl:template>

</xsl:stylesheet>
