﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
<!--- Zielbericht für Schnelldruck -->

	<xsl:include href="../../../../../Reporting/XSL/FOP/includes/standard.xsl"/>

	<xsl:template name="body">
		<xsl:variable name="finals" select="/data/Comps/Comp[Round = 64 and RoundCode = 'F' and HeatNumber = 1 and State = 4]"/>

		<xsl:if test="count($finals) &gt; 0">
			<fo:table width="100%" table-layout="fixed">
				<fo:table-column column-number="1" column-width="3.5cm"/>
				<fo:table-column column-number="2" column-width="2cm"/>
				<fo:table-column column-number="3" column-width="1.5cm"/>
				<fo:table-column column-number="4" column-width="proportional-column-width(1)"/>
				<fo:table-column column-number="5" column-width="proportional-column-width(1)"/>

				<fo:table-header font-size="9pt">
					<fo:table-row font-weight="bold">
						<fo:table-cell border="medium solid black" padding=".5em"><fo:block><xsl:text>Rennen</xsl:text></fo:block></fo:table-cell>
						<fo:table-cell border="medium solid black" padding=".5em"><fo:block><xsl:text>Datum</xsl:text></fo:block></fo:table-cell>
						<fo:table-cell border="medium solid black" padding=".5em"><fo:block><xsl:text>Medaille</xsl:text></fo:block></fo:table-cell>
						<fo:table-cell border="medium solid black" padding=".5em"><fo:block><xsl:text>Name</xsl:text></fo:block></fo:table-cell>
						<fo:table-cell border="medium solid black" padding=".5em"><fo:block><xsl:text>Verein</xsl:text></fo:block></fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell padding="0.25em"><fo:block></fo:block></fo:table-cell>
					</fo:table-row>
				</fo:table-header>

				<fo:table-body font-size="10pt">
					<xsl:apply-templates select="/data/Comps/Comp"/>
				</fo:table-body>
			</fo:table>
		</xsl:if>

		<xsl:if test="count($finals) = 0 or count(/data/Medalists/Medalist) = 0">
			<xsl:call-template name="error">
				<xsl:with-param name="message"><xsl:text>No finals or medalists found; nothing to be done.</xsl:text></xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Comp">
		<xsl:variable name="comp" select="current()"/>
		<xsl:for-each select="/data/Medalists/Medalist[CE_Comp_ID_FK = current()/ID]">
			<fo:table-row>
				<xsl:if test="(position() = 1)">
					<!-- comp header -->
					<fo:table-cell border="medium solid black" padding=".25em">
						<xsl:attribute name="number-rows-spanned">
							<xsl:value-of select="count(../Medalist[CE_Comp_ID_FK = current()/CE_Comp_ID_FK])"/>
						</xsl:attribute>
						<fo:block>
							<xsl:value-of select="/data/Races/Race[Offer_ID = $comp/Race_ID_FK]/Offer_RaceNumber"/>
							<xsl:text> - </xsl:text>
							<xsl:value-of select="/data/Races/Race[Offer_ID = $comp/Race_ID_FK]/Offer_LongLabel"/>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell border="medium solid black" padding=".25em">
						<xsl:attribute name="number-rows-spanned">
							<xsl:value-of select="count(../Medalist[CE_Comp_ID_FK = current()/CE_Comp_ID_FK])"/>
						</xsl:attribute>
						<fo:block>
							<xsl:value-of select="substring($comp/DateTime, 1, 10)"/>
						</fo:block>
					</fo:table-cell>
				</xsl:if>
				<xsl:if test="(position() = 1) or (Result_Rank != preceding-sibling::node()[1]/Result_Rank)">
					<!-- medal cell -->
					<fo:table-cell border="medium solid black" padding=".25em">
						<xsl:attribute name="number-rows-spanned">
							<xsl:value-of select="count(../Medalist[CE_Comp_ID_FK = current()/CE_Comp_ID_FK and Result_Rank = current()/Result_Rank])"/>
						</xsl:attribute>
						<fo:block>
							<xsl:choose>
								<xsl:when test="Result_Rank = 1"><xsl:text>Gold</xsl:text></xsl:when>
								<xsl:when test="Result_Rank = 2"><xsl:text>Silber</xsl:text></xsl:when>
								<xsl:when test="Result_Rank = 3"><xsl:text>Bronze</xsl:text></xsl:when>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
				</xsl:if>
				<!-- medalists themselves -->
				<fo:table-cell padding-left=".25em" border-right="medium solid black">
					<xsl:if test="(position() = 1) or (Result_Rank != preceding-sibling::node()[1]/Result_Rank)">
						<xsl:attribute name="border-top">
							<xsl:text>medium solid black</xsl:text>
						</xsl:attribute>
					</xsl:if>
					<xsl:if test="(position() = last()) or (Result_Rank != following-sibling::node()[1]/Result_Rank)">
						<xsl:attribute name="border-bottom">
							<xsl:text>medium solid black</xsl:text>
						</xsl:attribute>
					</xsl:if>
					<fo:block padding-top="0.25em">
						<xsl:text>(</xsl:text>
						<xsl:if test="Crew_IsCox = 1"><xsl:value-of select="$CoxAbbr"/></xsl:if>
						<xsl:if test="Crew_IsCox = 0"><xsl:value-of select="Crew_Pos"/></xsl:if>
						<xsl:text>) </xsl:text>
						<xsl:value-of select="Athlet_FirstName"/>
						<xsl:text> </xsl:text>
						<fo:inline text-transform="uppercase"><xsl:value-of select="Athlet_LastName"/></fo:inline>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="Athlet_YOB"/>
						<xsl:text>)</xsl:text>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell padding=".25em" border-right="medium solid black">
					<xsl:if test="(position() = 1) or (Result_Rank != preceding-sibling::node()[1]/Result_Rank)">
						<xsl:attribute name="border-top">
							<xsl:text>medium solid black</xsl:text>
						</xsl:attribute>
					</xsl:if>
					<xsl:if test="(position() = last()) or (Result_Rank != following-sibling::node()[1]/Result_Rank)">
						<xsl:attribute name="border-bottom">
							<xsl:text>medium solid black</xsl:text>
						</xsl:attribute>
					</xsl:if>
					<fo:block>
						<xsl:value-of select="Club_Abbr"/>
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
