﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <!-- don't use the standard include here (dont want header, footer, and other stuff here -->
    <!-- use import here to allow overriding templates in this stylesheet -->
    <xsl:import href="../../../../../Reporting/XSL/inc/rowing_tools.xsl"/>

    <xsl:output method="xml" encoding="utf-8" version="1.0" omit-xml-declaration="no" indent="yes"/>

    <xsl:template match="/">
        <fo:root font-family="Arial">
            <!-- Page Size Definitions -->
            <fo:layout-master-set>
                <!-- A4 portrait -->
                <fo:simple-page-master master-name="A4-portrait" page-height="297mm" page-width="210mm" margin="0mm">
                    <fo:region-body region-name="page-region-body"/>
                </fo:simple-page-master>
            </fo:layout-master-set>

            <!-- Sequenz für die Urkunden -->
            <fo:page-sequence master-reference="A4-portrait" id="seq-primary">
                <fo:flow flow-name="page-region-body">
                    <!-- you may filter out results with certain (per-heat) rank[s] here -->
                    <xsl:apply-templates select="/data/Results/Result"/>
                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>

    <!-- eine Urkunde -->
    <xsl:template match="Result">
        <!-- umschließender Block, ggf. für Rahmen, Anpassung der Abstände abändern (oder in page definiton)  -->
        <fo:block text-align="center" page-break-after="always">
            <!-- Rang -->
            <fo:block padding-top="10cm" font-weight="bold" font-size="20pt">
                <xsl:apply-templates select="current()" mode="rank"/>
                <xsl:text>. Platz</xsl:text>
            </fo:block>

            <!-- Rennbezeichnung -->
            <xsl:if test="string-length(/data/RaceInfo/RaceInfo/Offer_Prize) &gt; 0">
                <fo:block>
                    <xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_Prize"/>
                </fo:block>
            </xsl:if>
            
            <fo:block>
                <xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_LongLabel"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_Comment"/>
            </fo:block>

            <fo:block>
                <xsl:call-template name="GetGroupString">
                    <xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode"/>
                    <xsl:with-param name="value" select="/data/Comps/Comp[ID=current()/Comp_ID]/GroupValue"/>
                </xsl:call-template>
            </fo:block>

            <!-- Bootsbezeichnung -->
            <fo:block>
                <xsl:apply-templates select="/data/Entries/Entrie[Entry_ID = current()/Entry_ID]" mode="GetLabel"/>
            </fo:block>

            <!-- Mannschaft -->
            <fo:block>
                <xsl:apply-templates select="/data/Entries/Entrie[Entry_ID = current()/Entry_ID]" mode="GetCrewString">
                    <xsl:with-param name="short" select="true()"/>
                </xsl:apply-templates>
            </fo:block>
        </fo:block>
    </xsl:template>


    <xsl:template match="Result" mode="rank">
        <xsl:choose>
            <!-- use per-heat rank for heat-based events (same rank may occur multple times, for each heat) -->
            <xsl:when test="/data/Comps/Comp[id=current()/Comp_ID]/Code = 'A'">
                <xsl:value-of select="Rank"/>
            </xsl:when>
            <!-- use rank of overall final ranking for multi-round events -->
            <xsl:otherwise>
                <xsl:value-of select="GroupRank"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- override default short crew name template to make diploma look nice -->
    <xsl:template name="CrewNameShort">
        <xsl:param name="id"/>
        <xsl:value-of select="/data/Athlets/Athlet[ID = $id]/FirstName"/>
        <!-- use non-breaking space (U+00A0) to keep first and last name on same line (may have side effects), might be broken by multi-word names -->
        <xsl:text>&#160;</xsl:text>
        <xsl:value-of select="/data/Athlets/Athlet[ID = $id]/LastName"/>
    </xsl:template>

</xsl:stylesheet>
