<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:include href="./includes/standard.xsl"/>

	<xsl:param name="scratches" select="/data/ReportOptions/ReportOption[Name='scratches']/Value"/>

	<xsl:template name="header">
		<xsl:text>RNr;</xsl:text>
		<xsl:text>RBezKurz;</xsl:text>
		<xsl:text>RBezLang;</xsl:text>
		<xsl:text>Gruppe;</xsl:text>
		<xsl:text>StNr;</xsl:text>
		<xsl:text>Boot;</xsl:text>
		<xsl:text>BootNr;</xsl:text>
		<xsl:text>Bemerkung;</xsl:text>
		<xsl:text>Ab/Nach;</xsl:text>
		<xsl:text>Mannschaft;</xsl:text>
		<xsl:call-template name="linebreak"/>
	</xsl:template>

	<xsl:template match="data">
		<xsl:for-each select="/data/Races/Race">
			<xsl:variable name="rid" select="Offer_ID"/>
			<xsl:if test="Offer_Driven = 1 or $scratches = 1">
				<xsl:apply-templates select="/data/Entries/Entrie[Entry_Race_ID_FK = $rid]">
					<xsl:sort data-type="number" select="Entry_GroupValue"/>
					<xsl:sort data-type="number" select="Entry_FullBib"/>
				</xsl:apply-templates>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Entrie">
		<xsl:variable name="rid" select="Entry_Race_ID_FK"/>
		<xsl:variable name="race" select="/data/Races/Race[Offer_ID = $rid]"/>
		
		<xsl:choose>
			<xsl:when test="position() = 1">
				<xsl:value-of select="$race/Offer_RaceNumber"></xsl:value-of>
				<xsl:text>;</xsl:text>
				<xsl:value-of select="$race/Offer_ShortLabel"></xsl:value-of>
				<xsl:if test="string-length($race/Offer_Comment) &gt; 0">
					<xsl:value-of select="Offer_Comment"/> 
				</xsl:if>
				<xsl:text>;</xsl:text>
				<xsl:value-of select="$race/Offer_LongLabel"></xsl:value-of>
				<xsl:if test="string-length($race/Offer_Comment) &gt; 0">
					<xsl:value-of select="Offer_Comment"/> 
				</xsl:if>
				<xsl:text>;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!-- don't repeat race data for subsequent race entries -->
				<xsl:text>;;;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:if test="$race/Offer_GroupMode &gt; 0" >
			<xsl:call-template name="GetAbbrGroupString">
				<xsl:with-param name="mode" select="$race/Offer_GroupMode"/>
				<xsl:with-param name="value" select="Entry_GroupValue"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="Entry_FullBib"/>
		<xsl:text>;</xsl:text>
		<xsl:call-template name="GetEntryLabel">
			<xsl:with-param name="entry" select="current()"/>
			<xsl:with-param name="round" select="number(0)"/>
			<xsl:with-param name="short" select="true()"/>
			<xsl:with-param name="with-extra" select="false()"/>
		</xsl:call-template>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="Entry_BoatNumber"/>
		<xsl:text>;</xsl:text>
		<xsl:if test="Entry_CancelValue &gt; 0">
			<xsl:text>Abgemeldet</xsl:text>
		</xsl:if>
		<xsl:if test="Entry_IsLate &gt; 0">
			<xsl:text>Nachgemeldet</xsl:text>
		</xsl:if>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="Entry_Remark"/>
		<xsl:text>;</xsl:text>
		<xsl:apply-templates select="." mode="GetCrewString">
			<xsl:with-param name="round" select="number(0)"/>
		</xsl:apply-templates>
		<xsl:call-template name="linebreak"/>
	</xsl:template>

</xsl:stylesheet>
