<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:include href="./includes/standard.xsl"/>

    <xsl:decimal-format name="european" decimal-separator=',' grouping-separator='.' />  
      
	<xsl:template name="header">
		<xsl:text>meldender Verein;</xsl:text>
		<xsl:text>zahlt für;</xsl:text>
		<xsl:text>Meldungen;</xsl:text>
		<xsl:text>Rabatt;</xsl:text>
		<xsl:text>Beitrag;</xsl:text>
		<xsl:text>Nachmeldungen;</xsl:text>
		<xsl:text>Beitrag;</xsl:text>
		<xsl:text>Summe;</xsl:text>
		<xsl:call-template name="linebreak"/>
	</xsl:template>
	
	<xsl:template match="data">					
		<xsl:apply-templates select="/data/Clubs/Club">
			<xsl:sort select="City"/>
			<xsl:sort select="Abbr"/>
			<xsl:sort select="Team"/>
		</xsl:apply-templates>
	</xsl:template>
	
    <xsl:template match="Club">
        <xsl:variable name="e_ll" select="Entry_LongLabel"/>
        <xsl:variable name="cid" select="ID"/>
        
        <xsl:variable name="regularEntries" select="/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid and Entry_IsLate != 1]"/>
        <xsl:variable name="csum">
            <xsl:call-template name="club_fee_sum">
                <xsl:with-param name="entries" select="$regularEntries"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:variable name="lateEntries" select="/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid and Entry_IsLate = 1]"/>
        <xsl:variable name="clatesum">
            <xsl:call-template name="club_fee_sum">
                <xsl:with-param name="entries" select="$lateEntries"/>
            </xsl:call-template>
        </xsl:variable>        

		<!-- fields -->
		<xsl:value-of select="City"/>
		<xsl:text>, </xsl:text>
		<xsl:value-of select="Abbr"/>
		<xsl:text>;</xsl:text>

		<xsl:if test="Entry_ShortLabel != Abbr">
			<xsl:value-of select="Entry_ShortLabel"/>
		</xsl:if>
		<xsl:if test="Entry_ShortLabel = Abbr">
			<xsl:text>[sich selbst]</xsl:text>
		</xsl:if>
		<xsl:text>;</xsl:text>
			
		<xsl:value-of select="count(/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid])"/>
		<xsl:text>;</xsl:text>

		<xsl:value-of select="format-number(./Discount, '#0,#', 'european')"/>
		<xsl:text>;</xsl:text>
			
		<xsl:value-of select="format-number($csum * (100 - ./Discount) div 100, '#0,00', 'european')"/>
		<xsl:text>;</xsl:text>
					
		<xsl:value-of select="count($lateEntries)"/>
		<xsl:text>;</xsl:text>
			
		<xsl:value-of select="format-number(2 * $clatesum, '#0,00', 'european')"/>
		<xsl:text>;</xsl:text>

		<xsl:value-of select="format-number($csum * (100 - ./Discount) div 100 + 2 * $clatesum , '#0,00', 'european')"/>
		<xsl:call-template name="linebreak"/>
    </xsl:template>
	
</xsl:stylesheet>
