<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:include href="./includes/standard.xsl"/>
	<xsl:param name="only_invalid_aths" select="/data/ReportOptions/ReportOption[Name='only_invalid_aths']/Value"/>
	<xsl:param name="with_times" select="/data/ReportOptions/ReportOption[Name='with_times']/Value"/>

	<xsl:template name="header">
		<xsl:text>ClubID;ClubNOC;ClubCity;ClubName;ClubShort;ClubAbbr;AthName;AthFirstName;AthYOB;AthID;AthState;AthRaces</xsl:text>
		<xsl:if test="$with_times = 1">
			<xsl:text>;IsCox;RaceDay;RaceTime</xsl:text>
		</xsl:if>
		<xsl:call-template name="linebreak"/>
	</xsl:template>


	<xsl:template match="/data">
		<xsl:apply-templates select="/data/Clubs/Club"/>
	</xsl:template>


	<xsl:template match="Club">
		<xsl:apply-templates select="/data/Athlets/Athlet[(Crew_Club_ID_FK=current()/ID and State = 0 and $only_invalid_aths = 1) or (Crew_Club_ID_FK=current()/ID and $only_invalid_aths = 0)]">
			<xsl:with-param name="club" select="current()"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="Athlet">
		<xsl:param name="club"/>
		<xsl:value-of select="$club/ExternID"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="$club/Nation_IOC_Code"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="$club/City"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="$club/Name"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="$club/Abbr"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="$club/UltraAbbr"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="LastName"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="FirstName"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="YOB"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="ExternID_A"/>
		<xsl:text>;</xsl:text>
		<xsl:choose>
			<xsl:when test="State = 0">N</xsl:when>
			<xsl:when test="State = 1">J</xsl:when>
			<xsl:when test="State = 2">E</xsl:when>
			<xsl:otherwise><xsl:text>?</xsl:text></xsl:otherwise>
		</xsl:choose>
		<xsl:text>;</xsl:text>
		<xsl:if test="$with_times = 1">
			<xsl:for-each select="/data/AthRaces/AthRace[AID = current()/ID]">
				<xsl:variable name="first">
					<xsl:value-of select="number(position() = 1)"/>
				</xsl:variable>
				<xsl:variable name="rnr">
					<xsl:value-of select="Nr"/>
				</xsl:variable>
				<xsl:variable name="cox">
					<xsl:value-of select="IsCox"/>
				</xsl:variable>
				<xsl:if test="/data/Comps/Comp[Race_ID_FK = current()/ID]">
					<xsl:for-each select="/data/Comps/Comp[Race_ID_FK = current()/ID]">
						<xsl:if test="$first = 0">
							<xsl:call-template name="linebreak"/>
							<xsl:text>;;;;;;;;;;;</xsl:text>
						</xsl:if>
						<xsl:value-of select="$rnr"/>
						<xsl:text>;</xsl:text>
						<xsl:value-of select="$cox"/>
						<xsl:text>;</xsl:text>
						<xsl:value-of select="substring-before(RoundTime, ' ')"/>
						<xsl:text>;</xsl:text>
						<xsl:value-of select="substring-after(RoundTime, ' ')"/>
					</xsl:for-each>
				</xsl:if>

				<xsl:if test="count(/data/Comps/Comp[Race_ID_FK = current()/ID]) = 0">
					<xsl:if test="$first = 0">
						<xsl:call-template name="linebreak"/>
						<xsl:text>;;;;;;;;;;;</xsl:text>
					</xsl:if>
					<xsl:value-of select="Nr"/>
					<xsl:text>;</xsl:text>
					<xsl:value-of select="IsCox"/>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="$with_times = 0">
			<xsl:for-each select="/data/AthRaces/AthRace[AID=current()/ID]">
				<xsl:value-of select="Nr"/>
				<xsl:if test="IsCox = 1">
					<xsl:text> (St.)</xsl:text>
				</xsl:if>
				<xsl:if test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
		<xsl:call-template name="linebreak"/>
	</xsl:template>


</xsl:stylesheet>
