<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:include href="./includes/standard.xsl"/>

	<xsl:decimal-format name="european" decimal-separator=',' grouping-separator='.' />

	<xsl:template name="header">
		<xsl:if test="$show_noc">
			<xsl:text>Nation;</xsl:text>
		</xsl:if>
		<xsl:text>VereinsNr;Ort;Name;RennNr;RennBez;StNr;BootsBez;Betrag;Bemerkung</xsl:text>
		<xsl:call-template name="linebreak"/>
	</xsl:template>


	<xsl:template match="/data">
		<xsl:apply-templates select="/data/Entries/Entrie"/>
	</xsl:template>


	<xsl:template match="Entrie">
		<xsl:variable name="stat" select="/data/Stats/Stat[Race_ID = current()/Entry_Race_ID_FK and Entry_GroupValue = current()/Entry_GroupValue]"/>
		<xsl:variable name="discount" select="/data/Clubs/Club[ID = current()/Entry_OwnerClub_ID_FK]/Discount"/>

		<xsl:if test="$show_noc">
			<xsl:apply-templates select="." mode="GetNOCCode"/>
			<xsl:text>;</xsl:text>
		</xsl:if>

		<xsl:value-of select="/data/Clubs/Club[ID = current()/Entry_OwnerClub_ID_FK]/ExternID"/>
		<xsl:text>;</xsl:text>

		<xsl:value-of select="/data/Clubs/Club[ID = current()/Entry_OwnerClub_ID_FK]/City"/>
		<xsl:text>;</xsl:text>

		<xsl:value-of select="/data/Clubs/Club[ID = current()/Entry_OwnerClub_ID_FK]/Abbr"/>
		<xsl:text>;</xsl:text>
		
		<xsl:value-of select="/data/Races/Race[current()/Entry_Race_ID_FK = Offer_ID]/Offer_RaceNumber"/>
		<xsl:text>;</xsl:text>

		<xsl:value-of select="normalize-space(concat(/data/Races/Race[current()/Entry_Race_ID_FK = Offer_ID]/Offer_ShortLabel,  /data/Races/Race[current()/Entry_Race_ID_FK = Offer_ID]/Offer_Comment))"/>
		<xsl:text>;</xsl:text>

		<xsl:value-of select="Entry_Bib"/>
		<xsl:text>;</xsl:text>

		<xsl:value-of select="Label_Short"/>
		<xsl:text>;</xsl:text>
		<!--
		<xsl:value-of select="normalize-space(substring-before(Entry_Note, '('))"/>
		<xsl:text>;</xsl:text>

		<xsl:value-of select="normalize-space(substring-before(substring-after(Entry_Note, '('), ')'))"/>
		<xsl:text>;</xsl:text>
		-->
		<xsl:choose> 
			<xsl:when test="$stat/GroupDriven = 1">
				<xsl:if test="Entry_IsLate = 0">
					<xsl:value-of select="format-number($stat/Fee * (100.0 - $discount) div 100.0, '#0,00', 'european')"/>
				</xsl:if>
				<xsl:if test="Entry_IsLate = 1">
					<xsl:value-of select="format-number($stat/Fee * 2.0, '#0,00', 'european')"/>
					<xsl:text>;</xsl:text>
					<xsl:text>Nachmeldung</xsl:text>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>0</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:text>;</xsl:text>

		<xsl:call-template name="linebreak"/>
	</xsl:template>


</xsl:stylesheet>
