<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:include href="./includes/standard.xsl"/>
	
	<xsl:template match="data">
		<xsl:variable name="results" select="/data/Results/Result[SplitNr = 64]"/>
		<xsl:apply-templates select="$results">
			<xsl:sort select="SortValue" data-type="number"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template name="header">
		<!-- race meta data before actual header -->
		<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_RaceNumber"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_ShortLabel"/>
		<xsl:text>;</xsl:text>
		<xsl:apply-templates select="/data/CompInfo/CompInfo" mode="GetLongCompCaption"/>
		<xsl:if test="/data/RaceInfo/RaceInfo/Offer_GroupMode &gt; 0">
			<xsl:text> </xsl:text>
			<xsl:call-template name="GetShortGroupString">
				<xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode"/>
				<xsl:with-param name="value" select="/data/CompInfo/CompInfo/Comp_GroupValue"/>			
			</xsl:call-template>
		</xsl:if>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="concat(/data/CompInfo/CompInfo/Comp_RoundCode, /data/CompInfo/CompInfo/Comp_Label)"/>
		<xsl:text>;</xsl:text>
		<xsl:value-of select="Comp_Label"/>
		<xsl:if test="/data/RaceInfo/RaceInfo/Offer_GroupMode &gt; 0">
			<xsl:text> </xsl:text>
			<xsl:call-template name="GetShortGroupString">
				<xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode"/>
				<xsl:with-param name="value" select="/data/CompInfo/CompInfo/Comp_GroupValue"/>			
			</xsl:call-template>
		</xsl:if>
		<xsl:text>;</xsl:text>
		<xsl:call-template name="linebreak"/>

		<xsl:text>Rang;</xsl:text>
		<xsl:text>Bahn;</xsl:text>
		<xsl:text>StNr;</xsl:text>
		<xsl:text>Boot;</xsl:text>
		<xsl:text>Mannschaft;</xsl:text>
		<xsl:text>Ergebnis</xsl:text>
		<xsl:call-template name="linebreak"/>
	</xsl:template>

	<xsl:template match="Result">
		<xsl:variable name="ceid" select="CE_ID_FK" />
		<xsl:variable name="eid" select="/data/Lanes/Lane[CE_ID = $ceid]/CE_Entry_ID_FK"/>
		<xsl:variable name="entry" select="/data/Entries/Entrie[Entry_ID = $eid]" />
		<xsl:variable name="splits" select="/data/Results/Result[CE_ID_FK = $ceid]" />
		<xsl:variable name="finish" select="." />
		<xsl:variable name="round">
			<xsl:if test="/data/CompInfo">
				<xsl:value-of select="/data/CompInfo/CompInfo/Comp_Round"/>
			</xsl:if>
			<!-- for round results -->
			<xsl:if test="/data/RoundInfo">
				<xsl:value-of select="/data/RoundInfo/RoundInfo/Number"/>
			</xsl:if>
		</xsl:variable>
		
		<xsl:if test="count($splits) != 0">
			<xsl:if test="number($finish/Rank) &gt; 0">
				<xsl:value-of select="$finish/Rank" />
			</xsl:if>
			<xsl:text>;</xsl:text>
			
			<xsl:value-of select="$eid/../CE_Lane" />
			<xsl:text>;</xsl:text>
			
			<xsl:value-of select="$entry/Entry_FullBib" />
			<xsl:text>;</xsl:text>
			
			<xsl:apply-templates select="$entry" mode="GetLabel">
				<xsl:with-param name="round" select="$round"/>
			</xsl:apply-templates>
			<xsl:text>;</xsl:text>

			<xsl:apply-templates select="$entry" mode="GetCrewString">
				<xsl:with-param name="round" select="$round"/>
			</xsl:apply-templates>
			<xsl:text>;</xsl:text>
			
			<xsl:apply-templates select="DisplayValue" mode="friendly"/>
			<xsl:call-template name="linebreak"/>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
