<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt">

	<xsl:param name="convert_prefixed_bibs" select="boolean(/data/ReportOptions/ReportOption[Name='convert_prefixed_bibs']/Value = 1)"/>

	<xsl:template name="header">
		<xsl:text>EventCode;Date;Time;Lane/order;BibNo;LastName;FirstName;Nation;Dist;Race;Round;Sponsor</xsl:text>
		<xsl:call-template name="linebreak"/>
	</xsl:template>
	
	<xsl:template match="RaceInfo" mode="StartlistRaceHeader">
		<xsl:text>N</xsl:text>
		<xsl:value-of select="format-number(/data/CompInfo/CompInfo/Comp_Number, '0000')"></xsl:value-of>
		<xsl:text>;</xsl:text>
		
		<xsl:value-of select="substring-before(/data/CompInfo/CompInfo/Comp_DateTime, ' ')"/>
		<xsl:text>;</xsl:text>
		
		<xsl:value-of select="substring(substring-after(/data/CompInfo/CompInfo/Comp_DateTime, ' '), 1, 5)"/>
		<xsl:text>;</xsl:text>
		
		<xsl:text>;;;;;</xsl:text>
		
		<xsl:value-of select="/data/CompInfo/CompInfo/Comp_Distance"/>
		<xsl:text>;</xsl:text>
		
		<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_RaceNumber"/>
		<xsl:text> - </xsl:text>
		<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_ShortLabel"/>
		<xsl:text>;</xsl:text>
		
		<xsl:apply-templates select="/data/CompInfo/CompInfo" mode="GetLongCompCaption"/>
		<xsl:if test="/data/RaceInfo/RaceInfo/Offer_GroupMode &gt; 0">
			<xsl:text> </xsl:text>
			<xsl:call-template name="GetShortGroupString">
				<xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode"/>
				<xsl:with-param name="value" select="/data/CompInfo/CompInfo/Comp_GroupValue"/>			
			</xsl:call-template>
		</xsl:if>
		<xsl:text>;</xsl:text>
		
		<!-- Sponsor -->
		<xsl:text></xsl:text>
		<xsl:call-template name="linebreak"/>
	</xsl:template>
	

	<xsl:template match="Comp" mode="StartlistCompHeader">
		<xsl:variable name="rid">
			<xsl:if test="Comp_Race_ID_FK">
				<xsl:value-of select="Comp_Race_ID_FK"/>
			</xsl:if>
			<xsl:if test="Race_ID_FK">
				<xsl:value-of select="Race_ID_FK"/>
			</xsl:if>
		</xsl:variable>
		
		<xsl:text>N</xsl:text>
		<xsl:value-of select="format-number(Number, '0000')"></xsl:value-of>
		<xsl:text>;</xsl:text>
		
		<xsl:value-of select="substring-before(DateTime, ' ')"/>
		<xsl:text>;</xsl:text>
		
		<xsl:value-of select="substring(substring-after(DateTime, ' '), 1, 5)"/>
		<xsl:text>;</xsl:text>

		<xsl:text>;;;;;</xsl:text>
		
		<xsl:choose>
			<xsl:when test="count(/data/RaceInfo/RaceInfo[Offer_ID = $rid]) != 0">
				<xsl:copy-of select="Distance"/>
				<xsl:text>;</xsl:text>
				<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_RaceNumber"/>
				<xsl:text> - </xsl:text>
				<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_ShortLabel"/>
				<xsl:text>;</xsl:text>
				<xsl:apply-templates select="." mode="GetLongCompCaption"/>
				<xsl:if test="/data/RaceInfo/RaceInfo/Offer_GroupMode &gt; 0">
					<xsl:text> </xsl:text>
					<xsl:call-template name="GetShortGroupString">
						<xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode"/>
						<xsl:with-param name="value" select="GroupValue"/>			
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="count(/data/Races/Race[Offer_ID = $rid]) != 0">
				<xsl:copy-of select="Distance"/>
				<xsl:text>;</xsl:text>
				<xsl:value-of select="/data/Races/Race[Offer_ID = $rid][1]/Offer_RaceNumber"/>
				<xsl:text> - </xsl:text>
				<xsl:value-of select="/data/Races/Race[Offer_ID = $rid][1]/Offer_ShortLabel"/>
				<xsl:text>;</xsl:text>
				<xsl:apply-templates select="." mode="GetLongCompCaption"/>
				<xsl:if test="/data/Races/Race[Offer_ID = $rid][1]/Offer_GroupMode &gt; 0">
					<xsl:text> </xsl:text>
					<xsl:call-template name="GetShortGroupString">
						<xsl:with-param name="mode" select="/data/Races/Race[Offer_ID = $rid][1]/Offer_GroupMode"/>
						<xsl:with-param name="value" select="GroupValue"/>			
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
		<xsl:text>;</xsl:text>
		
		<!-- Sponsor -->
		<xsl:text></xsl:text>
		<xsl:call-template name="linebreak"/>
	</xsl:template>


	<xsl:template match="Lane" mode="StartListItem">
		<xsl:param name="round" select="number(64)"/>

		<xsl:variable name="eid" select="CE_Entry_ID_FK"/>
		<xsl:variable name="entry" select="/data/Entries/Entrie[Entry_ID = $eid]"/>
		
		<xsl:variable name="prefix" select="substring($entry/Entry_FullBib, 1, 1)"/>
		
		<!-- skip fields -->
		<xsl:text>;;;</xsl:text>
		
		<xsl:value-of select="CE_Lane"/>	
		<xsl:text>;</xsl:text>

		<xsl:if test="boolean($convert_prefixed_bibs)">
			<xsl:choose>
				<xsl:when test="$prefix = 'A'">1</xsl:when>
				<xsl:when test="$prefix = 'B'">2</xsl:when>
				<xsl:when test="$prefix = 'C'">3</xsl:when>
				<xsl:when test="$prefix = 'D'">4</xsl:when>
				<xsl:when test="$prefix = 'E'">5</xsl:when>
				<xsl:when test="$prefix = 'F'">6</xsl:when>
				<xsl:when test="$prefix = 'G'">7</xsl:when>
				<xsl:when test="$prefix = 'H'">8</xsl:when>
				<xsl:when test="$prefix = 'I'">9</xsl:when>
				<xsl:when test="$prefix = 'J'">10</xsl:when>
				<xsl:when test="$prefix = 'K'">11</xsl:when>
				<xsl:when test="$prefix = 'L'">12</xsl:when>
				<xsl:when test="$prefix = 'M'">13</xsl:when>
				<xsl:when test="$prefix = 'N'">14</xsl:when>
				<xsl:when test="$prefix = 'O'">15</xsl:when>
				<xsl:when test="$prefix = 'P'">16</xsl:when>
				<xsl:when test="$prefix = 'Q'">17</xsl:when>
				<xsl:when test="$prefix = 'R'">18</xsl:when>
				<xsl:when test="$prefix = 'S'">19</xsl:when>
				<xsl:when test="$prefix = 'T'">20</xsl:when>
				<xsl:when test="$prefix = 'U'">21</xsl:when>
				<xsl:when test="$prefix = 'V'">22</xsl:when>
				<xsl:when test="$prefix = 'W'">23</xsl:when>
				<xsl:when test="$prefix = 'X'">24</xsl:when>
				<xsl:when test="$prefix = 'Y'">25</xsl:when>
				<xsl:when test="$prefix = 'Z'">26</xsl:when>
				<xsl:otherwise>
					<xsl:text></xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="$entry/Entry_Bib &lt; 10">
				<xsl:text>0</xsl:text>
			</xsl:if>
			<xsl:value-of select="$entry/Entry_Bib"/>
		</xsl:if>

		<xsl:if test="not(boolean($convert_prefixed_bibs))">
			<xsl:value-of select="$entry/Entry_Bib"/>
		</xsl:if>
		<xsl:text>;</xsl:text>
		
		<!-- use OSV's lastname field for entry label (keep OSV's firstname field blank) -->
		<xsl:call-template name="GetEntryLabel">
			<xsl:with-param name="entry" select="$entry"/>
			<xsl:with-param name="round" select="$round"/>
			<xsl:with-param name="short" select="true()"/>
			<xsl:with-param name="with-extra" select="false()"/>
		</xsl:call-template>
		<xsl:text>;;</xsl:text>
		
		<!-- nation -->
		<xsl:apply-templates select="$entry" mode="GetNOCCode">
			<xsl:with-param name="round" select="$round"/>
		</xsl:apply-templates>
		<xsl:text>;</xsl:text>
		
		<!-- skip following fields -->
		<xsl:text>;;;</xsl:text>
		
		<xsl:call-template name="linebreak"/>
	</xsl:template>	
	
</xsl:stylesheet>
