<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:include href="./includes/standard.xsl"/>
	<xsl:include href="./includes/bookmarktree.xsl" />
	<xsl:include href="./includes/racecompheader.xsl"/>
	
	<xsl:param name="scratches" select="/data/ReportOptions/ReportOption[Name='scratches']/Value"/>	

	<xsl:template name="body">
		<!-- iterate over races -->
		<xsl:for-each select="/data/Races/Race[Offer_Driven = 1 or $scratches = 1]">
			<fo:block>
				<xsl:apply-templates select="." mode="header"/>
				<xsl:apply-templates select="." mode="schedule_info"/>
				<xsl:apply-templates select="." mode="groups"/>
			</fo:block>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Race" mode="groups">
		<!-- Alle Gruppen ausgeben -->
		<xsl:variable name="rid" select="Offer_ID"/>
		
		<fo:block margin=".5em 0em 1em 0em" keep-with-previous.within-page="always">
		<xsl:for-each select="/data/Stats/Stat[Race_ID = $rid]">
			<xsl:variable name="grp_val" select="GroupValue"/>
			<fo:block>
				<xsl:variable name="entries" select="/data/Entries/Entrie[Entry_Race_ID_FK = $rid and Entry_GroupValue = $grp_val]"/>
				
				<xsl:if test="count($entries) &gt; 0">
							
					<!--  Gruppenheader -->		
					<xsl:if test="Mode &gt; 0">
						<fo:block font-style="italic" line-height="2em" keep-with-previous.within-page="always" margin-left="1cm">
							<xsl:call-template name="GetGroupString">
								<xsl:with-param name="mode" select="Mode"/>
								<xsl:with-param name="value" select="GroupValue"/>
							</xsl:call-template>							
							<xsl:if test="(Entries &lt; 2 or Clubs &lt; 2) and (ForceDriven = 0)">
								<xsl:text> - fällt aus</xsl:text>
							</xsl:if>
						</fo:block>
					</xsl:if>
		
					<fo:list-block provisional-label-separation="2mm" provisional-distance-between-starts="1cm" keep-with-previous.within-page="always">
						<xsl:apply-templates select="$entries" mode="entry_list"/>
					</fo:list-block>
					
				</xsl:if>

			</fo:block>
		
		</xsl:for-each>
		</fo:block>
	</xsl:template>
	
	<!-- match expression is not a typo! -->
	<xsl:template match="Entrie" mode="entry_list">
			<fo:list-item>
				<!-- Bib (start number) -->
				<fo:list-item-label end-indent="label-end()">
					<fo:block font-weight="bold" text-align="right">
						<xsl:value-of select="Entry_FullBib"/>
					</fo:block>
				</fo:list-item-label>
				
				<!-- Entry Label and Crew -->
				<fo:list-item-body start-indent="body-start()">
					<fo:block text-align="justify" text-align-last="right">
						<xsl:variable name="boat_label">
							<xsl:call-template name="GetEntryLabel">
								<xsl:with-param name="entry" select="."/>
								<xsl:with-param name="short" select="true()"/>
								<xsl:with-param name="round" select="number('0')"/>
							</xsl:call-template>
						</xsl:variable>

						<xsl:variable name="crew_label">
							<xsl:apply-templates select="." mode="GetCrewString">
								<xsl:with-param name="round" select="number('0')"/>
							</xsl:apply-templates>
						</xsl:variable>

						<!-- some primitive heuristic for making linebreaks nicer -->
						<xsl:choose>
							<xsl:when test="string-length(concat($boat_label, $crew_label)) &gt; 80">
								<xsl:attribute name="text-align">justify</xsl:attribute>
								<xsl:attribute name="text-align-last">right</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="text-align-last">justify</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>

						<fo:inline font-weight="bold"><xsl:value-of select="$boat_label"/></fo:inline>
						<fo:leader/>
						<fo:inline><xsl:value-of select="$crew_label"/></fo:inline>
					</fo:block>
				</fo:list-item-body>
			</fo:list-item>
	</xsl:template>
	
	<xsl:template match="/data" mode="bookmarktree" priority="9">
		<fo:bookmark-tree>
			<xsl:call-template name="RaceBookMarkTree">
				<xsl:with-param name="races" select="/data/Races/Race[Offer_Driven = 1 or $scratches = 1]"/>		
			</xsl:call-template>
		</fo:bookmark-tree>
	</xsl:template>
	
</xsl:stylesheet>
