<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:output method="xml" encoding="utf-8" version="1.0" omit-xml-declaration="no" indent="yes"/>
	
	<xsl:include href="./includes/standard.xsl"/>

    <xsl:decimal-format name="european" decimal-separator=',' grouping-separator='.' />    

	<!-- use landscape paper layout -->
	<xsl:template match="/data" mode="pageformat" priority="9">
		<xsl:text>A4-landscape</xsl:text>
	</xsl:template>

	<xsl:template name="body">
		<xsl:if test="count(/data/Clubs/Club) &gt; 0">
			<fo:table table-layout="fixed" width="100%" font-size="10pt">
				<fo:table-column column-number="1" column-width="8cm"/>
				<fo:table-column column-number="2" column-width="9cm"/>
				<fo:table-column column-number="3" column-width="1.cm"/>
				<fo:table-column column-number="4" column-width="1.5cm"/>
				<fo:table-column column-number="5" column-width="2cm"/>
				<fo:table-column column-number="6" column-width="1.5cm"/>
				<fo:table-column column-number="7" column-width="2cm"/>
				<fo:table-column column-number="8" column-width="2cm"/>
				
				<fo:table-header>
					<fo:table-row border="medium solid black" margin-bottom="4pt" padding-bottom="4pt">
						<fo:table-cell margin-left="0.25em"><fo:block>meldender Verein</fo:block></fo:table-cell>
						<fo:table-cell border-right="medium solid black"><fo:block>zahlt für</fo:block></fo:table-cell>
						<fo:table-cell margin-right="0.25em"><fo:block text-align="right">Meld.</fo:block></fo:table-cell>
						<fo:table-cell margin-right="0.25em"><fo:block text-align="right">Rabatt</fo:block></fo:table-cell>
						<fo:table-cell margin-right="0.25em" border-right="medium solid black"><fo:block text-align="right">Beitrag</fo:block></fo:table-cell>	
						<fo:table-cell margin-right="0.25em"><fo:block text-align="right">Nachm.</fo:block></fo:table-cell>					
						<fo:table-cell margin-right="0.25em" border-right="medium solid black"><fo:block text-align="right">Beitrag</fo:block></fo:table-cell>
						<fo:table-cell margin-right="0.25em"><fo:block text-align="right">Summe</fo:block></fo:table-cell>
					</fo:table-row>
			        <fo:table-row>
			            <fo:table-cell padding="0.125em">
			                <fo:block></fo:block>
			            </fo:table-cell>
			        </fo:table-row>					
				</fo:table-header>
				
				<fo:table-body border="medium black solid">
					<xsl:apply-templates select="/data/Clubs/Club">
						<xsl:sort select="Nation_IOC_Code"/>
						<xsl:sort select="City"/>
						<xsl:sort select="Abbr"/>
						<xsl:sort select="Team"/>
					</xsl:apply-templates>
				</fo:table-body>		
			</fo:table>
		</xsl:if>
	</xsl:template>
	
    <xsl:template match="Club">
        <xsl:variable name="e_ll" select="Entry_LongLabel"/>
        <xsl:variable name="cid" select="ID"/>
        
        <xsl:variable name="regularEntries" select="/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid and Entry_IsLate != 1]"/>
        <xsl:variable name="csum">
            <xsl:call-template name="club_fee_sum">
                <xsl:with-param name="entries" select="$regularEntries"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:variable name="lateEntries" select="/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid and Entry_IsLate = 1]"/>
        <xsl:variable name="clatesum">
            <xsl:call-template name="club_fee_sum">
                <xsl:with-param name="entries" select="$lateEntries"/>
            </xsl:call-template>
        </xsl:variable>        

		<fo:table-row>
			<fo:table-cell>
				<fo:block-container overflow="hidden" margin-left="0.25em" margin-right="0.25em">
					<fo:block wrap-option="no-wrap">
						<xsl:if test="$show_noc">
							<xsl:value-of select="Nation_IOC_Code"/>
							<xsl:text> </xsl:text>
						</xsl:if>
						<xsl:value-of select="City"/>
						<xsl:text>, </xsl:text>
						<xsl:value-of select="Abbr"/>
					</fo:block>
				</fo:block-container>
			</fo:table-cell>
			<fo:table-cell border-right="medium solid black">
				<fo:block-container overflow="hidden" margin-right="0.25em">
					<fo:block wrap-option="no-wrap">
						<xsl:if test="Entry_ShortLabel != Abbr">
							<xsl:value-of select="Entry_ShortLabel"/>
						</xsl:if>
						<xsl:if test="Entry_ShortLabel = Abbr">
							<fo:inline font-size="8pt">
								<xsl:text>[sich selbst]</xsl:text>
							</fo:inline>
						</xsl:if>
					</fo:block>
				</fo:block-container>			
			</fo:table-cell>
			
			<!-- number of total entries (including late) -->
			<fo:table-cell>
				<fo:block text-align="right">
					<xsl:value-of select="count(/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid])"/>
				</fo:block>			
			</fo:table-cell>

			<!-- discount -->			
			<fo:table-cell>
				<fo:block text-align="right">
					<xsl:if test="./Discount &gt; 0"> 
						<xsl:value-of select="format-number(./Discount, '#0,#', 'european')"/>
						<xsl:text>%</xsl:text>					
					</xsl:if>
					<xsl:if test="./Discount = 0"> 
						<xsl:text>-</xsl:text>					
					</xsl:if>					
				</fo:block>			
			</fo:table-cell>
			
			<!-- fee for regular entries -->
			<fo:table-cell border-right="medium solid black">
				<fo:block text-align="right" margin-right="0.25em">
					<xsl:value-of select="format-number($csum * (100 - ./Discount) div 100, '#0,00', 'european')"/>
					<xsl:text> €</xsl:text>
				</fo:block>			
			</fo:table-cell>
			
			<!-- number of late entries -->
			<fo:table-cell>
				<fo:block text-align="right">
					<xsl:if test="count($lateEntries) &gt; 0">
						<xsl:value-of select="count(/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid and Entry_IsLate = 1])"/>
					</xsl:if>
					<xsl:if test="count($lateEntries) = 0"> 
						<xsl:text>-</xsl:text>					
					</xsl:if>					
				</fo:block>			
			</fo:table-cell>
			
			<!-- fee for late entries -->
			<fo:table-cell border-right="medium solid black">
				<fo:block text-align="right" margin-right="0.25em">
					<xsl:if test="$clatesum &gt; 0">
						<xsl:value-of select="format-number(2 * $clatesum, '#0,00', 'european')"/>
						<xsl:text> €</xsl:text>
					</xsl:if>
					<xsl:if test="$clatesum = 0"> 
						<xsl:text>-</xsl:text>
					</xsl:if>
				</fo:block>			
			</fo:table-cell>			

			<!-- total -->
			<fo:table-cell>
				<fo:block text-align="right" margin-right="0.25em">
					<xsl:value-of select="format-number($csum * (100 - ./Discount) div 100 + 2 * $clatesum , '#0,00', 'european')"/>
					<xsl:text> €</xsl:text>
				</fo:block>			
			</fo:table-cell>
			
		</fo:table-row>    	
    </xsl:template>
	
</xsl:stylesheet>
