<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:include href="./includes/standard.xsl"/>
    
    <xsl:decimal-format name="european" decimal-separator=',' grouping-separator='.' />    

    <xsl:template name="body">   
		<fo:table width="100%" table-layout="fixed" font-size="9.25pt" table-omit-footer-at-break="true">
		
		    <!-- Tabellenlayout:
		        Spalte 1: Rennnummer
		        Spalte 2: Bezeichnung
		        Spalte 3: Meldegeld 
		        Spalte 4: Boote
		        Spalte 5: befreite Boote (wg. Ausfall der Leistungs/Altersgruppe 
		        Spalte 6: Summe
		     -->
		
		    <fo:table-column column-number="1" column-width="2cm"/> 
		    <fo:table-column column-number="2" column-width="5cm"/>
		    <fo:table-column column-number="3" column-width="2.5cm"/>
		    <fo:table-column column-number="4" column-width="1.25cm"/>
		    <fo:table-column column-number="5" column-width="1.25cm"/>
		    <fo:table-column column-number="6" column-width="1.25cm"/>
		    <fo:table-column column-number="7" column-width="2.25cm"/>
		    <fo:table-column column-number="8" column-width="2.5cm"/>
		    
		    <fo:table-header>
		        <fo:table-row font-weight="bold">
		            <fo:table-cell padding-left="0.25em" padding-top="0.1em" border="medium black solid"><fo:block>Rennnr.</fo:block></fo:table-cell>
		            <fo:table-cell padding-left="0.25em" padding-top="0.1em" border="medium black solid"><fo:block>Bezeichnung</fo:block></fo:table-cell>
		            <fo:table-cell padding-right="0.25em" padding-top="0.1em" border="medium black solid"><fo:block text-align="right">Meldegeld</fo:block></fo:table-cell>
		            <fo:table-cell padding-right="0.25em" padding-top="0.1em" border="medium black solid"><fo:block text-align="right">Boote</fo:block></fo:table-cell>                     
		            <fo:table-cell padding-right="0.25em" padding-top="0.1em" border="medium black solid"><fo:block text-align="right">Nachm</fo:block></fo:table-cell>
		            <fo:table-cell padding-right="0.25em" padding-top="0.1em" border="medium black solid"><fo:block text-align="right">befreit</fo:block></fo:table-cell>
		            <fo:table-cell padding-right="0.25em" padding-top="0.1em" border="medium black solid"><fo:block text-align="right">Rabatte</fo:block></fo:table-cell>
		            <fo:table-cell padding-right="0.25em" padding-top="0.1em" border="medium black solid"><fo:block text-align="right">Summe</fo:block></fo:table-cell>
		        </fo:table-row>
		        <fo:table-row>
		            <fo:table-cell padding="0.125em">
		                <fo:block></fo:block>
		            </fo:table-cell>
		        </fo:table-row>
		    </fo:table-header>
		    
            <fo:table-footer font-weight="bold">
                <fo:table-row>
                    <fo:table-cell padding="0.25em">
                        <fo:block></fo:block>
                    </fo:table-cell>
                </fo:table-row>
                <fo:table-row>
                    <fo:table-cell margin-top="1em"><fo:block/></fo:table-cell>
                    <fo:table-cell><fo:block/></fo:table-cell>
                    <fo:table-cell padding="0.25em">
                        <fo:block text-align="right">Summe</fo:block>
                    </fo:table-cell>
                    
                    <fo:table-cell border="medium solid black" padding="0.25em">
                        <fo:block text-align="right">
                            <xsl:value-of select="sum(/data/Stats/Stat/Entries)"/>
                        </fo:block>
                    </fo:table-cell>
                    
                    <fo:table-cell border="medium solid black" padding="0.25em">
                        <fo:block text-align="right">
                            <xsl:value-of select="sum(/data/Stats/Stat/NumLate)"/>
                        </fo:block>
                    </fo:table-cell>
                    
                    <fo:table-cell border="medium solid black" padding="0.25em">
                        <fo:block text-align="right">
                            <xsl:value-of select="sum(/data/Stats/Stat[GroupDriven = 0]/Entries)"/>
                        </fo:block>
                    </fo:table-cell>
                    
                    <fo:table-cell border="medium solid black" padding="0.25em">
                        <fo:block text-align="right">
                            <xsl:value-of select="format-number(sum(/data/Stats/Stat/DiscountSum), '#0,00', 'european')"/>
                            <xsl:text> EUR</xsl:text>
                        </fo:block>
                    </fo:table-cell>
                    
                    <fo:table-cell border="medium solid black" padding="0.25em">
                        <fo:block text-align="right">
                            <xsl:value-of select="format-number(sum(/data/Stats/Stat/GroupFee) - sum(/data/Stats/Stat/DiscountSum) + sum(/data/Stats/Stat/LateFee), '#0,00', 'european')"/>
                            <xsl:text> EUR</xsl:text>
                        </fo:block>
                    </fo:table-cell>                    
                </fo:table-row>
            </fo:table-footer>            
		    
		    <fo:table-body border="medium black solid">

		        <xsl:for-each select="/data/Races/Race">
		            <xsl:variable name="rid" select="Offer_ID"/>
		            <xsl:variable name="fee" select="/data/Stats/Stat[Race_ID = $rid]/Fee[1]"/>
		            <xsl:variable name="entry_count" select="sum(/data/Stats/Stat[Race_ID = $rid]/Entries)"/>
		            <xsl:variable name="freed_count" select="sum(/data/Stats/Stat[Race_ID = $rid and GroupDriven = 0]/Entries)"/>
		            <xsl:variable name="fee_sum" select="sum(/data/Stats/Stat[Race_ID = $rid]/GroupFee) * 1.00"/>
		            <xsl:variable name="late_count" select="sum(/data/Stats/Stat[Race_ID = $rid]/NumLate)"/>
		            <xsl:variable name="late_fee" select="sum(/data/Stats/Stat[Race_ID = $rid]/LateFee)"/>
		            <xsl:variable name="discount_sum" select="sum(/data/Stats/Stat[Race_ID = $rid]/DiscountSum)"/>
		             	        
		            <fo:table-row>
                        <fo:table-cell padding="0.25em">
                            <fo:block>
                                <xsl:value-of select="Offer_RaceNumber"/>
		                   </fo:block>
                        </fo:table-cell>
		               
                        <fo:table-cell padding="0.25em" border-left="medium black solid">
                            <fo:block>
                                <xsl:value-of select="Offer_ShortLabel"/>
                                <xsl:text> </xsl:text>
                                <xsl:value-of select="Offer_Comment"/>
                            </fo:block>
                        </fo:table-cell>
		                           
                        <fo:table-cell padding="0.25em" border-left="medium black solid">
                            <fo:block text-align="right">
                                <xsl:value-of select="format-number(Offer_Fee, '#0,00', 'european')"/>
                                <xsl:text> EUR</xsl:text>
                            </fo:block>
                        </fo:table-cell>
		               
                        <fo:table-cell padding="0.25em" border-left="medium black solid">
                            <fo:block text-align="right">
                                <xsl:value-of select="$entry_count"/>
                            </fo:block>
                        </fo:table-cell>
		                                          
                        <fo:table-cell padding="0.25em" border-left="medium black solid">
                        	<fo:block text-align="right">
                       			<xsl:value-of select="$late_count"/>
                        	</fo:block>
                        </fo:table-cell>

                        <fo:table-cell padding="0.25em" border-left="medium black solid">
                            <fo:block text-align="right">
                                <xsl:value-of select="$freed_count"/>
                            </fo:block>
                        </fo:table-cell>
                        
                        <fo:table-cell padding="0.25em" border-left="medium black solid">
                        	<fo:block text-align="right">
                        		<xsl:if test="$discount_sum &gt; 0">
                        			<xsl:value-of select="format-number($discount_sum, '#0,00', 'european')"/>
                        			<xsl:text> EUR</xsl:text>
                        		</xsl:if>
                        		<xsl:if test="$discount_sum = 0">
                        			<xsl:text>-</xsl:text>
                        		</xsl:if>
                        	</fo:block>
                        </fo:table-cell>

                        <fo:table-cell padding="0.25em" border-left="medium black solid">
                            <fo:block text-align="right">
                                <xsl:value-of select="format-number($fee_sum - $discount_sum + $late_fee, '#0,00', 'european')"/>
                                <xsl:text> EUR</xsl:text>
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>
                </xsl:for-each> 
            </fo:table-body>
        </fo:table>
    </xsl:template>
    

</xsl:stylesheet>
