<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:param name="scratches" select="/data/ReportOptions/ReportOption[Name='scratches']/Value"/>
	<xsl:param name="highlight_changes" select="boolean(/data/ReportOptions/ReportOption[Name='highlight_changes']/Value = 1)"/>
	<xsl:param name="order_by_final_time" select="boolean(/data/ReportOptions/ReportOption[Name='order_by_final_time']/Value = 1)"/>
	<xsl:param name="break_at_day_change" select="boolean(/data/ReportOptions/ReportOption[Name='break_at_day_change']/Value = 1)"/>

	<xsl:include href="./includes/standard.xsl"/>
	<xsl:include href="./includes/bookmarktree.xsl" />
	<xsl:include href="./includes/racecompheader.xsl"/>

	<xsl:template name="body">
		<!-- iterate over (sorted) races -->
		<xsl:if test="$order_by_final_time">
			<!-- sort races by time of their first A-final. Note that this may confuse consumers when race 1 is in between 19 and 20 due to changes in the schedule -->
			<xsl:apply-templates select="/data/Races/Race[Offer_Driven = 1 or $scratches = 1]" mode="item">
				<xsl:sort select="number(translate(/data/Comps/Comp[Race_ID_FK = current()/Offer_ID and Round = 64 and HeatNumber = 1][1]/RawDate, ',', '.'))" data-type="number"/>
			</xsl:apply-templates>
		</xsl:if>
		<xsl:if test="not($order_by_final_time)">
			<xsl:apply-templates select="/data/Races/Race[Offer_Driven = 1 or $scratches = 1]" mode="item"/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Race" mode="item">
		<xsl:apply-templates select="." mode="header"/>
		<xsl:apply-templates select="." mode="schedule_info">
			<xsl:with-param name="pretty_print" select="true()"/>			
		</xsl:apply-templates>
		<xsl:apply-templates select="." mode="groups">
			<xsl:with-param name="first_race" select="position() = 1"/>
		</xsl:apply-templates>
		<fo:block margin-bottom="1em" keep-with-previous="always"/>
		<xsl:apply-templates select="." mode="daybreak"/>
	</xsl:template>
	
	<xsl:template match="Race" mode="groups">
		<!-- Alle Gruppen ausgeben -->
		<xsl:param name="first_race"/>
		<xsl:variable name="rid" select="Offer_ID"/>
		
		<xsl:for-each select="/data/Stats/Stat[Race_ID = $rid]">
			<xsl:variable name="grp_val" select="GroupValue"/>
				<xsl:variable name="entries" select="/data/Entries/Entrie[Entry_Race_ID_FK = $rid and Entry_GroupValue = $grp_val]"/>				

				<xsl:if test="count($entries) &gt; 0">
					<fo:block keep-with-next="always" margin-top=".5em">
						<!-- group header -->		
						<xsl:if test="Mode &gt; 0">
							<fo:block font-style="italic" line-height="2em" keep-with-next="always" margin-left="1cm">
								<xsl:call-template name="GetGroupString">
									<xsl:with-param name="mode" select="Mode"/>
									<xsl:with-param name="value" select="GroupValue"/>
								</xsl:call-template>							
								<xsl:if test="Entries &lt; 2 or Clubs &lt; 2">
									<xsl:text> - fällt aus</xsl:text>
								</xsl:if>
							</fo:block>
						</xsl:if>

						<!-- entries -->			
						<fo:list-block provisional-label-separation="2mm"
							provisional-distance-between-starts="1cm" font-size="11pt"
							keep-with-next="always">		
							<xsl:apply-templates select="$entries" mode="entry_list">
								<xsl:with-param name="first_race" select="$first_race"/>
							</xsl:apply-templates>
						</fo:list-block>
					</fo:block>
				</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<!-- match expression is not a typo! -->
	<xsl:template match="Entrie" mode="entry_list">
		<xsl:param name="first_race"/>
		<fo:list-item>
			<xsl:if test="$first_race = false()">
				<xsl:attribute name="keep-with-next">
					<xsl:text>400</xsl:text>
				</xsl:attribute>
			</xsl:if>
			<!-- Bib (start number) -->
			<fo:list-item-label end-indent="label-end()">
				<fo:block font-weight="bold" text-align="right">
					<xsl:value-of select="Entry_FullBib"/>
				</fo:block>
			</fo:list-item-label>
			
			<!-- Entry Label and Crew -->
			<fo:list-item-body start-indent="body-start()">
				<fo:block font-weight="bold" keep-with-next="always" keep-together.within-page="always">
					<xsl:if test="$highlight_changes">
						<xsl:if test="Entry_CancelValue != 0">
							<xsl:attribute name="text-decoration">
								<xsl:text>line-through</xsl:text>
							</xsl:attribute>
						</xsl:if>
					</xsl:if>

					<xsl:call-template name="GetEntryLabel">
						<xsl:with-param name="entry" select="."/>
						<!-- use latest crew label -->
					</xsl:call-template>

					<xsl:if test="($highlight_changes) and ((Entry_CancelValue != 0) or (Entry_IsLate != 0))">
						<fo:inline font-weight="normal" text-decoration="none">
							<xsl:text> (</xsl:text>
							<xsl:if test="Entry_IsLate != 0">
								<xsl:text>nachgemeldet</xsl:text>
							</xsl:if>
							<xsl:if test="(Entry_CancelValue != 0) and (Entry_IsLate != 0)">
								<xsl:text>, </xsl:text>
							</xsl:if>							
							<xsl:if test="Entry_CancelValue != 0">
								<xsl:text>abgemeldet</xsl:text>
							</xsl:if>
							<xsl:text>)</xsl:text>
						</fo:inline>
					</xsl:if>
				</fo:block>
				<fo:block font-size="10pt" keep-together.within-page="always">
					<!-- fetch most recent crew as we also account changes -->
					<xsl:apply-templates select="." mode="GetCrewString"/>
				</fo:block>
			</fo:list-item-body>
		</fo:list-item>
	</xsl:template>

	<xsl:template match="/data" mode="bookmarktree" priority="9">
		<fo:bookmark-tree>
			<xsl:call-template name="RaceBookMarkTree">
				<xsl:with-param name="races" select="/data/Races/Race[Offer_Driven = 1 or $scratches = 1]"/>		
			</xsl:call-template>
		</fo:bookmark-tree>
	</xsl:template>

	<!-- insert page break when a new day starts -->
	<xsl:template match="Race" mode="daybreak">
		<xsl:variable name="cid" select="Offer_ID"/>
		<xsl:variable name="nextrace" select="current()/following-sibling::Race[Offer_Driven = 1][1]"/>
		<!-- find time of the first final comp of the next driven race (ignore any group values) -->
		<xsl:variable name="cur_final" select="/data/Comps/Comp[Race_ID_FK = $cid and Round = 64 and HeatNumber = 1][1]"/>
		<xsl:variable name="cur_date" select="substring-before($cur_final/DateTime, ' ')"/>
		<xsl:variable name="next_date" select="substring-before(/data/Comps/Comp[Race_ID_FK = $nextrace/Offer_ID and Round = 64 and HeatNumber = 1][1]/DateTime, ' ')"/>
		<xsl:if test="($break_at_day_change) and ($nextrace) and ($cur_date != $next_date)">
			<fo:block text-align="center" keep-with-previous="always" break-after="page" font-style="italic" margin="1em">
				<xsl:text>Ende </xsl:text>
				<xsl:call-template name="GetLongWeekDay">
					<xsl:with-param name="day" select="$cur_final/WeekDay"/>
				</xsl:call-template>
			</fo:block>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>
