<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:include href="./includes/standard.xsl"/>
	
	<xsl:param name="hide_licence_id" select="/data/ReportOptions/ReportOption[Name='hide_licence_id']/Value"/>
	<xsl:param name="only_invalid_aths" select="/data/ReportOptions/ReportOption[Name='only_invalid_aths']/Value"/>
	<xsl:param name="with_external_state" select="/data/ReportOptions/ReportOption[Name='with_external_state']/Value"/>
	<xsl:param name="with_times" select="/data/ReportOptions/ReportOption[Name='with_times']/Value"/>
	<xsl:param name="exclude_foreigners" select="/data/ReportOptions/ReportOption[Name='exclude_foreigners']/Value"/>

	<xsl:template name="body">
	
		<xsl:if test="count(/data/Athlets/Athlet[(State = 0 and $only_invalid_aths = 1) or ($only_invalid_aths = 0)]) &gt; 0">
			<fo:table width="100%" table-layout="fixed" font-size="9.25pt">
			
				<!-- Tabellenlayout:
					Spalte 1: Verein
					Spalte 2: Sportler 
					Spalte 3: Jahrgang
					Spalte 4: Startberechtigung
					(Spalte 5: sekundaerer Status)
					Spalte 5: Pass
					Spalte 6: Rennen des Sportles
				 -->
	
				<fo:table-column column-number="1" column-width="4cm"/>
				<xsl:if test="$with_external_state = 0">
					<fo:table-column column-number="2" column-width="5cm"/>
					<fo:table-column column-number="3" column-width="1cm"/>
					<fo:table-column column-number="4" column-width="1cm"/>
					<fo:table-column column-number="5" column-width="2.25cm"/>
					<fo:table-column column-number="6" column-width="4.75cm"/>
				</xsl:if>
				<xsl:if test="$with_external_state = 1">
					<fo:table-column column-number="2" column-width="4.25cm"/>
					<fo:table-column column-number="3" column-width="1cm"/>
					<fo:table-column column-number="4" column-width="1cm"/>
					<fo:table-column column-number="5" column-width="2.25cm"/>
					<fo:table-column column-number="6" column-width="0.75cm"/>
					<fo:table-column column-number="7" column-width="4.75cm"/>
				</xsl:if>
				
				<fo:table-header>
					<fo:table-row border="0.75pt solid black" font-weight="bold">
						<fo:table-cell padding-left="0.25em" padding-top="0.1em" border="0.75pt color solid"><fo:block>Verein</fo:block></fo:table-cell>
						<fo:table-cell padding-left="0.25em" padding-top="0.1em" border="0.75pt color solid"><fo:block>Athlet</fo:block></fo:table-cell>
						<fo:table-cell padding-right="0.25em" padding-top="0.1em" border="0.75pt color solid"><fo:block text-align="right">Jahr</fo:block></fo:table-cell>
						<fo:table-cell padding-right="0.25em" padding-top="0.1em" border="0.75pt color solid"><fo:block text-align="right">SB</fo:block></fo:table-cell>
						<fo:table-cell padding-right="0.25em" padding-top="0.1em" border="0.75pt color solid"><fo:block text-align="right">Pass</fo:block></fo:table-cell>
						<xsl:if test="$with_external_state = 1">
							<fo:table-cell padding-right="0.25em" padding-top="0.1em" border="0.75pt color solid"><fo:block text-align="right">TS</fo:block></fo:table-cell>
						</xsl:if>
						<fo:table-cell padding-left="0.25em" padding-top="0.1em" border="0.75pt color solid"><fo:block>Rennen</fo:block></fo:table-cell>
					</fo:table-row>
					<fo:table-row>
						<fo:table-cell padding="0.125em">
							<fo:block></fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				
				<fo:table-body border="0.75pt solid black">
			
					<xsl:for-each select="/data/Clubs/*">
						<xsl:call-template name="club_athletes">
							<xsl:with-param name="club" select="ID"/>
							<xsl:with-param name="clubname" select="concat(City, ', ', Abbr)"/>
						</xsl:call-template>
					</xsl:for-each>	
				
				</fo:table-body>
				
			</fo:table>
		</xsl:if>
	</xsl:template>
	
	<!-- Alle Sportler eines Vereins -->
	<xsl:template name="club_athletes">
		<xsl:param name="club"/>
		<xsl:param name="clubname"/>

		<xsl:variable name="event_nation" select="/data/Event/Event/Venue_Nation_Code"/>
		<xsl:variable name="aths" select="/data/Athlets/Athlet[((Crew_Club_ID_FK=$club and State = 0 and $only_invalid_aths = 1) or (Crew_Club_ID_FK=$club and $only_invalid_aths = 0)) and (($exclude_foreigners = 0) or ($exclude_foreigners = 1 and Nation_IOC_Code = $event_nation))]"/>
		<xsl:variable name="ath_count" select="count($aths)"/>
		
		<xsl:for-each select="$aths">
				<fo:table-row>
					<xsl:if test="position() = last()">
						<xsl:attribute name="border-bottom">0.75pt solid black</xsl:attribute>
					</xsl:if>
				
					<xsl:if test="position() = 1">
						<fo:table-cell padding-top="0.1em" padding-left="0.25em"> 
							<xsl:attribute name="number-rows-spanned">
								<xsl:value-of select="$ath_count"/>
							</xsl:attribute> 
							<fo:block>
								<xsl:if test="$show_noc">
									<xsl:value-of select="Nation_IOC_Code"/>
									<xsl:text>, </xsl:text>
								</xsl:if>
								<xsl:value-of select="$clubname"/>
								<fo:block color="gray">
									<xsl:text> (</xsl:text>
									<xsl:value-of select="$ath_count"/>
									<xsl:text> Athlet</xsl:text>
									<xsl:if test="$ath_count &gt; 1">
										<xsl:text>en</xsl:text>    
									</xsl:if>   
								<xsl:text>)</xsl:text>
							</fo:block>
                                
						    </fo:block>
						</fo:table-cell>
					</xsl:if>					
					
					<fo:table-cell border-left="0.75pt solid black" padding-left="0.25em" padding-right="0.25em" padding-top="0.1em">
						<fo:block-container overflow="hidden">
							<fo:block wrap-option="no-wrap">
								<fo:inline text-transform="uppercase"><xsl:value-of select="LastName"/></fo:inline>
								<xsl:text>, </xsl:text>
								<xsl:value-of select="FirstName"/>
							</fo:block>
						</fo:block-container>
					</fo:table-cell>
					
					<fo:table-cell border-left="0.75pt solid black" padding-right="0.25em" padding-top="0.1em">
						<fo:block text-align="right">
							<xsl:value-of select="YOB"/>
						</fo:block>
					</fo:table-cell>
					
					<fo:table-cell border-left="0.75pt solid black" padding-right="0.25em" padding-top="0.1em">
						<fo:block text-align="right" text-transform="uppercase">
							<xsl:choose>
								<xsl:when test="State = 0">Nein</xsl:when>
								<xsl:when test="State = 1">Ja</xsl:when>
								<xsl:when test="State = 2">erw</xsl:when>
								<xsl:otherwise><xsl:text>?</xsl:text></xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					
					<fo:table-cell border-left="0.75pt solid black" padding-right="0.25em" padding-top="0.1em">
						<fo:block text-align="right" text-transform="uppercase">
							<xsl:if test="$hide_licence_id != 1">
								<xsl:value-of select="ExternID_A"/>
							</xsl:if>
							<xsl:if test="$hide_licence_id = 1">
								<xsl:choose>
									<xsl:when test="string-length(ExternID_A) &gt; 9"><xsl:text>Ja</xsl:text></xsl:when>
									<xsl:otherwise><xsl:text>Nein</xsl:text></xsl:otherwise>
								</xsl:choose>
							</xsl:if>
						</fo:block>
					</fo:table-cell>

					<xsl:if test="$with_external_state = 1">
						<fo:table-cell border-left="0.75pt solid black" padding-left="0.25em" padding-right="0.25em" padding-top="0.1em">
							<fo:block text-align="right">
								<xsl:value-of select="ExternState_B"/>
							</fo:block>
						</fo:table-cell>					
					</xsl:if>
					
					<fo:table-cell border-left="0.75pt solid black" padding-left="0.25em" padding-right="0.25em" padding-top="0.1em">
						<fo:block>
							<xsl:call-template name="ath_races">
								<xsl:with-param name="athlete" select="ID"/>
							</xsl:call-template>
						</fo:block>
					</fo:table-cell>
				
				</fo:table-row>
			</xsl:for-each>
	</xsl:template>

	<xsl:template name="ath_races">
		<xsl:param name="athlete"/>
		<xsl:for-each select="/data/AthRaces/AthRace[AID=$athlete]">
			<xsl:value-of select="Nr"/>
			<xsl:if test="count(/data/Comps/Comp[Race_ID_FK = current()/ID]) != 0">
				<xsl:if test="$with_times = 1">
					<xsl:text> (</xsl:text>
					<xsl:if test="IsCox = 1">
						<xsl:text>St., </xsl:text>
					</xsl:if>
					<xsl:for-each select="/data/Comps/Comp[Race_ID_FK = current()/ID]">
						<xsl:call-template name="GetShortWeekDay">
							<xsl:with-param name="day" select="WeekDay"/>
						</xsl:call-template>
						<xsl:text>.&#xA0;</xsl:text>
						<xsl:value-of select="substring(RoundTime, 12, 5)"/>
						<xsl:if test="position() != last()">
							<xsl:text>, </xsl:text>
						</xsl:if>
					</xsl:for-each>
					<xsl:text>)</xsl:text>
				</xsl:if>
			</xsl:if>
			<xsl:if test="$with_times = 0 and IsCox = 1">
				<xsl:text>&#xA0;(St.)</xsl:text>
			</xsl:if>
			<xsl:if test="position() != last()">
				<xsl:text>, </xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Title" mode="reportTitle" priority="500">
		<xsl:if test="$only_invalid_aths = 1">
			<xsl:text>nicht startberechtigte Sportler</xsl:text>
		</xsl:if>
		<xsl:if test="$only_invalid_aths = 0">
			<xsl:value-of select="."/>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>
