<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:output method="xml" encoding="utf-8" version="1.0" omit-xml-declaration="no" indent="yes"/>

    <xsl:param name="use_a4_paper" select="boolean(number(/data/ReportOptions/ReportOption[Name='use_a4_paper']/Value))"/>

    <xsl:decimal-format name="european" decimal-separator=',' grouping-separator='.' />    

    <!-- don't use standard include here, since we use another paper 
         format and want neither headers nor footers. -->

	<xsl:include href="./../inc/rowing_tools.xsl"/>

	<xsl:template match="/">
        <fo:root>
            <!-- Page Size Definitions -->      
            <fo:layout-master-set>
            
                <!-- A5 landscape -->
                <fo:simple-page-master master-name="A5-landscape" page-height="148.5mm" page-width="210mm" margin="7mm">
                    <fo:region-body region-name="page-region-body" margin-top="0.75cm" margin-bottom="0.8cm" column-count="3" column-gap="7mm"/>
                    <fo:region-before extent="0.5cm" region-name="page-header"/>
                    <fo:region-after extent="0.5cm" region-name="page-footer"/>
                </fo:simple-page-master>
                
                <!-- one third of a regular portraied A4 page -->
                <fo:simple-page-master master-name="A4-third" page-height="148.5mm" page-width="210mm" margin="7mm">
                    <fo:region-body region-name="page-region-body" margin-top="0.8cm" margin-bottom="0.8cm" column-count="3" column-gap="7mm"/>
                    <fo:region-before extent="0.75cm" region-name="page-header"/>
                    <fo:region-after extent="0.75cm" region-name="page-footer"/>
                </fo:simple-page-master>

		<!-- A4 portrait -->
		<fo:simple-page-master master-name="A4-portrait" page-height="297mm" page-width="210mm" margin="12mm">
                    <fo:region-body region-name="page-region-body" margin-top="0.75cm" margin-bottom="0.8cm" column-count="3" column-gap="7mm"/>
                    <fo:region-before extent="0.5cm" region-name="page-header"/>
                    <fo:region-after extent="0.5cm" region-name="page-footer"/>
		</fo:simple-page-master>
                
            </fo:layout-master-set>     
        
            <!-- Master Sequence -->
            <fo:page-sequence id="seq-primary">
            	<xsl:attribute name="master-reference">
			<xsl:if test="not(boolean($use_a4_paper))">A5-landscape</xsl:if>
			<xsl:if test="boolean($use_a4_paper)">A4-portrait</xsl:if>
            	</xsl:attribute>

                <xsl:comment>Header</xsl:comment>
                <fo:static-content flow-name="page-header">
                    <fo:block border-bottom="medium solid black" font-size="10pt">
                        <xsl:text>Quittung </xsl:text>
                        <xsl:value-of select="/data/Event/Event/Title"/>
                        <xsl:text>, </xsl:text> 
                        <xsl:value-of select="/data/Event/Event/Venue"/>
                    </fo:block>
                </fo:static-content>

                
                <xsl:comment>Footer</xsl:comment>
                <fo:static-content flow-name="page-footer">
                    <fo:block border-bottom="medium solid black" font-size="10pt">
                    	<xsl:value-of select="/data/Event/Event/Club_Name"/>
                    	<xsl:text>, </xsl:text>
                        <xsl:text>Stand </xsl:text>
                        <xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateDay, '00')"/>
                        <xsl:text>.</xsl:text>
                        <xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateMonth, '00')"/>
                        <xsl:text>.</xsl:text>
                        <xsl:value-of select="/data/ReportInfo/ReportInfo/DateYear"/>
                        <xsl:text> - </xsl:text>
                        <xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateHour, '00')"/>
                        <xsl:text>:</xsl:text>
                        <xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateMinute, '00')"/>
                        <xsl:text> Uhr</xsl:text>
                    </fo:block>
                </fo:static-content>
                         
                
                <xsl:comment>----------------------- Body ---------------------</xsl:comment>               
                
                <fo:flow flow-name="page-region-body" border="medium solid black" font-size="11pt">
                    <xsl:apply-templates select="/data/Clubs/Club">
                    	<xsl:sort select="Nation_IOC_Code"/>
                        <xsl:sort select="City"/>
                        <xsl:sort select="Abbr"/>
                        <xsl:sort select="Team"/>
                    </xsl:apply-templates>
                </fo:flow>
            </fo:page-sequence>
        </fo:root>
	</xsl:template>
	

    <xsl:template match="Club">
        <xsl:variable name="e_ll" select="Entry_LongLabel"/>
        <xsl:variable name="cid" select="ID"/>
        <xsl:variable name="csum">
            <xsl:call-template name="club_fee_sum">
                <xsl:with-param name="entries" select="/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid and Entry_IsLate != 1]"/>
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:variable name="lateEntries" select="/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid and Entry_IsLate = 1]"/>
        <xsl:variable name="clatesum">
            <xsl:call-template name="club_fee_sum">
                <xsl:with-param name="entries" select="$lateEntries"/>
            </xsl:call-template>
        </xsl:variable>
     
		<fo:block span="all" margin-bottom="1em">
		    <fo:block font-weight="bold" font-size="14pt">
		        <fo:inline font-weight="bold">
                            <xsl:if test="$show_noc">
                                <xsl:value-of select="Nation_IOC_Code"/>
                                <xsl:text>, </xsl:text>
                            </xsl:if>
		            <xsl:value-of select="City"/>
		            <xsl:text>, </xsl:text>
		            <xsl:value-of select="Abbr"/>
                </fo:inline>
            </fo:block>

	        <xsl:if test="Entry_LongLabel != Abbr">
	            <fo:block>
	                <xsl:text>Meldungen von o.g. Verein für </xsl:text>
	                <!-- text-decoration="underline"  /* too thin */ -->
	                <fo:inline border-bottom="medium solid black">
	                   <xsl:value-of select="Entry_LongLabel"/>
                    </fo:inline>
	            </fo:block>
	        </xsl:if>
		</fo:block>
		
		<xsl:call-template name="entries">
			<xsl:with-param name="entries" select="/data/Entries/Entrie[Label_Long = $e_ll and Entry_OwnerClub_ID_FK = $cid and Entry_IsLate != 1]"/>
		</xsl:call-template>
		
		<xsl:if test="count($lateEntries) &gt; 0">
			<fo:block keep-with-next="always" margin-top=".5em" font-weight="bold">
				<xsl:text>Nachmeldungen</xsl:text>
			</fo:block>
			<xsl:call-template name="entries">
				<xsl:with-param name="entries" select="$lateEntries"/>
			</xsl:call-template>
		</xsl:if>
 
		<!-- summary -->

		<fo:block text-align-last="justify" margin-top="0.5em" keep-with-next="always">
			<xsl:text>Meldegeld:</xsl:text>
			<fo:leader leader-pattern="space"/>
			<fo:inline>
                <xsl:value-of select="format-number($csum, '#0,00', 'european')"/>
   	            <xsl:text> €</xsl:text>
			</fo:inline>
		</fo:block>

		<fo:block text-align-last="justify" keep-with-next="always">
			<xsl:text>Nachmeldungen</xsl:text>
			<fo:leader leader-pattern="space"/>
			<fo:inline>
                <xsl:value-of select="format-number(2 * $clatesum, '#0,00', 'european')"/>
   	            <xsl:text> €</xsl:text>
			</fo:inline>
		</fo:block>
       
		<fo:block text-align-last="justify" keep-with-next="always">
			<xsl:text>Rabatt:</xsl:text>
			<fo:leader leader-pattern="space"/>
			<fo:inline>
                <xsl:value-of select="format-number(./Discount, '#0,#', 'european')"/>
   	            <xsl:text>%</xsl:text>
			</fo:inline>
		</fo:block>

        <fo:block text-align-last="justify" font-weight="bold" margin-top="0.5em" border-bottom="thick solid black">
            <xsl:text>Summe:</xsl:text>
            <fo:leader leader-pattern="space"/>
            <fo:inline>
                <xsl:value-of select="format-number($csum * (100 - ./Discount) div 100 + 2 * $clatesum , '#0,00', 'european')"/>
                <xsl:text> €</xsl:text>
            </fo:inline>
        </fo:block>
        
        <fo:block font-size="8pt" margin-top="1em" keep-with-previous="always">Betrag erhalten</fo:block>
        <fo:block-container height="2cm" border="medium dotted gray" keep-with-previous="always">
            <fo:block text-align="center" font-size="8pt" margin-top="1.5cm" color="gray">Datum, Stempel/Unterschrift</fo:block>
        </fo:block-container>
        
        <!-- force page break after each payee -->
        <fo:block break-after="page"/>
            
    </xsl:template>
       
    <xsl:template name="entries">
    	<xsl:param name="entries"/>
        <xsl:for-each select="$entries">
            <xsl:variable name="rid" select="Entry_Race_ID_FK"/>
            <xsl:variable name="gv" select="Entry_GroupValue"/>
            <xsl:variable name="gd" select="/data/Stats/Stat[Race_ID = $rid and Entry_GroupValue = $gv]/GroupDriven"/>
            <xsl:variable name="fee" select="/data/Stats/Stat[Race_ID = $rid and Entry_GroupValue = $gv]/Fee"/>
            
            <fo:block text-align-last="justify">
                <fo:inline>
                    <xsl:value-of select="/data/Races/Race[Offer_ID = $rid]/Offer_RaceNumber"/>
                    <xsl:text> - </xsl:text>
                    <xsl:value-of select="/data/Races/Race[Offer_ID = $rid]/Offer_ShortLabel"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="/data/Races/Race[Offer_ID = $rid]/Offer_Comment"/>
                </fo:inline>
                <fo:leader leader-pattern="space"/>
                <fo:inline>
                    <xsl:if test="$gd = 0"><xsl:text>-</xsl:text></xsl:if>
                    <xsl:if test="$gd = 1">
                    	<xsl:if test="Entry_IsLate != 1">
                        	<xsl:value-of select="format-number($fee, '#0,00', 'european')"></xsl:value-of>
                       	</xsl:if>
                    	<xsl:if test="Entry_IsLate = 1">
                        	<xsl:value-of select="format-number(2 * $fee, '#0,00', 'european')"></xsl:value-of>
                       	</xsl:if>
                        <xsl:text> €</xsl:text>
                    </xsl:if>
                </fo:inline>
            </fo:block>
        </xsl:for-each>    
    </xsl:template>
	
</xsl:stylesheet>
