<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:include href="./includes/standard.xsl"/>

    <xsl:template name="body">
    	<fo:table font-size="11pt">
    		<fo:table-column column-number="1" column-width="1.5cm"/>
    		<fo:table-column column-number="2" column-width="4.5cm"/>
    		<fo:table-column column-number="3" column-width="12cm"/>
    		
    		<fo:table-header font-size="8pt">
    			<fo:table-row>
    				<fo:table-cell><fo:block>Rennen</fo:block></fo:table-cell>
    				<fo:table-cell><fo:block></fo:block></fo:table-cell>
    				<fo:table-cell><fo:block>Meldungen</fo:block></fo:table-cell>
    			</fo:table-row>
    		</fo:table-header>
    		
    		<fo:table-body>
   				<xsl:apply-templates select="/data/Races/Race"/>
    		</fo:table-body>
    		
    	</fo:table>
	</xsl:template>
	
	<xsl:template match="Race">
		<xsl:variable name="rid" select="Offer_ID"/>
		<xsl:variable name="entries" select="/data/Entries/Entrie[Entry_Race_ID_FK = $rid]"/>

		<xsl:if test="count($entries) = 0 and Offer_Driven = 0">
			<fo:table-row>
				<fo:table-cell>
					<fo:block><xsl:value-of select="Offer_RaceNumber"/></fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:value-of select="Offer_ShortLabel"/>
						<xsl:text> </xsl:text>
						<xsl:value-of select="Offer_Comment"/>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:text>-</xsl:text>
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</xsl:if>

		<!-- todo: force driven beachten. -->
		<xsl:if test="count($entries) &gt; 0 and Offer_Driven = 0">
			<xsl:apply-templates select="/data/Stats/Stat[Race_ID = $rid and (Entries &lt; 2 or Clubs &lt; 2)]"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="Stat">
		<xsl:variable name="rid" select="Race_ID"/>
		<xsl:variable name="gv" select="GroupValue"/>
		<xsl:variable name="entries" select="/data/Entries/Entrie[Entry_Race_ID_FK = $rid and Entry_GroupValue = $gv]"/>
		<xsl:variable name="race" select="/data/Races/Race[Offer_ID = $rid]"/>
		
		<fo:table-row>
			<fo:table-cell>
				<fo:block><xsl:value-of select="$race/Offer_RaceNumber"/></fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="$race/Offer_ShortLabel"/>
					<xsl:if test="$race/Offer_GroupMode != 0">
						<xsl:text> (</xsl:text>
						<xsl:call-template name="GetShortGroupString">
							<xsl:with-param name="mode" select="$race/Offer_GroupMode"/>
							<xsl:with-param name="value" select="$gv"/>
						</xsl:call-template>
						<xsl:text>)</xsl:text>
					</xsl:if>
					<xsl:if test="$race/Offer_GroupMode = 0">
						<xsl:text> </xsl:text>
						<xsl:value-of select="$race/Offer_Comment"/>
					</xsl:if>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<xsl:for-each select="$entries">
					<fo:block>
						<xsl:call-template name="GetEntryLabel">
							<xsl:with-param name="entry" select="current()"/>
							<xsl:with-param name="short" select="true()"/>
							<xsl:with-param name="with-extra" select="false()"/>
						</xsl:call-template>
					</fo:block>
				</xsl:for-each>
				<xsl:if test="count($entries) = 0">
					<fo:block>
						<xsl:text>-</xsl:text>
					</fo:block>
				</xsl:if>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>

</xsl:stylesheet>
