<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:output method="xml" encoding="utf-8" version="1.0" omit-xml-declaration="no" indent="yes"/>
	
	<xsl:param name="vc_stat" select="/data/ReportOptions/ReportOption[Name='vc_stat']/Value"/>
	
	<xsl:key name="race_by_comp" match="VcStat" use="Offer_ID"/>

	<xsl:include href="./includes/standard.xsl"/>
	<xsl:include href="./includes/stats.xsl" />

	<xsl:template name="body">
		<fo:table table-layout="fixed" width="100%" font-size="10pt">
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<xsl:call-template name="overview"/>
					</fo:table-cell>
<!-- 						
					<fo:table-cell>
						<fo:block font-weight="bold">Einzugsbereich</fo:block>
						<fo:block border="medium solid black">
							<fo:external-graphic src="url('./images/vendor/germany.svg')" height="8cm" content-height="scale-to-fit"/>
						</fo:block>
					</fo:table-cell>
 -->					
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell>
						<xsl:call-template name="ceremony"/>
					</fo:table-cell>
					<fo:table-cell>
						<xsl:call-template name="boats"/>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		<xsl:call-template name="athletes_age_stats"/>
		<xsl:call-template name="clubs"/>
		<xsl:call-template name="athletes"/>
		<xsl:if test="$vc_stat = 1">
			<xsl:call-template name="vc_race_stat"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="overview">
		<fo:block font-weight="bold">Überblick</fo:block>
		<fo:table table-layout="fixed" width="100%" border="medium solid black" margin-top="0.25em">
			<fo:table-column column-number="1" column-width="7.5cm"/>
			<fo:table-column column-number="2" column-width="1.0cm"/>
			
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell padding-left=".25em"><fo:block>ausgeschriebene Rennen</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/RaceCount"/></fo:block></fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left=".25em"  padding-bottom="1em"><fo:block>davon vollständig nicht zu Stande gekommen</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/CancelledRaceCount"/></fo:block></fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left=".25em"><fo:block>Läufe</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/CompCount"/></fo:block></fo:table-cell>
				</fo:table-row>				
				<xsl:if test="(/data/Stats/Stat/RaceCount - /data/Stats/Stat/CancelledRaceCount) &gt; 0">
					<fo:table-row>
						<fo:table-cell padding-left=".25em"  padding-bottom="1em"><fo:block>Läufe je ausgetragenem Rennen</fo:block></fo:table-cell>
						<fo:table-cell padding-right=".25em">
							<fo:block text-align="right">
								<xsl:value-of select="round(/data/Stats/Stat/CompCount div (/data/Stats/Stat/RaceCount - /data/Stats/Stat/CancelledRaceCount)*10) div 10"/>
							</fo:block>
						</fo:table-cell>								
					</fo:table-row>
				</xsl:if>
				<fo:table-row>
					<fo:table-cell padding-left=".25em"><fo:block>Meldungen (Boote)</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/EntryCount"/></fo:block></fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left=".25em"><fo:block>Meldungen von Renngemeinschaften</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/EntryTeamCount"/></fo:block></fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left=".25em" padding-bottom="1em"><fo:block>Nennungen (Rollsitze)</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/OccupiedSeatsCount"/></fo:block></fo:table-cell>
				</fo:table-row>
				
				
				<fo:table-row>
					<fo:table-cell padding-left=".25em"><fo:block>meldende Vereine</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/EntryOwnerCount"/></fo:block></fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left=".25em"><fo:block>teilnehmende Vereine</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/AthleteClubCount"/></fo:block></fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell padding-left=".25em"><fo:block>teilnehmende Sportler</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/AthleteCount"/></fo:block></fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template name="ceremony">
		<fo:block font-weight="bold" margin-top="0.25em">Siegerehrung</fo:block>
		<fo:table table-layout="fixed" width="100%" border="medium solid black" margin-top="0.25em">
			<fo:table-column column-number="1" column-width="6.5cm"/>
			<fo:table-column column-number="2" column-width="2.0cm"/>
			
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell padding-left=".25em"><fo:block>A-Finalläufe/Abteilungen</fo:block></fo:table-cell>
					<fo:table-cell padding-right=".25em"><fo:block text-align="right"><xsl:value-of select="/data/Stats/Stat/CompFinalCount"/></fo:block></fo:table-cell>
				</fo:table-row>
				<xsl:call-template name="vcstat">
					<xsl:with-param name="rank" select="1"/>
				</xsl:call-template>
				<xsl:call-template name="vcstat">
					<xsl:with-param name="rank" select="2"/>
				</xsl:call-template>
				<xsl:call-template name="vcstat">
					<xsl:with-param name="rank" select="3"/>
				</xsl:call-template>
				<fo:table-row>
					<fo:table-cell padding="0.25em">
						<fo:block font-size="7pt">
							<xsl:text>Auf Grundlage des Meldeergebnisses/Zeitplans</xsl:text>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>				
		</fo:table>
	</xsl:template>
		
	<xsl:template name="vcstat">
		<xsl:param name="rank"/>
		<fo:table-row>
			<fo:table-cell padding-left=".25em">
				<fo:block>
					<xsl:value-of select="$rank"/>
					<xsl:text>. Platz (Boote / Ruderer u. St.)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell padding-right=".25em">
				<fo:block text-align="right">
					<xsl:value-of select="sum(/data/VcStats/VcStat[EntryCount &gt;= $rank]/CompCount)"/>
					<xsl:text> / </xsl:text>
					<xsl:value-of select="sum(/data/VcStats/VcStat[EntryCount &gt;= $rank]/WinRowers)"/>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>

	<xsl:template name="clubs">
		<fo:table table-layout="fixed" margin-top="0.5em" width="100%" font-size="10pt">
			<fo:table-column column-number="1" column-width="50%"/>
			<fo:table-column column-number="2" column-width="50%"/>
		
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<fo:block font-weight="bold"><xsl:text>Meiste Meldungen pro Verein</xsl:text></fo:block>
						<fo:block border="medium solid black" margin-right="0.5em">
							<xsl:apply-templates select="/data/TopEntryClubs"/>
						</fo:block>
					</fo:table-cell>
					
					<fo:table-cell>
						<fo:block font-weight="bold"><xsl:text>Meiste Ruderer pro Verein</xsl:text></fo:block>
						<fo:block border="medium solid black">
							<xsl:apply-templates select="/data/TopAthleteClubs"/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	
	<xsl:template match="TopEntryClubs|TopAthleteClubs">
		<xsl:if test="count(./*) &gt; 0">
			<fo:table table-layout="fixed" width="100%">
				<fo:table-column column-number="1" column-width="1cm"/>
				<fo:table-column column-number="2" column-width="6.5cm"/>
				<fo:table-column column-number="3" column-width="1.25cm"/>
			
				<fo:table-header>
					<fo:table-row font-size="8pt">
						<fo:table-cell><fo:block text-align="center">Rang</fo:block></fo:table-cell>
						<fo:table-cell><fo:block>Verein</fo:block></fo:table-cell>
						<fo:table-cell><fo:block text-align="center">Anzahl</fo:block></fo:table-cell>
					</fo:table-row>
				</fo:table-header>
			
				<fo:table-body>
					<xsl:for-each select="./*">
						<fo:table-row>
							<fo:table-cell><fo:block text-align="center"><xsl:value-of select="Rank"/></fo:block></fo:table-cell>
							<fo:table-cell>
								<fo:block-container overflow="hidden">
									<fo:block wrap-option="no-wrap">
										<xsl:value-of select="Club_Abbr"/>
									</fo:block>
								</fo:block-container>
							</fo:table-cell>
							<fo:table-cell><fo:block text-align="center"><xsl:value-of select="Cnt"/></fo:block></fo:table-cell>
						</fo:table-row>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="athletes">
	<!-- 
		<fo:table table-layout="fixed" margin-top="0.5em" width="100%" font-size="10pt">
			<fo:table-column column-number="1" column-width="50%"/>
			<fo:table-column column-number="2" column-width="50%"/>
		
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<fo:block font-weight="bold"><xsl:text>Meiste Starts (Männer)</xsl:text></fo:block>
						<fo:block border="medium solid black" margin-right="0.5em">
							
						</fo:block>
					</fo:table-cell>
					
					<fo:table-cell>
						<fo:block font-weight="bold"><xsl:text>Meiste Starts (Frauen)</xsl:text></fo:block>
						<fo:block border="medium solid black">
							
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	 -->	
	</xsl:template>

	<xsl:template name="vc_race_stat">
		<fo:block font-weight="bold" margin-top="0.5em">
			<fo:inline>Rennstatistik</fo:inline>
			<fo:inline font-size="8pt" font-weight="normal">(für zu Stande gekommene Rennen)</fo:inline>
		</fo:block>
		<fo:table table-layout="fixed" width="100%" font-size="10pt" border="medium solid black">
            <fo:table-column column-number="1" column-width="1.5cm"/>   
            <fo:table-column column-number="2" column-width="4cm"/>
            <fo:table-column column-number="3" column-width="2cm"/>
            <fo:table-column column-number="4" column-width="2cm"/>
            <fo:table-column column-number="5" column-width="2cm"/>		
			<fo:table-header margin="4pt">
				<fo:table-row font-size="8pt">
					<fo:table-cell><fo:block>RennNr</fo:block></fo:table-cell>
					<fo:table-cell><fo:block>Rennen</fo:block></fo:table-cell>
					<fo:table-cell><fo:block text-align="right">A-Finals/Abt.</fo:block></fo:table-cell>
					<fo:table-cell><fo:block text-align="right">Boote</fo:block></fo:table-cell>
					<fo:table-cell><fo:block text-align="right">Athleten</fo:block></fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body margin="4pt">
				<xsl:for-each select="/data/VcStats/VcStat[generate-id() = generate-id(key('race_by_comp', Offer_ID)[1])]">
				<xsl:variable name="rid" select="Offer_ID"/>
					<fo:table-row>
						<fo:table-cell><fo:block><xsl:value-of select="Offer_RaceNumber"/></fo:block></fo:table-cell>
						<fo:table-cell><fo:block><xsl:value-of select="Offer_ShortLabel"/></fo:block></fo:table-cell>
						<fo:table-cell><fo:block text-align="right"><xsl:value-of select="sum(/data/VcStats/VcStat[$rid = Offer_ID]/CompCount)"/></fo:block></fo:table-cell>
						<fo:table-cell><fo:block text-align="right"><xsl:value-of select="sum(/data/VcStats/VcStat[$rid = Offer_ID]/EntryCount)"/></fo:block></fo:table-cell>						
						<fo:table-cell><fo:block text-align="right"><xsl:value-of select="sum(/data/VcStats/VcStat[$rid = Offer_ID]/TotalRowers)"/></fo:block></fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
				<fo:table-row font-weight="bold" border-top="medium solid black">
					<fo:table-cell><fo:block/></fo:table-cell>
					<fo:table-cell><fo:block text-align="right">Summe</fo:block></fo:table-cell>
					<fo:table-cell><fo:block text-align="right"><xsl:value-of select="sum(/data/VcStats/VcStat/CompCount)"></xsl:value-of></fo:block></fo:table-cell>
					<fo:table-cell><fo:block text-align="right"><xsl:value-of select="sum(/data/VcStats/VcStat/EntryCount)"></xsl:value-of></fo:block></fo:table-cell>
					<fo:table-cell><fo:block text-align="right"><xsl:value-of select="sum(/data/VcStats/VcStat/TotalRowers)"></xsl:value-of></fo:block></fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>	
	</xsl:template>

	<xsl:template name="boats">
		<xsl:if test="sum(/data/BoatStats/BoatStat/Count) &gt; 0">
			<fo:block font-weight="bold" margin-top="0.25em" margin-bottom="0.25em">Meldezahlen nach Bootsklasse</fo:block>
			<fo:table table-layout="fixed" width="100%" font-size="10pt" border="medium solid black">
				<xsl:for-each select="/data/BoatStats/BoatStat">
					<fo:table-column/>
				</xsl:for-each>

				<fo:table-header>
					<fo:table-row>
						<xsl:for-each select="/data/BoatStats/BoatStat">
							<fo:table-cell>
								<fo:block text-align="center" margin="0.25em"><xsl:value-of select="Abbr"/></fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</fo:table-header>

				<fo:table-body>
					<fo:table-row margin-top="0.25em">
						<xsl:for-each select="/data/BoatStats/BoatStat">
							<fo:table-cell>
								<fo:block text-align="center" margin="0.25em"><xsl:value-of select="Count"/></fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>

					<fo:table-row>
						<fo:table-cell padding="0.25em">
							<xsl:attribute name="number-columns-spanned">
								<xsl:value-of select="count(/data/BoatStats/BoatStat)"/>
							</xsl:attribute>
							<fo:block font-size="7pt">
								<xsl:text>Unter Berücksichtigung ausgetragener Rennen und deren Meldungen</xsl:text>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-body>
			</fo:table>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
