<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:include href="./includes/standard.xsl"/>

	<xsl:template name="body">
		<xsl:for-each select="/data/Clubs/Club">
			<xsl:sort select="City"/>
			<xsl:sort select="Team" data-type="number"/>
			<xsl:sort select="Entry_ShortLabel"/>
			
			<xsl:variable name="sl" select="Entry_ShortLabel"/>
			<xsl:variable name="entries" select="/data/Entries/Entrie[Label_Short = $sl]"/>
			<xsl:variable name="numEntries" select="count($entries)"/>
			
			<fo:block font-weight="bold" keep-with-next="always">
				<xsl:value-of select="concat(City, ', ', Entry_ShortLabel)"></xsl:value-of>
			</fo:block>

			<fo:table width="100%" table-layout="fixed" font-size="11pt">			
				<fo:table-column column-number="1" column-width="50%"/>
				<fo:table-column column-number="2" column-width="50%"/>			

				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<xsl:apply-templates select="$entries">
								<xsl:with-param name="to" select="$numEntries div 2"/>
								<xsl:sort data-type="number" select="Entry_FullBib"/>
							</xsl:apply-templates>
							<fo:block/>
						</fo:table-cell>
				
						<fo:table-cell>
							<xsl:apply-templates select="$entries">
								<xsl:with-param name="from" select="$numEntries div 2"/>
								<xsl:sort data-type="number" select="Entry_FullBib"/>
							</xsl:apply-templates>
							<fo:block/>
						</fo:table-cell>
					</fo:table-row>
				
				</fo:table-body>
			</fo:table>
			
			<fo:block padding="0.5em"/>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="Entrie">
		<xsl:param name="from" select="0"/>
		<xsl:param name="to" select="9999"/>
		
		<xsl:variable name="rid" select="Entry_Race_ID_FK"/>
		
		<xsl:if test="position() - 1 &gt;= $from and position() - 1 &lt; $to">
			<fo:block keep-with-next="400">
				<xsl:text>Nr. </xsl:text>
				<xsl:value-of select="Entry_FullBib"/>
				<xsl:text>: </xsl:text>
				<xsl:apply-templates select="/data/Races/Race[Offer_ID = $rid]"/>
			</fo:block>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="Race">
		<xsl:text>Re. </xsl:text>
		<xsl:value-of select="Offer_RaceNumber"/>
		<xsl:text> - </xsl:text>
		<xsl:value-of select="normalize-space(concat(Offer_ShortLabel, ' ', Offer_Comment))"/>
	</xsl:template>

</xsl:stylesheet>
