<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:include href="./includes/standard.xsl"/>
	
	<xsl:param name="optSmallRaceCol" select="/data/ReportOptions/ReportOption[Name='pdf_small_race_col']/Value"/>
	<xsl:param name="optShowCity" select="/data/ReportOptions/ReportOption[Name='show_city']/Value"/>

	<xsl:template name="body">
		<fo:table width="100%" table-layout="fixed">
		
			<!-- Tabellenlayout:
				Spalte 1: laufende Nummer
				Spalte 2: (Ort) Verein/Renngemeinschaft
				Spalte 3: Rennen 
			 -->

			<fo:table-column column-number="1" column-width="5%"/>
			<xsl:if test="$optSmallRaceCol = 0">
				<fo:table-column column-number="2" column-width="40%"/>
				<fo:table-column column-number="3" column-width="55%"/>
			</xsl:if>
			<xsl:if test="$optSmallRaceCol = 1">
				<fo:table-column column-number="2" column-width="60%"/>
				<fo:table-column column-number="3" column-width="35%"/>
			</xsl:if>
			
			<fo:table-body font-size="11pt">
				<xsl:apply-templates select="/data/Clubs/Club[Team = 0]"/>
				<!-- and Abbr = Entry_ShortLabel = verhindert Ausgabe von Meldungen eines 
				     Vereins mit vollständig Fremden Vereinen -->
				<xsl:if test="count(/data/Clubs/Club[Team = 1]) &gt; 0">
					<xsl:apply-templates select="/data/Clubs/Club[Team = 1]">
						<xsl:with-param name="offset">
							<!-- see above -->
							<xsl:value-of select="count(/data/Clubs/Club[Team = 0])"/>
						</xsl:with-param>
					</xsl:apply-templates>
				</xsl:if>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	
	<xsl:template match="Club">
		<xsl:param name="offset" select="number(0)"/>
		<fo:table-row>
			<xsl:variable name="label" select="Entry_LongLabel"/>
			<xsl:variable name="short_label" select="Entry_ShortLabel"/>
			
			<!-- Fortlaufende Nummer -->
			<fo:table-cell>
				<fo:block text-align="right">
					<xsl:value-of select="position() + $offset"/>
				</fo:block>
			</fo:table-cell>
			
			<!-- Label (Verein/Rgm.) -->
			<fo:table-cell padding-left="0.5em">
				<fo:block>
					<xsl:if test="$show_noc">
						<xsl:value-of select="Nation_IOC_Code"/>
						<xsl:text> </xsl:text>
					</xsl:if>
					<xsl:if test="$optShowCity = 1">
						<xsl:value-of select="City"/>
						<xsl:text>, </xsl:text>
					</xsl:if>
					<xsl:if test="Team = 0">
						<xsl:value-of select="$label"/>
					</xsl:if>
					<xsl:if test="Team = 1">
						<xsl:value-of select="$short_label"/>
					</xsl:if>
				</fo:block>
			</fo:table-cell>
			
			<!-- Rennen -->						
			<fo:table-cell padding-left="0.5em">
				<fo:block>
					<xsl:for-each select="/data/Entries/Entrie[Label_Short=$short_label]">
						<xsl:variable name="oid" select="Entry_Race_ID_FK"/>
						<xsl:variable name="race" select="/data/Races/Race[Offer_ID = $oid]"/>
						
						<xsl:if test="$race/Offer_Driven=1">
							<xsl:value-of select="$race/Offer_RaceNumber"/>
						</xsl:if>
						
						<xsl:if test="$race/Offer_Driven=0">
							(<xsl:value-of select="$race/Offer_RaceNumber"/>)
						</xsl:if>
						
						<xsl:if test="position() != last()">
							<xsl:text>, </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</fo:block>	
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>


</xsl:stylesheet>
