<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:param name="show_all_comps" select="boolean(/data/ReportOptions/ReportOption[Name='show_all_comps']/Value = 1)"/>
    <xsl:param name="show_distance" select="boolean(/data/ReportOptions/ReportOption[Name='show_distance']/Value = 1)"/>

    <xsl:include href="./includes/standard.xsl"/>

    <xsl:template name="body">
	    <xsl:variable name="has_heats" select="boolean(count(/data/Comps/Comp[Round = 4 and Cancelled = 0]))"/>
	    <xsl:variable name="has_quarterfinals" select="boolean(count(/data/Comps/Comp[Round = 8 and Cancelled = 0]))"/>
	    <xsl:variable name="has_repechages" select="boolean(count(/data/Comps/Comp[Round = 16 and Cancelled = 0]))"/>
	    <xsl:variable name="has_semifinals" select="boolean(count(/data/Comps/Comp[Round = 32 and Cancelled = 0]))"/>

	    <fo:table width="100%" table-layout="auto" font-size="9.25pt">
            <fo:table-column column-width="1cm"/>
			<fo:table-column column-width="proportional-column-width(1)"/>
			<fo:table-column column-width="1.1cm"/>
			<xsl:if test="$has_heats"><fo:table-column column-width="2.3cm"/></xsl:if>
			<xsl:if test="$has_quarterfinals"><fo:table-column column-width="2.3cm"/></xsl:if>
			<xsl:if test="$has_repechages"><fo:table-column column-width="2.3cm"/></xsl:if>
			<xsl:if test="$has_semifinals"><fo:table-column column-width="2.3cm"/></xsl:if>
            <fo:table-column column-width="2.3cm"/>
            		<xsl:if test="$show_distance"><fo:table-column column-width="1.5cm"/></xsl:if>
            
            <fo:table-header font-weight="bold">
                <fo:table-row border="medium solid black" font-size="9pt">
                    <fo:table-cell border="medium solid black" padding="0.25em"><fo:block text-align="center">RNr</fo:block></fo:table-cell>
					<fo:table-cell border="medium solid black" padding="0.25em"><fo:block text-align="left">Rennen</fo:block></fo:table-cell>
					<fo:table-cell border="medium solid black" padding="0.25em"><fo:block text-align="center">Boote</fo:block></fo:table-cell>
					<xsl:if test="$has_heats">
						<fo:table-cell border="medium solid black" padding="0.25em">
							<fo:block text-align="center">
								<xsl:if test="count(/data/Comps/Comp[Round = 4 and RoundCode='V']) &gt; 0">
									<xsl:text>Vorlauf</xsl:text>
								</xsl:if>
								<xsl:if test="count(/data/Comps/Comp[Round = 4 and RoundCode='X']) &gt; 0">
									<xsl:if test="count(/data/Comps/Comp[Round = 4 and RoundCode='V']) &gt; 0">
										<xsl:text>/</xsl:text>
									</xsl:if>
									<fo:block text-align="center">Bahnvert.*</fo:block>
								</xsl:if>
								<xsl:if test="count(/data/Comps/Comp[Round = 4 and RoundCode='LS']) &gt; 0">
									<xsl:text>Langstrecke</xsl:text>
								</xsl:if>
							</fo:block>
						</fo:table-cell>
					</xsl:if>
                    <xsl:if test="$has_repechages"><fo:table-cell border="medium solid black" padding="0.25em"><fo:block text-align="center">Hoffnungslauf</fo:block></fo:table-cell></xsl:if>
                    <xsl:if test="$has_quarterfinals"><fo:table-cell border="medium solid black" padding="0.25em"><fo:block text-align="center">Viertelfinale</fo:block></fo:table-cell></xsl:if>
		    <xsl:if test="$has_semifinals">
			    <fo:table-cell border="medium solid black" padding="0.25em">
				    <fo:block text-align="center">
					    <xsl:if test="count(/data/Comps/Comp[Round = 32 and RoundCode = 'Z' and Cancelled = 0]) &gt; 0">
						<xsl:text>Zwischen-lauf</xsl:text>
					    </xsl:if>
					    <xsl:if test="count(/data/Comps/Comp[Round = 32 and (RoundCode = 'HF' or RoundCode = 'S') and Cancelled = 0]) &gt; 0">
					    	<xsl:text>Halbfinale</xsl:text>
					    </xsl:if>
				    </fo:block>
			    </fo:table-cell>
		    </xsl:if>
		    <fo:table-cell border="medium solid black" padding="0.25em">
			    <fo:block text-align="center">
				<xsl:choose>
					<xsl:when test="count(/data/Comps/Comp[Round = 64 and RoundCode = 'F' and Cancelled = 0]) &gt; 0">
						<xsl:text>Finale</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$default_finalround_caption"/>
					</xsl:otherwise>
				</xsl:choose>
			    </fo:block>
		    	</fo:table-cell>
			<xsl:if test="$show_distance">
				<fo:table-cell border="medium solid black" padding="0.25em"><fo:block text-align="center">Strecke</fo:block></fo:table-cell>
			</xsl:if>
                </fo:table-row>
				<fo:table-row>
					<fo:table-cell padding="0.25em">
						<fo:block></fo:block>
					</fo:table-cell>
				</fo:table-row>
            </fo:table-header>
		
			<fo:table-body>
				<xsl:for-each select="/data/Races/Race[Offer_Driven = 1 and Offer_Cancelled = 0]">
					<fo:table-row border="medium solid black" keep-together.within-column="1">
						<fo:table-cell padding="0.25em" border-right="medium solid black">
							<fo:block text-align="center"><xsl:value-of select="Offer_RaceNumber"/></fo:block>
						</fo:table-cell>
						<fo:table-cell padding="0.25em">
							<fo:block text-align="left">
								<xsl:value-of select="Offer_ShortLabel"/>
								<xsl:text> </xsl:text>
								<xsl:value-of select="Offer_Comment"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell border="medium solid black" padding="0.25em">
							<fo:block text-align="center">
								<xsl:value-of select="/data/EntryCounts/EntryCount[Race_ID = current()/Offer_ID]/Entry_Count - /data/EntryCounts/EntryCount[Race_ID = current()/Offer_ID]/Cancel_Count"/>
							</fo:block>
						</fo:table-cell>
						<xsl:if test="$has_heats">
							<xsl:call-template name="raceRoundSchedule">
								<xsl:with-param name="round" select="4"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="$has_repechages">
							<xsl:call-template name="raceRoundSchedule">
								<xsl:with-param name="round" select="16"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="$has_quarterfinals">
							<xsl:call-template name="raceRoundSchedule">
								<xsl:with-param name="round" select="8"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="$has_semifinals">
							<xsl:call-template name="raceRoundSchedule">
								<xsl:with-param name="round" select="32"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:call-template name="raceRoundSchedule">
							<xsl:with-param name="round" select="64"/>
						</xsl:call-template>
						<xsl:if test="$show_distance">
							<fo:table-cell border="medium solid black" padding="0.25em">
								<fo:block text-align="right">
									<xsl:value-of select="Offer_Distance"/>
									<xsl:text> m</xsl:text>
								</fo:block>
							</fo:table-cell>
						</xsl:if>
					</fo:table-row>            			
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
    </xsl:template>

	<xsl:template name="raceRoundSchedule">
		<xsl:param name="round"/>

		<xsl:if test="boolean($show_all_comps) = true()">
			<xsl:variable name="rid" select="Offer_ID"/>

			<fo:table-cell border-left="medium solid black" padding="0.25em">
				<fo:block>
					<xsl:apply-templates select="/data/Comps/Comp[Race_ID_FK = $rid and Round = $round and string-length(WeekDay) &gt; 0 and Cancelled = 0]" mode="list-item">
						<xsl:sort select="HeatNumber" data-type="number"/>
					</xsl:apply-templates>
				</fo:block>
			</fo:table-cell>
		</xsl:if>

		<xsl:if test="boolean($show_all_comps) = false()">
			<xsl:call-template name="raceRound1stComp">
				<xsl:with-param name="round" select="$round"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
    
    <xsl:template name="raceRound1stComp">
    	<xsl:param name="round"/>
    	<xsl:variable name="rid" select="Offer_ID"/>
    	<xsl:variable name="comps" select="/data/Comps/Comp[Race_ID_FK = $rid and Round= $round and string-length(WeekDay) &gt; 0 and Cancelled = 0]"/>
    	<xsl:variable name="comp" select="$comps[1]"/>
    	
    	<fo:table-cell border-left="medium solid black" padding="0.25em">
    		<fo:block text-align="center">
				<xsl:if test="$comp">
					<xsl:apply-templates select="$comp" mode="date-string"/>
					<fo:inline color="gray">
						<xsl:text> (</xsl:text>
						<xsl:value-of select="count($comps)" />
						<xsl:text>)</xsl:text>	
					</fo:inline>
				</xsl:if>
    		</fo:block>
    	</fo:table-cell>
    </xsl:template>

	<xsl:template match="Comp" mode="list-item">
		<fo:block text-align="right">
			<xsl:if test="position() &gt; 1">
				<xsl:attribute name="keep-with-previous">always</xsl:attribute>
			</xsl:if>
			<xsl:if test="string-length(Label) &gt; 0">
				<fo:inline>
					(<xsl:value-of select="Label"/>)
				</fo:inline>
			</xsl:if>
			<xsl:apply-templates select="current()" mode="date-string"/>
		</fo:block>
	</xsl:template>

	<xsl:template match="Comp" mode="date-string">
		<fo:inline text-transform="uppercase">
			<xsl:call-template name="GetShortWeekDay">
				<xsl:with-param name="day" select="WeekDay" />
			</xsl:call-template>
		</fo:inline>
		<xsl:text> </xsl:text>
		<xsl:value-of select="format-number(Hour, '00')" />
		<xsl:text>:</xsl:text>
		<xsl:value-of select="format-number(Minute, '00')" />
		<xsl:if test="Round = 4 and RoundCode = 'X'">
			<xsl:text>*</xsl:text>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
