<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:include href="./includes/standard.xsl"/>

    <xsl:template name="body">
        <fo:table width="100%" table-layout="fixed" border="medium solid black">
        
            <!-- Tabellenlayout:
                Spalte 1: Zeit
                Spalte 2-4: REnnen (Nummer, Kurz, Lang)
                Spalte 5: Strecke 
             -->

            <fo:table-column column-number="1" column-width="1.5cm"/>   
            <fo:table-column column-number="2" column-width="1.5cm"/>
            <fo:table-column column-number="3" column-width="5cm"/>
            <fo:table-column column-number="4" column-width="8cm"/>
            <fo:table-column column-number="5" column-width="2cm"/>
            
            <fo:table-header border-bottom="medium solid black" margin-bottom="1em">
                <fo:table-row font-size="8pt">
                    <fo:table-cell padding-end="6pt"><fo:block text-align="right">Zeit</fo:block></fo:table-cell>
                    <fo:table-cell><fo:block/></fo:table-cell>
                    <fo:table-cell padding-start="6pt" number-columns-spanned="2"><fo:block>Rennen</fo:block></fo:table-cell>
                    <fo:table-cell padding-end="6pt"><fo:block text-align="right">Strecke</fo:block></fo:table-cell>
                </fo:table-row>
            </fo:table-header>
            
            <fo:table-body font-size="11">
                <xsl:for-each select="/data/Comps/Comp[Cancelled = 0]">
                    <xsl:variable name="race_fk" select="Race_ID_FK"/>
                    <xsl:variable name="prev_comp" select="preceding-sibling::Comp[1]"/>

                    <!-- skip consecutive comps the same race -->
                    <xsl:if test="Dummy = 0 and number($prev_comp/Race_ID_FK) != number($race_fk)">
                        <xsl:variable name="race" select="/data/Races/Race[Offer_ID=$race_fk]"/>
                        <fo:table-row>
                            <fo:table-cell padding-end="6pt" border-right="medium solid black">
                                <fo:block text-align="right">
                                    <xsl:number value="Hour" format="1"></xsl:number>
                                    <xsl:text>:</xsl:text>
                                    <xsl:if test="Minute &lt; 10"><xsl:text>0</xsl:text></xsl:if>
                                    <xsl:value-of select="Minute"/>
                                </fo:block>
                            </fo:table-cell>
                            
                            <fo:table-cell padding-end="6pt" border-right="medium solid black">
                                <fo:block text-align="right">
                                    <xsl:value-of select="$race/Offer_RaceNumber"/>
                                </fo:block>
                            </fo:table-cell>
                            
			    <fo:table-cell padding-start="6pt">
				<fo:block-container overflow="hidden">
                               	    <fo:block wrap-option="no-wrap">
                                        <xsl:value-of select="$race/Offer_ShortLabel"/>
                                        <xsl:text> </xsl:text>
                                        <xsl:value-of select="$race/Offer_Comment"/>
				    </fo:block>
			        </fo:block-container>
                            </fo:table-cell>
                            
                            <fo:table-cell>
				<fo:block-container overflow="hidden">
                                    <fo:block wrap-option="no-wrap">
                                        <xsl:value-of select="$race/Offer_LongLabel"/>
                                        <xsl:text> </xsl:text>
                                        <xsl:value-of select="$race/Offer_Comment"/>
                                    </fo:block>
		                </fo:block-container>
                            </fo:table-cell>
                            
                            <fo:table-cell padding-end="6pt">
                                <fo:block text-align="right">
                                    <!-- use comp's distance -->
                                    <xsl:value-of select="Distance"/>
                                    <xsl:text> m</xsl:text>
                                </fo:block>
                            </fo:table-cell>
                            
                        </fo:table-row>
                    </xsl:if>
                    
                    <xsl:if test="Dummy = 1">
                        <fo:table-row keep-with-previous="always">
                            <fo:table-cell border-right="medium solid black"><fo:block/></fo:table-cell>
                            <fo:table-cell border-right="medium solid black"><fo:block/></fo:table-cell>
                            <fo:table-cell padding-before="0.25em" padding-after="0.25em" padding-start="6pt" number-columns-spanned="3">
                                <fo:block>
                                    <xsl:value-of select="Label"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:if>
                </xsl:for-each>
            </fo:table-body>
            
        </fo:table>
    </xsl:template>
    
</xsl:stylesheet>
