<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:include href="./includes/standard.xsl"/>

    <xsl:param name="with_event" select="false()"/>

    <xsl:template name="body">
        <fo:table width="100%" table-layout="fixed" border="medium solid black" font-size="9.25pt">
        
            <!-- Tabellenlayout:
                Spalte 1: Zeit
                Spalte 2: LaufNr.
                Spalte 3-5: REnnen (Nummer, Kurz, Lang)
                Spalte 6: Lauftyp
                Spalte 7: Strecke 
             -->

            <fo:table-column column-width="1.25cm"/>
            <xsl:if test="boolean($with_event)">
                <fo:table-column column-width="1.5cm"/>
            </xsl:if>
            <fo:table-column column-width="1cm"/>
            <fo:table-column column-width="1cm"/>
            <fo:table-column column-width="3.5cm"/>
            <fo:table-column column-width="5.5cm"/>
            <xsl:if test="boolean($with_event)">
                <fo:table-column column-width="2.75cm"/>
            </xsl:if>
            <xsl:if test="not(boolean($with_event))">
                <fo:table-column column-width="4.25cm"/>
            </xsl:if>
            <fo:table-column column-width="1.5cm"/>
            
            <fo:table-header border="medium solid black">
                <fo:table-row font-size="8pt">
                    <fo:table-cell border-right="medium solid black"><fo:block text-align="center">Zeit</fo:block></fo:table-cell>
                    <xsl:if test="boolean($with_event)">
                        <fo:table-cell border-right="medium solid black"><fo:block text-align="center">Ver.</fo:block></fo:table-cell>
                    </xsl:if>
                    <fo:table-cell border-right="medium solid black"><fo:block text-align="center">Lauf</fo:block></fo:table-cell>
                    <fo:table-cell padding-start="6pt" border-right="medium solid black" number-columns-spanned="3"><fo:block>Rennen</fo:block></fo:table-cell>
                    <fo:table-cell padding-start="3pt" border-right="medium solid black"><fo:block text-align="left">Lauf</fo:block></fo:table-cell>
                    <fo:table-cell><fo:block text-align="center">Strecke</fo:block></fo:table-cell>
                </fo:table-row>
            </fo:table-header>
                      
            <fo:table-body font-size="10">
                <xsl:for-each select="/data/Comps/Comp">
                    <xsl:variable name="race_fk" select="Race_ID_FK"/>
                    <xsl:variable name="prev_comp" select="preceding-sibling::Comp[1]"/>
                    <xsl:variable name="new_race" select="number($prev_comp/Race_ID_FK) != number($race_fk)"/>

                    <xsl:if test="Dummy = 0">
                        <xsl:variable name="race" select="/data/Races/Race[Offer_ID=$race_fk]"/>
                        <fo:table-row>
                            <fo:table-cell padding-end="6pt" border-right="medium solid black">
                                <fo:block text-align="right">
                                    <xsl:if test="./Cancelled = 0">
                                        <xsl:number value="Hour" format="1"></xsl:number>
                                        <xsl:text>:</xsl:text>
                                        <xsl:if test="Minute &lt; 10"><xsl:text>0</xsl:text></xsl:if>
                                        <xsl:value-of select="Minute"/>
                                    </xsl:if>
                                    <xsl:if test="./Cancelled = 1">
                                        <xsl:text>gestr.</xsl:text>
                                    </xsl:if>
                                </fo:block>
                            </fo:table-cell>

                            <xsl:if test="boolean($with_event)">
                            <fo:table-cell padding-end="6pt" border-right="medium solid black">
                                <fo:block text-align="right">
				    <xsl:apply-templates select="current()" mode="event_code"/>
                                </fo:block>
                            </fo:table-cell>
                            </xsl:if>

                            <fo:table-cell padding-end="6pt" border-right="medium solid black">
                                <fo:block text-align="right" color="silver">
                                    <xsl:value-of select="./Number"/>
                                </fo:block>
                            </fo:table-cell>
                            
                            <fo:table-cell padding-start="6pt">
                                <fo:block text-align="right">
                                    <xsl:if test="$new_race or true()">
                                        <xsl:value-of select="$race/Offer_RaceNumber"/>
                                    </xsl:if>
                                    <xsl:if test="not($new_race) and false()">
                                        <fo:inline color="silver">
                                       	    <xsl:text>...</xsl:text>
                                       	</fo:inline>
                                    </xsl:if>
                                </fo:block>
                            </fo:table-cell>
                            
                            <fo:table-cell padding-start="12pt">
                                <fo:block-container overflow="hidden">
                                    <fo:block wrap-option="no-wrap">
                                        <xsl:if test="$new_race or true()">
                                            <xsl:value-of select="$race/Offer_ShortLabel"/>
                                            <xsl:text> </xsl:text>
                                            <xsl:value-of select="$race/Offer_Comment"/>
                                        </xsl:if>
                                        <xsl:if test="not($new_race) and false()">
                                            <fo:inline color="silver">
                                                <xsl:text>...</xsl:text>
                                            </fo:inline>
                                        </xsl:if>
                                    </fo:block>
                                </fo:block-container>
                            </fo:table-cell>
                            
                            <fo:table-cell padding-end="3pt" border-right="medium solid black">
                                <fo:block-container overflow="hidden">                          
                                    <fo:block wrap-option="no-wrap">
                                        <xsl:if test="$new_race or true()">
                                            <xsl:value-of select="$race/Offer_LongLabel"/>
                                            <xsl:text> </xsl:text>
                                            <xsl:value-of select="$race/Offer_Comment"/>                                    
                                        </xsl:if>
                                        <xsl:if test="not($new_race) and false()">
                                            <fo:inline color="silver">
                                                <xsl:text>...</xsl:text>
                                            </fo:inline>
                                        </xsl:if>                                    
                                    </fo:block>
                                </fo:block-container>
                            </fo:table-cell>
                            
                            <fo:table-cell padding-start="3pt" border-right="medium solid black">
                                <fo:block>
                                    <xsl:apply-templates select="." mode="GetLongCompCaption"/>
	                                <xsl:text> </xsl:text>
	                                <xsl:if test="$race/Offer_GroupMode != 0">
	                                    <xsl:text> </xsl:text>
                                            <xsl:call-template name="GetAbbrGroupString">
                                                <xsl:with-param name="mode" select="$race/Offer_GroupMode"/>
                                                <xsl:with-param name="value" select="GroupValue"/>
                                            </xsl:call-template>
					</xsl:if>
                                </fo:block>
                            </fo:table-cell>
                            
                            <fo:table-cell padding-end="3pt">
                                <fo:block text-align="right">
                                    <!-- use comp's distance -->
                                    <xsl:value-of select="Distance"/>
                                    <xsl:text> m</xsl:text>
                                </fo:block>
                            </fo:table-cell>
                            
                        </fo:table-row>
                    </xsl:if>
                    
                    <xsl:if test="Dummy = 1">
                        <fo:table-row keep-with-previous="always">
                            <fo:table-cell border-right="medium solid black"><fo:block/></fo:table-cell>
                            <fo:table-cell border-right="medium solid black"><fo:block/></fo:table-cell>
                            <xsl:if test="boolean($with_event)">
                                <fo:table-cell border-right="medium solid black"><fo:block/></fo:table-cell>
                            </xsl:if>
                            <fo:table-cell padding-before="0.5em" padding-after="0.5em" padding-start="6pt" number-columns-spanned="3" border-right="medium solid black">
                                <fo:block font-weight="bold">
                                    <xsl:value-of select="Label"/>
                                </fo:block>
                            </fo:table-cell>
                            <fo:table-cell border-right="medium solid black"><fo:block/></fo:table-cell>
                            <fo:table-cell border-right="medium solid black"><fo:block/></fo:table-cell>
                        </fo:table-row>
                    </xsl:if>
                </xsl:for-each>
            </fo:table-body>
                        
        </fo:table>
       
    </xsl:template>

    <xsl:template match="Comp" mode="event_code" priority="5">
       <xsl:text>?</xsl:text>
    </xsl:template>
    
</xsl:stylesheet>
