<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	
	<xsl:include href="./includes/standard.xsl" />
	<xsl:include href="./../INC/rowing_result.xsl" />
	<xsl:include href="./includes/full_event_result.xsl" />
	<xsl:include href="./includes/bookmarktree.xsl" />
	<xsl:include href="./includes/stats.xsl" />

	<xsl:param name="hide_stats" select="boolean(/data/ReportOptions/ReportOption[Name='hide_stats']/Value = 1)"/>
	
	<xsl:template name="body">
		<xsl:call-template name="full_result"/>
		<xsl:if test="not($hide_stats)">
			<fo:block font-weight="bold" margin-top="0.5em" id="eventStats">Statistik</fo:block>
			<xsl:call-template name="athletes_age_stats"/>
			<xsl:call-template name="top_results"/>
		</xsl:if>
	</xsl:template>
		
	<!-- Spitzenvereine/Athleten -->
	<xsl:template name="top_results">
		<fo:table table-layout="fixed" margin-top="0.5em" width="100%" font-size="10pt">
			<fo:table-column column-number="1" column-width="50%"/>
			<fo:table-column column-number="2" column-width="50%"/>
		
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<fo:block font-weight="bold">
							<xsl:text>Erfolgreichste Vereine</xsl:text>
							<fo:inline font-weight="normal" font-size="8pt">	
								<xsl:text> (inkl. Siege in Rgm.)</xsl:text>
							</fo:inline>
						</fo:block>
						<fo:block keep-with-previous="always" border="medium solid black" margin-right="0.5em">
							<xsl:apply-templates select="/data/TopClubs"/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	
	<xsl:template match="TopClubs">
		<fo:table table-layout="fixed" width="100%">
			<fo:table-column column-number="1" column-width="1cm"/>
			<fo:table-column column-number="2" column-width="6.5cm"/>
			<fo:table-column column-number="3" column-width="1cm"/>

			<fo:table-header>
				<fo:table-row font-size="8pt">
					<fo:table-cell><fo:block text-align="center">Rang</fo:block></fo:table-cell>
					<fo:table-cell><fo:block>Verein</fo:block></fo:table-cell>
					<fo:table-cell><fo:block text-align="right">Siege</fo:block></fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			
			<fo:table-body>
				<xsl:for-each select="TopClub[WinRank &lt; 6]">
					<fo:table-row>
						<fo:table-cell>
							<fo:block text-align="center">
								<xsl:value-of select="WinRank"></xsl:value-of>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="Club_Abbr"></xsl:value-of>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block text-align="right">
								<xsl:value-of select="WinCount"></xsl:value-of>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
			
		</fo:table>		
	</xsl:template>
	
	<xsl:template name="top_athlets">
		<xsl:param name="aths"/>
		
		<fo:table table-layout="fixed" width="100%">
			<fo:table-column column-number="1" column-width="1cm"/>
			<fo:table-column column-number="2" column-width="6.5cm"/>
			<fo:table-column column-number="3" column-width="1cm"/>
			
			<fo:table-header>
				<fo:table-row font-size="8pt">
					<fo:table-cell><fo:block text-align="center">Rang</fo:block></fo:table-cell>
					<fo:table-cell><fo:block>Ruderer</fo:block></fo:table-cell>
					<fo:table-cell><fo:block text-align="right">Siege</fo:block></fo:table-cell>
				</fo:table-row>
			</fo:table-header>
			
			<fo:table-body>
				<xsl:for-each select="$aths/*">
					<fo:table-row>
						<fo:table-cell>
							<fo:block text-align="center">
								<xsl:value-of select="./WinRank"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block>
								<xsl:value-of select="./Athlet_FirstName"/>
								<xsl:text> </xsl:text>
								<xsl:value-of select="./Athlet_LastName"/>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block text-align="right">
								<xsl:value-of select="./WinCount"/>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	

	<xsl:template match="/data" mode="bookmarktree" priority="9">
		<fo:bookmark-tree>
			<fo:bookmark internal-destination="bodyHeadAnchor">
				<fo:bookmark-title>Rennergebnisse</fo:bookmark-title>
				<xsl:call-template name="RaceAndCompBookMarkTree">
					<xsl:with-param name="races" select="/data/Races/Race[Offer_Driven = 1]"/>		
				</xsl:call-template>
			</fo:bookmark>
			<fo:bookmark internal-destination="raceScratches">
				<fo:bookmark-title>ausgefallene Rennen</fo:bookmark-title>
			</fo:bookmark>
			<fo:bookmark internal-destination="eventReferees">
				<fo:bookmark-title>Wettkampfrichter</fo:bookmark-title>
			</fo:bookmark>
			<xsl:if test="not($hide_stats)">
				<fo:bookmark internal-destination="eventStats">
					<fo:bookmark-title>Statistik</fo:bookmark-title>
				</fo:bookmark>
			</xsl:if>
		</fo:bookmark-tree>
	</xsl:template>

</xsl:stylesheet>
