<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	
	<xsl:param name="force_landscape" select="boolean(/data/ReportOptions/ReportOption[Name='force_landscape']/Value = 1)"/>
	<xsl:param name="force_portrait" select="false()"/>
	<xsl:param name="num_splits" select="number(concat('0', /data/RaceInfo/RaceInfo/Offer_Splits))"/>
	<xsl:param name="landscape" select="($num_splits &gt; 0 or $force_landscape) and not($force_portrait)"/>

	<xsl:variable name="use_small_font">
		<xsl:value-of select="$force_portrait"/>
	</xsl:variable>

	<xsl:variable name="scale_factor">
		<xsl:choose>
			<xsl:when test="$use_small_font">
				<xsl:value-of select="number(0.8125)"/>
				<xsl:comment>Bla</xsl:comment>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="number(1.0)"/>
				<xsl:comment>Blub</xsl:comment>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<!-- in cm -->
	<xsl:param name="suppl_col_width" select="number(1.0) * $scale_factor"/>

	<xsl:param name="main_col_width">
		<xsl:choose>
			<xsl:when test="$landscape">
				<xsl:value-of select="27.0"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="18.0"/>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:param>
	
	<xsl:include href="./includes/standard.xsl" />
	<xsl:include href="./../INC/rowing_result.xsl"/>
	
	<xsl:template match="/data" mode="pageformat" priority="9">
		<xsl:if test="$landscape">
			<xsl:text>A4-landscape</xsl:text>
		</xsl:if>
		<xsl:if test="not($landscape)">
			<xsl:text>A4-portrait</xsl:text>
		</xsl:if>
	</xsl:template>	
	
	<xsl:template name="body">
		<xsl:variable name="cid" select="/data/Comps/Comp/ID" />
		<xsl:variable name="results" select="/data/Results/Result[SplitNr = 64]"/>
		<xsl:variable name="referees" select="/data/CompReferees/CompReferee"/>
		<xsl:variable name="split_col_width">
			<xsl:if test="count($results) &gt; 9">2.85</xsl:if>
			<xsl:if test="count($results) &lt; 10">2.55</xsl:if>
		</xsl:variable>

		<xsl:if test="count(/data/CompInfo/CompInfo)">
			<xsl:call-template name="large-header"/>
		</xsl:if>

		<xsl:if test="string-length(/data/RaceInfo/RaceInfo/Offer_Prize) &gt; 0">
			<fo:block margin-bottom="4pt" border="medium solid black">
				<fo:block font-weight="bold" font-size="16pt" text-align="center" padding="4pt">
					<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_Prize"/>
				</fo:block>
			</fo:block>
		</xsl:if>
		
		<!--
			table layout 
			col 1: rank 
			col 2: lane 
			col 3: bib 
			col 4: boat + crew
			(col 5 + n splits)
		-->
		<xsl:if test="count($results) &gt; 0">
			<fo:table width="100%" table-layout="fixed">
			
				<fo:table-column><xsl:attribute name="column-width"><xsl:value-of select="$suppl_col_width"/>cm</xsl:attribute></fo:table-column>
				<fo:table-column><xsl:attribute name="column-width"><xsl:value-of select="$suppl_col_width"/>cm</xsl:attribute></fo:table-column>
				<fo:table-column><xsl:attribute name="column-width"><xsl:value-of select="$suppl_col_width"/>cm</xsl:attribute></fo:table-column>

				<fo:table-column> 
					<xsl:attribute name="column-width" >
						<xsl:value-of select="$main_col_width - (3 * $suppl_col_width + (1 + $num_splits) * $split_col_width * $scale_factor)"/>
						<xsl:text>cm</xsl:text>
					</xsl:attribute>
				</fo:table-column>
				
				<xsl:call-template name="splitColumns">
					<xsl:with-param name="split_col_width" select="$split_col_width * $scale_factor"/>
				</xsl:call-template>
 
				<fo:table-column>
					<xsl:attribute name="column-width">
						<xsl:value-of select="$split_col_width * $scale_factor"/>
						<xsl:text>cm</xsl:text>
					</xsl:attribute>
					<!--
					<xsl:attribute name="column-number">
						<xsl:value-of select="4 + $num_splits + 1"/>
					</xsl:attribute>
					-->
				</fo:table-column>
				
				<fo:table-header font-size="8pt">
					<fo:table-row font-weight="bold">
						<fo:table-cell border="medium solid black" padding-top=".5em" padding-bottom=".5em">
							<fo:block text-align="center">Rang</fo:block>
						</fo:table-cell>
						<fo:table-cell border="medium solid black" padding-top=".5em" padding-bottom=".5em">
							<fo:block text-align="center">Bahn</fo:block>
						</fo:table-cell>
						<fo:table-cell border="medium solid black" padding-top=".5em" padding-bottom=".5em">
							<fo:block text-align="center">StNr.</fo:block>
						</fo:table-cell>
						<fo:table-cell border="medium solid black" padding=".5em">
							<fo:block>Boot/Mannschaft</fo:block>
						</fo:table-cell>
						
						<xsl:call-template name="splitHeaders"/>
						
						<fo:table-cell border="medium solid black" padding=".5em">
							<fo:block text-align="right">Ziel</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<!-- spacer -->
					<fo:table-row>
						<fo:table-cell padding=".25em">
							<fo:block></fo:block>
						</fo:table-cell>
					</fo:table-row>
				</fo:table-header>
				
				<fo:table-body>
					<xsl:call-template name="adjust_font_size"/>

					<xsl:apply-templates select="$results">
						<xsl:sort select="SortValue" data-type="number"/>
					</xsl:apply-templates>
				</fo:table-body>
			</fo:table>
			
			<xsl:if test="string-length(normalize-space(/data/CompInfo/CompInfo/Comp_RuleText)) &gt; 0 and $show_qrule">
				<fo:block border="medium solid black" margin="0.25em 0" padding="0.25em" font-size="8pt">
					<xsl:call-template name="adjust_font_size"/>

					<fo:inline font-weight="bold">
						<xsl:text>Qualifikation: </xsl:text>
					</fo:inline>
					<xsl:value-of select="/data/CompInfo/CompInfo/Comp_RuleText"/>
				</fo:block>
			</xsl:if>
			
			<xsl:if test="count($referees) &gt; 0">
				<fo:table width="100%" table-layout="fixed" border="medium solid black" font-size="8pt">
					<xsl:call-template name="adjust_font_size"/>
					
					<fo:table-column column-width="3cm" />
					<fo:table-column>
						<xsl:attribute name="column-width">
							<xsl:value-of select="$main_col_width - 3"/>
							<xsl:text>cm</xsl:text>
						</xsl:attribute>
					</fo:table-column>
					
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell padding="2pt">
								<fo:block text-align="right">Wettkampfrichter:</fo:block>
							</fo:table-cell>
							<fo:table-cell padding="2pt">
								<fo:block>
									<xsl:for-each select="$referees">
										<fo:block>
											<fo:inline text-transform="uppercase">
												<xsl:value-of select="Referee_LastName"></xsl:value-of>
											</fo:inline>
											<xsl:text>, </xsl:text>
											<xsl:value-of select="Referee_FirstName"></xsl:value-of>
											<xsl:text> (</xsl:text>
											<xsl:value-of select="Referee_City"></xsl:value-of>
											<xsl:text>, </xsl:text>
											<fo:inline text-transform="uppercase">
												<xsl:value-of select="Nation_IOC_Code" />
											</fo:inline>
											<xsl:text>)</xsl:text>
										</fo:block>
									</xsl:for-each>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</xsl:if>
		</xsl:if>
		<!-- just to keep fop alive -->
		<fo:block/>
	</xsl:template>
	
	<xsl:template name="large-header">
		<!-- large header to find results quickly on result hangout  -->			
		<fo:table width="100%" table-layout="fixed" border-bottom="medium solid black" margin-bottom="4pt">
		
			<fo:table-column column-width="22.5%" />
			<fo:table-column column-width="55%" />
			<fo:table-column column-width="22.5%" />
			
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell>
						<fo:block font-size="32pt">
							<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_RaceNumber"/>
						</fo:block>
						<fo:block font-size="14pt">
							<xsl:text>Rennen </xsl:text>
							<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_RaceNumber"/>
						</fo:block>
						
					</fo:table-cell>
					
					<fo:table-cell>
						<fo:block text-align="center">
							<fo:block font-size="32pt">
								<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_ShortLabel"/>
								<xsl:if test="string-length(data/RaceInfo/RaceInfo/Offer_Comment) != 0">
									<xsl:text> </xsl:text>
									<xsl:value-of select="substring(/data/RaceInfo/RaceInfo/Offer_Comment, 1, 7)"/>
								</xsl:if>
							</fo:block>
							<fo:block font-size="14pt">
								<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_LongLabel"/>
								<xsl:text> </xsl:text>
								<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_Comment"/>
							</fo:block>
						</fo:block>
					</fo:table-cell>
					
					<fo:table-cell>
						<fo:block text-align="right" font-size="32pt">
							<xsl:if test="/data/CompInfo/CompInfo/Comp_RoundCode != 'R' or /data/CompInfo/CompInfo/Comp_RoundCode != 'L'">
								<xsl:value-of select="/data/CompInfo/CompInfo/Comp_RoundCode"/>
							</xsl:if>
							<xsl:value-of select="/data/CompInfo/CompInfo/Comp_Label"/>
							<xsl:text> </xsl:text>
							<xsl:call-template name="GetShortGroupString">
								<xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode"/>
								<xsl:with-param name="value" select="/data/CompInfo/CompInfo/Comp_GroupValue"/>
							</xsl:call-template>
						</fo:block>
						<fo:block text-align="right" font-size="14pt">
							<xsl:apply-templates select="/data/CompInfo/CompInfo" mode="GetLongCompCaption"/>
							<xsl:text> </xsl:text>							
							<xsl:call-template name="GetShortGroupString">
								<xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode"/>
								<xsl:with-param name="value" select="/data/CompInfo/CompInfo/Comp_GroupValue"/>
							</xsl:call-template>
						</fo:block>
					</fo:table-cell>
					
				</fo:table-row>
			</fo:table-body>
		</fo:table>
	</xsl:template>

	<xsl:template match="Result">
		<xsl:variable name="ceid" select="CE_ID_FK" />
		<xsl:variable name="eid" select="/data/Lanes/Lane[CE_ID = $ceid]/CE_Entry_ID_FK"/>
		<xsl:variable name="entry" select="/data/Entries/Entrie[Entry_ID = $eid]" />
		<xsl:variable name="splits" select="/data/Results/Result[CE_ID_FK = $ceid]" />
		<xsl:variable name="finish" select="." />
		
		<xsl:if test="count($splits) != 0">
			<fo:table-row>
				<fo:table-cell border="medium solid black" padding-top="0.5em" font-weight="bold">
					<fo:block text-align="center">
						<xsl:if test="number($finish/Rank) &gt; 0">
							<xsl:value-of select="$finish/Rank" />
						</xsl:if>
					</fo:block>
				</fo:table-cell>
				
				<fo:table-cell border="medium solid black" padding-top="0.5em">
					<fo:block text-align="center"><xsl:value-of select="$eid/../CE_Lane" /></fo:block>
				</fo:table-cell>
				
				<fo:table-cell border="medium solid black" padding-top="0.5em">
					<fo:block text-align="center"><xsl:value-of select="$entry/Entry_FullBib" /></fo:block>
				</fo:table-cell>
				
				<fo:table-cell border="medium solid black" padding="0.5em">
					<fo:block font-weight="bold">
						<xsl:apply-templates select="$entry" mode="GetLabel">
							<xsl:with-param name="round">
								<xsl:if test="/data/CompInfo">
									<xsl:value-of select="/data/CompInfo/CompInfo/Comp_Round"/>
								</xsl:if>
								<!-- for round results -->
								<xsl:if test="/data/RoundInfo">
									<xsl:value-of select="/data/RoundInfo/RoundInfo/Number"/>
								</xsl:if>
							</xsl:with-param>
						</xsl:apply-templates>
					</fo:block>
					<fo:block keep-with-previous="always">
						<xsl:if test="$use_small_font">
							<xsl:attribute name="font-size">9pt</xsl:attribute>
						</xsl:if>
						<xsl:if test="not($use_small_font)">
							<xsl:attribute name="font-size">10pt</xsl:attribute>
						</xsl:if>
						<xsl:apply-templates select="$entry" mode="GetCrewString">
							<xsl:with-param name="round">
								<xsl:if test="/data/CompInfo">
									<xsl:value-of select="/data/CompInfo/CompInfo/Comp_Round"/>
								</xsl:if>
								<!-- for round results -->
								<xsl:if test="/data/RoundInfo">
									<xsl:value-of select="/data/RoundInfo/RoundInfo/Number"/>
								</xsl:if>
							</xsl:with-param>
						</xsl:apply-templates>
					</fo:block>
					<fo:block font-size="10pt" text-decoration="underline" keep-with-previous="always">
						<xsl:value-of select="$finish/Comment"/>
					</fo:block>
				</fo:table-cell>
				
				<!--  splits and finish -->
				<xsl:call-template name="showSplits">
					<xsl:with-param name="splits" select="$splits"/>
				</xsl:call-template>		
			</fo:table-row>
			
			<fo:table-row>
				<fo:table-cell>
					<fo:block margin-top=".25em"></fo:block>
				</fo:table-cell>
			</fo:table-row>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="splitColumns">
		<xsl:param name="splitNr" select="number(1)"/>
		<xsl:param name="split_col_width"/>
		<xsl:if test="$splitNr &lt;= $num_splits">
			<fo:table-column>
				<xsl:attribute name="column-width">
					<xsl:value-of select="$split_col_width"/>
					<xsl:text>cm</xsl:text>
				</xsl:attribute>
				<!--
				<xsl:attribute name="column-number">
					<xsl:value-of select="$splitNr + 4"/>
				</xsl:attribute>
				-->
			</fo:table-column>
			
			<!-- recursion -->
			<xsl:call-template name="splitColumns">
				<xsl:with-param name="splitNr" select="$splitNr + 1"/>
				<xsl:with-param name="split_col_width" select="$split_col_width"/>
			</xsl:call-template> 
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="splitHeaders">
		<xsl:param name="nr" select="number(1)"/>
		<xsl:if test="$num_splits &gt; 0">
			<fo:table-cell border="medium solid black" padding=".5em">
				<fo:block text-align="right">
					<xsl:value-of select="floor((/data/CompInfo/CompInfo/Comp_Distance div ($num_splits + 1)) * $nr)"/>
					<xsl:text> m</xsl:text>
				</fo:block>
			</fo:table-cell>
			<xsl:if test="$nr &lt; $num_splits">
				<xsl:call-template name="splitHeaders">
					<xsl:with-param name="nr" select="$nr + 1"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template name="showSplits">
		<xsl:param name="splits"/>
		<xsl:param name="lastSplit" select="false()"/>		
		<xsl:param name="nr" select="number(1)"/>
		<xsl:param name="split" select="$splits[SplitNr = $nr]"/>
		
		<xsl:choose>
			<xsl:when test="$nr &lt;= $num_splits">
				<!-- show split and step deeper -->
				<xsl:call-template name="showSplit">
					<xsl:with-param name="split" select="$split"/>
					<xsl:with-param name="lastSplit" select="$lastSplit"/>
				</xsl:call-template>
				<xsl:call-template name="showSplits">
					<xsl:with-param name="splits" select="$splits"/>
					<xsl:with-param name="nr" select="number($nr + 1)"/>
					<xsl:with-param name="lastSplit">
						<xsl:if test="count($splits[SplitNr = number($nr)]) &gt; 0">
							<xsl:value-of select="$split/NetTime"/>
						</xsl:if>
						<xsl:if test="count($splits[SplitNr = number($nr)]) = 0">
							<xsl:copy-of select="$lastSplit"/>
						</xsl:if>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<!-- last split, show finish and abort template recursion -->
				<xsl:call-template name="showSplit">
					<xsl:with-param name="split" select="$splits[SplitNr = 64]"/>
					<xsl:with-param name="lastSplit">
						<xsl:value-of select="$lastSplit"/>
					</xsl:with-param>
				</xsl:call-template>			
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- display a single split -->
	<xsl:template name="showSplit">
		<xsl:param name="split"/>
		<xsl:param name="lastSplit" select="false()"/>
		<xsl:param name="strokes" select="substring-after($split/Params, '=')"/>
		
		<fo:table-cell margin="2pt" border="medium solid black" padding-top="0.5em">
			<fo:block text-align="right">
				<xsl:if test="$split">
					<xsl:apply-templates select="$split/DisplayValue" mode="friendly"/>
					<xsl:if test="$num_splits &gt; 0 and $split/Rank &gt; 0">
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$split/Rank"/>
						<xsl:text>)</xsl:text>
					</xsl:if>
				</xsl:if>
			</fo:block>
			
			<xsl:if test="/data/RaceInfo/RaceInfo/Offer_RaceType = 16">
				<fo:block font-size="8pt" text-align="right" keep-with-previous="always">
					<fo:block>
						<xsl:text>Frequenz: </xsl:text>
						<xsl:value-of select="format-number($strokes div ($split/NetTime div 1000 div 60), '#.0')"/>
					</fo:block>
					<fo:block>
						<xsl:text>Zeit: </xsl:text>
						<xsl:call-template name="format-time-from-int">
							<xsl:with-param name="value" select="$split/NetTime"/> 
							<xsl:with-param name="minimal" select="true()"/>
						</xsl:call-template>
					</fo:block>
					<fo:block>
						<xsl:text>Schläge: </xsl:text>
						<xsl:value-of select="$strokes"/>
					</fo:block>
				</fo:block>
			</xsl:if>
			
			<!-- additional infos -->
			<xsl:if test="$split/Rank &gt; 0 and /data/RaceInfo/RaceInfo/Offer_RaceType != 16">
				<!-- gap (relative to the last split) -->
				<xsl:if test="$num_splits &gt; 0">
					<fo:block text-align="right" keep-with-previous="always" white-space-treatment="preserve">
						<xsl:text> </xsl:text>
						<xsl:if test="$lastSplit != false()">
							<xsl:call-template name="format-time-from-int">
								<xsl:with-param name="value" select="floor($split/NetTime div 10)*10 - floor($lastSplit div 10)*10"/>
								<xsl:with-param name="minimal" select="true()"/>
							</xsl:call-template>
						</xsl:if>
					</fo:block>
				</xsl:if>
				
				<!-- delta (relative to first place) -->
				<xsl:if test="$split/DisplayType = 'T' and $split/Rank &gt; 1">
					<fo:block text-align="right" keep-with-previous="always">
						<xsl:if test="$split">
							<xsl:text>+</xsl:text>
							<xsl:call-template name="format-time-from-int">
								<xsl:with-param name="value" select="$split/Delta"/>
								<xsl:with-param name="minimal" select="true()"/>
							</xsl:call-template>
						</xsl:if>
					</fo:block>
				</xsl:if>
			</xsl:if>
		</fo:table-cell>
	</xsl:template>

	<xsl:template name="adjust_font_size">
		<xsl:if test="$use_small_font">
			<xsl:attribute name="font-size">
				<xsl:text>9.5pt</xsl:text>
			</xsl:attribute>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
