<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:include href="./includes/standard.xsl"/>
    <xsl:include href="./includes/racecompheader.xsl"/>

	<xsl:param name="by_startlist" select="/data/ReportOptions/ReportOption[Name='by_startlist']/Value"/>
	
	<xsl:variable name="wraces" select="/data/Races/Race[Offer_IsLightweight = 1 or BoatClass_Coxed = 1]"/>

	<xsl:key name="dayraces" match="/data/Races/Race[Offer_IsLightweight = 1 or BoatClass_Coxed = 1]" use="Offer_ID" />

    <xsl:template name="body">
    	<xsl:if test="$by_startlist = 1">
    		<xsl:for-each select="/data/Comps/Comp[State = 1]">
			<xsl:variable name="race" select="/data/Races/Race[Offer_ID = current()/Race_ID_FK][1]"/>
    			<xsl:variable name="lanes" select="/data/Lanes/Lane[CE_Comp_ID_FK = current()/ID]"/>
			<xsl:variable name="round" select="Round"/>
    			
			<xsl:if test="($race/Weigh_Cox = 1 or $race/Weigh_Athlete = 1) and count($lanes) &gt; 0">
    				<fo:block border="medium solid black">
    					<fo:block font-size="12pt" font-weight="bold" border-bottom="medium solid black">
    						<fo:block margin="2pt">
    							<xsl:apply-templates select="." mode="comp_header"/>
       						</fo:block>
    					</fo:block>

						<fo:block margin="0 2pt">    					
		    					<xsl:apply-templates select="$race" mode="weight_info">
		    						<xsl:with-param name="comp" select="current()"/>
		    					</xsl:apply-templates>    						
    					</fo:block>
    					
						<fo:list-block start-indent="7mm" provisional-label-separation="1.5mm" provisional-distance-between-starts="7mm" keep-with-previous.within-page="always">    				
							<xsl:for-each select="$lanes">
								<xsl:sort select="CE_Lane" data-type="number" />
 								<xsl:apply-templates select="/data/Entries/Entrie[Entry_ID = current()/CE_Entry_ID_FK]" mode="weigh">
				    					<xsl:with-param name="race" select="$race"/>
									<xsl:with-param name="info" select="/data/WeighInfos/WeighInfo[AgeClass_ID = $race/Offer_AgeClass_ID_FK]"/>
									<xsl:with-param name="round" select="$round"/>
								</xsl:apply-templates>								
							</xsl:for-each>
 						</fo:list-block>						
    				</fo:block>
    				
				<fo:block keep-with-previous="always" padding-bottom="1em"></fo:block>
    			</xsl:if>
    		</xsl:for-each>
    	</xsl:if> 	
    	
    	<xsl:if test="$by_startlist = 0">
		<xsl:for-each select="/data/Races/Race">
			<xsl:variable name="race" select="current()"/>
			<xsl:variable name="rid" select="./Offer_ID"/>

			<xsl:if test="count(/data/Entries/Entrie[Entry_Race_ID_FK = $rid]) &gt; 0 and count(/data/Comps/Comp[Race_ID_FK = $rid]) &gt; 0">
				<xsl:apply-templates select="$race" mode="header"/>
				<xsl:apply-templates select="$race" mode="schedule_info"/>
				<xsl:apply-templates select="$race" mode="weight_info"/>
  
				<fo:list-block start-indent="7mm" provisional-label-separation="1.5mm" provisional-distance-between-starts="7mm" keep-with-previous.within-page="always">
					<xsl:apply-templates select="/data/Entries/Entrie[Entry_Race_ID_FK = $rid]" mode="weigh">
    						<xsl:with-param name="race" select="$race"/>
    						<xsl:with-param name="info" select="/data/WeighInfos/WeighInfo[AgeClass_ID = current()/Offer_AgeClass_ID_FK]"/>
						<xsl:with-param name="round" select="/data/Comps/Comp[Race_ID_FK = current()/Offer_ID][1]/Round"/>
    					</xsl:apply-templates>
				</fo:list-block>

				<fo:block keep-with-previous="always" padding-bottom="2em"></fo:block>
			</xsl:if>
    		</xsl:for-each>
    	</xsl:if> 	    	
	</xsl:template>

	<xsl:template match="Race" mode="weight_info">
		<xsl:param name="comp" select="/data/Comps/Comp[Race_ID_FK = current()/Offer_ID][1]"/>
		<xsl:variable name="aid" select="./Offer_AgeClass_ID_FK"/>
		<xsl:variable name="rid" select="./Offer_ID"/>
		<xsl:variable name="info" select="/data/WeighInfos/WeighInfo[AgeClass_ID = $aid]"/>
		
		<fo:block padding=".5em 0" keep-with-previous="always" font-size="9pt">
			<fo:block font-weight="bold" keep-with-previous="always">Regularien</fo:block>
			
			<fo:block keep-with-previous="always">
				<xsl:text>Wiegezeitraum: </xsl:text>
				<xsl:value-of select="$comp/Hour - 2"/>
				<xsl:text>:</xsl:text>
				<xsl:value-of select="format-number($comp/Minute, '00')"/>
				<xsl:text> bis </xsl:text>
				<xsl:value-of select="$comp/Hour - 1"/>
				<xsl:text>:</xsl:text>
				<xsl:value-of select="format-number($comp/Minute, '00')"/>
				<xsl:text> Uhr</xsl:text>
			</fo:block>
			
			<xsl:if test="Weigh_Athlete = 1"> 
				<xsl:if test="$info/UpperLimit &gt; 0"> 
					<fo:block keep-with-previous="always">
						<xsl:text>Maximalgewicht einzelner Ruderer: </xsl:text>
						<xsl:value-of select="format-number($info/UpperLimit div 1000, '###.0')"/>
						<xsl:text> kg</xsl:text>
					</fo:block> 
				</xsl:if>
				<xsl:if test="BoatClass_NumRowers &gt; 1 and $info/AvgLimit &gt; 0"> 
					<fo:block keep-with-previous="always">
						<xsl:text>Höchstwert für Durchschnittsgewicht der Ruderer (nicht St.): </xsl:text>
						<xsl:value-of select="format-number($info/AvgLimit div 1000, '###.0')"/>
						<xsl:text> kg</xsl:text>
					</fo:block> 
				</xsl:if>
			</xsl:if>

			<xsl:if test="Weigh_Cox = 1">
				<fo:block keep-with-previous="always">
					<xsl:text>Steuermann: Mindestgewicht </xsl:text>
					<xsl:value-of select="format-number($info/CoxLowerLimit div 1000, '###.0')"/>
					<xsl:text> kg</xsl:text>
				</fo:block>
				<xsl:if test="$info/CoxLowerLimit &gt; 0">
					<fo:block keep-with-previous="always">
						<xsl:text>Mindergewicht Steuermann ausgleichbar bis </xsl:text>
						<xsl:value-of select="format-number($info/CoxTolerance div 1000, '###.0')"/>
						<xsl:text> kg</xsl:text>
					</fo:block>
				</xsl:if> 
			</xsl:if>
		</fo:block>
	</xsl:template>
	
	<xsl:template match="Entrie" mode="weigh">
		<xsl:param name="info"/>
		<xsl:param name="race"/>
		<xsl:param name="round"/>
	
		<fo:list-item>
			<fo:list-item-label end-indent="label-end()">
				<fo:block font-weight="bold" text-align="right">
					<xsl:value-of select="Entry_FullBib"/>
				</fo:block>
			</fo:list-item-label>
	
			<fo:list-item-body start-indent="body-start()">
				<fo:block font-weight="bold">
					<xsl:apply-templates select="current()" mode="GetLabel">
						<xsl:with-param name="short" select="true()"/>
						<xsl:with-param name="round" select="$round"/>
					</xsl:apply-templates>
				</fo:block>
				
				<fo:table start-indent="body-start()" width="90%" table-layout="fixed" keep-with-previous="always">
		            <fo:table-column column-number="1" column-width="6%"/>   
		            <fo:table-column column-number="2" column-width="45%"/>
		            <fo:table-column column-number="3" column-width="15%"/>
		            <fo:table-column column-number="4" column-width="34%"/>
		            
		            <fo:table-body start-indent="0" end-indent="0">		            
		            	<xsl:if test="$race/Weigh_Athlete = 1">
					<xsl:apply-templates select="/data/Crews/Crew[Entry_ID_FK = current()/Entry_ID and IsCox = 0 and RoundFrom &lt;= $round and RoundTo &gt;= $round]">
						<xsl:with-param name="round" select="$round"/>
					</xsl:apply-templates>
					<xsl:if test="count(/data/Crews/Crew[Entry_ID_FK = current()/Entry_ID and IsCox = 0 and RoundFrom &lt;= $round and RoundTo &gt;= $round]) = 0">
			            		 <fo:table-row>
			            		 	<fo:table-cell><fo:block></fo:block></fo:table-cell>
			            		 	<fo:table-cell><fo:block>keine Mannschaft eingetragen!</fo:block></fo:table-cell>
			            		 </fo:table-row>
			            	</xsl:if>
		            	</xsl:if>
		            	<xsl:if test="$race/Weigh_Cox = 1">
					<xsl:apply-templates select="/data/Crews/Crew[Entry_ID_FK = current()/Entry_ID and IsCox = 1 and RoundFrom &lt;= $round and RoundTo &gt;= $round]">
						<xsl:with-param name="round" select="$round"/>
					</xsl:apply-templates>
					<xsl:if test="count(/data/Crews/Crew[Entry_ID_FK = current()/Entry_ID and IsCox = 1 and RoundFrom &lt;= $round and RoundTo &gt;= $round]) = 0">
			            		 <fo:table-row>
			            		 	<fo:table-cell><fo:block></fo:block></fo:table-cell>
							<fo:table-cell><fo:block>kein St. eingetragen!</fo:block></fo:table-cell>
			            		 </fo:table-row>
			            	</xsl:if>
		            	</xsl:if>
		            </fo:table-body>
				</fo:table>
			</fo:list-item-body>
		</fo:list-item>
	</xsl:template>
	
	<xsl:template match="Crew">
		<xsl:param name="round" select="number(64)"/>

		<xsl:variable name="pos" select="current()/Pos"/>
		<xsl:variable name="eid" select="current()/Entry_ID_FK"/>
		<xsl:variable name="pos_ath_count" select="count(/data/Crews/Crew[Entry_ID_FK = $eid and Pos = $pos and RoundFrom &lt;= $round and RoundTo &gt;= $round])"/>
		<xsl:variable name="a" select="/data/Athlets/Athlet[ID = current()/Athlete_ID_FK]"/>
		<xsl:variable name="oeids" select="/data/Races/Race[Offer_ID = /data/Crews/Crew[Athlete_ID_FK = current()/Athlete_ID_FK and Entry_ID_FK != current()/Entry_ID_FK]/Entry_ID_FK]/Offer_ID"/>

		<xsl:if test="$pos_ath_count &gt; 0">
			<fo:table-row keep-with-previous="always">
				<fo:table-cell>
					<fo:block text-align="left">
						<xsl:text>(</xsl:text>
						<xsl:if test="IsCox = 1"><xsl:text>St.</xsl:text></xsl:if>
						<xsl:if test="IsCox = 0"><xsl:value-of select="Pos"/></xsl:if>
						<xsl:text>)</xsl:text>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:value-of select="concat($a/LastName, ', ', $a/FirstName, ' (', $a/YOB, ')')"/>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell border-bottom="thin dashed gray">
					<fo:block/>
				</fo:table-cell>
				<fo:table-cell padding-left="1em" font-size="9pt">
					<fo:block>
						<xsl:if test="count($oeids) &gt; 0">
							<xsl:text>gemeldet auch in Re. </xsl:text>
							<xsl:for-each select="$oeids">
								<xsl:variable name="rid" select="/data/Entries/Entrie[Entry_ID = current()]/Entry_Race_ID_FK"/>
								
								<xsl:if test="position() &gt; 1">
									<xsl:text>, </xsl:text>
								</xsl:if>
								
								<xsl:value-of select="/data/Races/Race[Offer_ID = $rid]/Offer_RaceNumber"/>
							</xsl:for-each>
						</xsl:if>
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
