<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"  xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:variable name="weburl">
		<xsl:choose>			
			<xsl:when test="/data/Event/Event/Url != ''">
				<xsl:value-of select="/data/Event/Event/Url" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>www.havel-regatta-verein.de</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="dataservice">
		<xsl:choose>			
			<xsl:when test="/data/Event/Event/Club_Name != ''">
				<xsl:value-of select="/data/Event/Event/Club_Name" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>Havel-Regatta-Verein von 1920 e. V.</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:template name="PageFooter">
		<fo:static-content flow-name="page-footer">
			<fo:block-container font-size="8.5pt">
				<fo:block text-align-last="justify" border-bottom="medium solid black">
					<xsl:text>Internet: </xsl:text>
            		<fo:basic-link>
            			<xsl:attribute name="external-destination">
            				<xsl:text>http://</xsl:text>
            				<xsl:value-of select="$weburl" />
            			</xsl:attribute>
						<xsl:value-of select="$weburl" />
            		</fo:basic-link>
            							 
					<fo:leader leader-pattern="space"/>
					
					<xsl:text>Seite </xsl:text>
					<fo:page-number/>
					<xsl:text>/</xsl:text>
					<fo:page-number-citation-last ref-id="seq-primary"/>
				</fo:block>
				<fo:table space-before="2pt" width="100%" table-layout="fixed">
					<fo:table-column column-number="1" column-width="33.333%"/>
					<fo:table-column column-number="2" column-width="33.333%"/>
					<fo:table-column column-number="3" column-width="33.333%"/>
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell>
								<fo:block font-weight="bold">
									<xsl:value-of select="$dataservice"/>
								</fo:block>
							</fo:table-cell>
							<!-- Datum: TAG dd.mm.yyyy / hh:nn -->
							<fo:table-cell>
								<fo:block text-align="center">
									<xsl:text>Report erstellt: </xsl:text>
									<fo:inline text-transform="uppercase">
										<xsl:call-template name="GetShortWeekDay">
											<xsl:with-param name="day" select="(/data/ReportInfo/ReportInfo/DateWeekDay - 1) mod 7"/>
										</xsl:call-template>
									</fo:inline>
									<xsl:text> </xsl:text>
									<xsl:number value="/data/ReportInfo/ReportInfo/DateDay" format="01"/>
									<xsl:text> </xsl:text>
									<fo:inline text-transform="uppercase">
										<xsl:call-template name="GetShortMonth">
											<xsl:with-param name="month" select="/data/ReportInfo/ReportInfo/DateMonth"/>
										</xsl:call-template>
									</fo:inline>									
									<xsl:text> </xsl:text>
									<xsl:number value="/data/ReportInfo/ReportInfo/DateYear"/>
									<xsl:text> / </xsl:text>
									<xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateHour, '00')"></xsl:value-of>
									<xsl:text>:</xsl:text>
									<xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateMinute, '00')"></xsl:value-of>
								</fo:block>
							</fo:table-cell>
							<!-- ReportCode/Version: RO0000Y24_M_ZPDAY -->
							<fo:table-cell>
								<fo:block text-align="right">
									<xsl:if test="$show_code = true()">
										<xsl:value-of select="/data/ReportInfo/ReportInfo/Code"/>
									</xsl:if>
									<xsl:if test="$show_code = false()">
										<xsl:text>Version</xsl:text>
									</xsl:if>
									<xsl:text> </xsl:text>
									<xsl:value-of select="/data/ReportInfo/ReportInfo/VerMajor"/>
									<xsl:text>.</xsl:text>
									<xsl:value-of select="/data/ReportInfo/ReportInfo/VerMinor"/>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>				
			</fo:block-container>
			<xsl:if test="string-length(/data/Event/Event/FootLogo) != 0">
				<fo:block text-align="center">
					<fo:external-graphic height="1.75cm" width="100%" content-height="scale-to-fit" content-width="scale-to-fit">
						<xsl:attribute name="src">
							<xsl:text>url('file:///</xsl:text>
							<xsl:value-of select="translate(concat(/data/ReportInfo/ReportInfo/ImageDir, /data/Event/Event/FootLogo), '\', '/')"/>
							<xsl:text>')</xsl:text>
						</xsl:attribute>
					</fo:external-graphic>
				</fo:block>
			</xsl:if>
		</fo:static-content>		
	</xsl:template>

</xsl:stylesheet>
