<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:param name="only_finals" select="boolean(/data/ReportOptions/ReportOption[Name='only_finals']/Value = 1)"/>
	<xsl:param name="hide_names_in_non_finals" select="boolean(/data/ReportOptions/ReportOption[Name='hide_names_in_non_finals']/Value = 1)"/>
	<xsl:param name="hide_yob" select="boolean(/data/ReportOptions/ReportOption[Name='hide_yobs']/Value = 1)"/>

	<xsl:template name="full_result">
		<xsl:apply-templates select="/data/Races/Race[Offer_Driven = 1]" mode="Result"/>		
		<xsl:call-template name="cancelled-races"/>
		<xsl:call-template name="referees"/>
	</xsl:template>
	
	<xsl:template match="Race" mode="Result">
		<xsl:variable name="rid" select="Offer_ID"/>
		<xsl:variable name="cancelled_entries" select="/data/Entries/Entrie[Entry_Race_ID_FK = $rid and Entry_CancelValue != 0]"/>
	
		<fo:block font-weight="bold" keep-with-next="always">
			<xsl:attribute name="id">
				<xsl:text>r</xsl:text>
				<xsl:value-of select="Offer_ID"/>
			</xsl:attribute>
			<xsl:text>Rennen </xsl:text>
			<xsl:value-of select="Offer_RaceNumber"/>
			<xsl:text> - </xsl:text>
			<xsl:value-of select="Offer_ShortLabel"/>
			<xsl:text>, </xsl:text>
			<xsl:value-of select="Offer_LongLabel"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="Offer_Comment"/>
		</fo:block>
		
		<fo:block font-weight="bold" keep-with-next="always" margin-bottom="2pt">
			<xsl:value-of select="Offer_Prize"/>
		</fo:block>
		
		<xsl:apply-templates select="/data/Comps/Comp[Race_ID_FK = $rid and Cancelled = 0 and (($only_finals and Round = 64) or (not($only_finals)))]" mode="Result">
			<xsl:sort select="Round" data-type="number"/>
			<xsl:sort select="GroupValue" data-type="number"/>
			<xsl:sort select="HeatNumber" data-type="number"/>
		</xsl:apply-templates>
		
		<xsl:if test="$cancelled_entries">
			<fo:block border="medium solid black" font-size="10pt">
				<fo:block font-weight="bold" margin="0.25em">
					<xsl:text>Abmeldungen</xsl:text>
				</fo:block>		
			
				<fo:table table-layout="fixed" width="100%">
					<fo:table-column column-number="1" column-width="2cm"/>
					<fo:table-column column-number="2" column-width="14cm"/>
						
					<fo:table-body>
						<xsl:for-each select="$cancelled_entries">
							<xsl:sort select="Entry_Bib" data-type="number"/>
							
							<fo:table-row>
								<fo:table-cell padding-right="0.25em">
									<fo:block text-align="right">
										<xsl:value-of select="Entry_FullBib"/>
									</fo:block>							
								</fo:table-cell>
								<fo:table-cell padding-left="0.25em">
									<fo:block>
										<xsl:if test="$show_noc">
											<xsl:apply-templates select="." mode="GetNOCCode"/>
											<xsl:text> </xsl:text>
										</xsl:if>
										<xsl:apply-templates select="." mode="GetLabel">
											<xsl:with-param name="short" select="true()"/>
										</xsl:apply-templates>
									</fo:block>							
								</fo:table-cell>
							</fo:table-row>
						</xsl:for-each>
					</fo:table-body>
				</fo:table>
			</fo:block>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="Comp" mode="Result">
		<xsl:variable name="cid" select="ID"/>
		<xsl:variable name="rid" select="Race_ID_FK"/>
		<xsl:variable name="round" select="Round"/>
		<xsl:variable name="gm" select="/data/Races/Race[Offer_ID = $rid]/Offer_GroupMode"/>
		<xsl:variable name="results" select="/data/Results/Result[Comp_ID = $cid and SplitNr = 64]"/>
		
		<fo:block font-size="10pt" font-weight="normal">
			<xsl:attribute name="id">
				<xsl:text>c</xsl:text>
				<xsl:value-of select="ID"/>
			</xsl:attribute>
			
			<xsl:apply-templates select="." mode="GetLongCompCaption"/>
			<xsl:if test="$gm != 0">
				<xsl:text>, </xsl:text>
				<xsl:call-template name="GetGroupString">
					<xsl:with-param name="mode" select="$gm"/>
					<xsl:with-param name="value" select="GroupValue"/>
				</xsl:call-template>
			</xsl:if>
		</fo:block>

		<xsl:if test="count($results) &gt; 0">		
			<fo:table table-layout="fixed" width="100%" font-size="10pt" border="medium solid black" margin-bottom="0.25em" keep-with-previous="always" table-omit-footer-at-break="true">
				<fo:table-column column-number="1" column-width="1cm"/>
				<fo:table-column column-number="2" column-width="1cm"/>
				<fo:table-column column-number="3" column-width="13.5cm"/>
				<fo:table-column column-number="4" column-width="2.5cm"/>
				
				<fo:table-header border-bottom="medium solid black">
					<fo:table-row font-size="8pt" keep-with-previous="always">
						<fo:table-cell padding-top="0.25em"><fo:block text-align="center">Rang</fo:block></fo:table-cell>
						<fo:table-cell padding-top="0.25em"><fo:block text-align="center">StNr</fo:block></fo:table-cell>
						<fo:table-cell padding-top="0.25em"><fo:block >Boot/Mannschaft</fo:block></fo:table-cell>
						<fo:table-cell padding-top="0.25em" padding-right="0.25em"><fo:block text-align="right">Ergebnis</fo:block></fo:table-cell>
					</fo:table-row>
				</fo:table-header>

				<xsl:if test="/data/CompReferees/CompReferee[Comp_ID_FK = $cid]">
					<fo:table-footer>
						<fo:table-row keep-with-previous="always">
							<fo:table-cell><fo:block/></fo:table-cell>
							<fo:table-cell><fo:block/></fo:table-cell>
							<fo:table-cell>
								<fo:block>
									<xsl:for-each select="/data/CompReferees/CompReferee[Comp_ID_FK = $cid]">
										<xsl:variable name="refid" select="Referee_ID_FK"/>
										<xsl:if test="position() = 1">
											<xsl:text>Schiedsrichter: </xsl:text>
										</xsl:if>
										<xsl:for-each select="/data/Referees/Referee[ID = $refid]">
											<xsl:call-template name="RefereeName"/>
										</xsl:for-each>
										<xsl:if test="position() != last()">
											<xsl:text>, </xsl:text>
										</xsl:if>
									</xsl:for-each>									
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-footer>
				</xsl:if>
				
				<fo:table-body font-size="10pt">
					<xsl:apply-templates select="$results">
						<xsl:sort select="SortValue" data-type="number"/>
						<xsl:with-param name="round" select="$round"/>
					</xsl:apply-templates>
				</fo:table-body>
			</fo:table>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="Result">
		<xsl:param name="round" select="number('64')"/>
		<xsl:variable name="ceid" select="CE_ID_FK"/>
		<xsl:variable name="eid" select="/data/Lanes/Lane[CE_ID = $ceid]/CE_Entry_ID_FK"/>
		<xsl:variable name="entry" select="/data/Entries/Entrie[Entry_ID=$eid]"/>
		
		<fo:table-row keep-with-previous="400">
			<fo:table-cell padding-top="0.25em" >
				<fo:block text-align="center">
					<xsl:if test="Rank &gt; 0">
						<xsl:value-of select="Rank"></xsl:value-of>
					</xsl:if>
				</fo:block>
			</fo:table-cell>
			
			<fo:table-cell padding-top="0.25em" >
				<fo:block text-align="center">
					<xsl:value-of select="$entry/Entry_FullBib"></xsl:value-of>
				</fo:block>
			</fo:table-cell>
				
			<fo:table-cell padding-top="0.25em" >
				<fo:block>
					<fo:inline font-weight="bold">
						<xsl:apply-templates select="$entry" mode="GetLabel"/>
					</fo:inline>
				</fo:block>
				<xsl:if test="not($hide_names_in_non_finals) or ($round = 64 and $hide_names_in_non_finals)">
					<fo:block keep-with-previous="always">
						<xsl:apply-templates select="$entry" mode="GetCrewString">
							<xsl:with-param name="round" select="$round"/>
							<xsl:with-param name="hide_yob" select="$hide_yob"/>
						</xsl:apply-templates>
					</fo:block>
				</xsl:if>
				<fo:block text-decoration="underline" keep-with-previous="always">
					<xsl:value-of select="Comment"></xsl:value-of>
				</fo:block>
			</fo:table-cell>
			
			<fo:table-cell padding-top="0.25em" padding-right="0.25em">
				<fo:block text-align="right" >
					<fo:block>
						<xsl:apply-templates select="DisplayValue" mode="friendly"/>
					</fo:block>
					<xsl:if test="Rank &gt; 1 and DisplayType = 'T'">
						<fo:block keep-with-previous="always">
							<xsl:text>+</xsl:text>
							<xsl:call-template name="format-time-from-int">
								<xsl:with-param name="value" select="Delta"/>
							</xsl:call-template>
						</fo:block>
					</xsl:if>
				</fo:block>
			</fo:table-cell>
			
			
		</fo:table-row>
	</xsl:template>
	
	<xsl:template name="cancelled-races">
		<fo:block border="medium solid black" font-size="10pt" margin-top="1em" id="raceScratches">
			<fo:block margin="0.25em" font-weight="bold" keep-with-next="always">nicht zu Stande gekommene Rennen</fo:block>
			<fo:block margin-left="1cm" margin-right="1cm">
				<xsl:for-each select="/data/Races/Race[Offer_Driven = 0]">
					<xsl:value-of select="Offer_RaceNumber"/>
					<xsl:if test="position() != last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
<!--
	 				<xsl:text> (</xsl:text>
					<xsl:value-of select="Offer_ShortLabel"/>
					<xsl:if test="string-length(Offer_Comment) &gt; 0">
						<xsl:text> </xsl:text>
						<xsl:value-of select="Offer_Comment"/>
					</xsl:if>
					<xsl:text>)</xsl:text>					
					<xsl:if test="position() != last()">
						<xsl:text>, </xsl:text>
					</xsl:if>
-->
				</xsl:for-each>
			</fo:block>
		</fo:block>	
	</xsl:template>
	
	<xsl:template name="referees">
		<fo:block border="medium solid black" font-size="10pt" margin-top="1em" id="eventReferees">
			<fo:block margin="0.25em" font-weight="bold">Wettkampfrichter-Obmann</fo:block>
			<xsl:for-each select="/data/Event/Event">
				<fo:block margin-left="1cm" margin-bottom="0.5em" keep-with-previous="always">
					<xsl:call-template name="RefereeName"/>
				</fo:block>
			</xsl:for-each>
			
			<fo:block margin="0.25em" font-weight="bold" keep-with-previous="always">
				<xsl:text>eingesetzte Wettkampfrichter</xsl:text>
			</fo:block>
			
			<xsl:for-each select="/data/Referees/Referee">
				<fo:block margin-left="1cm" keep-with-previous="always">
					<xsl:call-template name="RefereeName"/>
				</fo:block>
			</xsl:for-each>
			
		</fo:block>	
	</xsl:template>

</xsl:stylesheet>
