﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"  xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:template name="PageHeader">
		<xsl:variable name="race_comp_long_label">
			<xsl:if test="count(/data/RaceInfo) != 0">
				<!-- Rennbeschreibung (lang): "Männer-Doppelzweier A" -->
				<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_LongLabel"/>
			
				<!-- Laufbeschreibung: "Abteilung 1" -->
				<xsl:if test="count(/data/CompInfo) != 0">
					<xsl:text> - </xsl:text>
					<xsl:apply-templates select="/data/CompInfo/CompInfo" mode="GetLongCompCaption"/>
					<xsl:text> </xsl:text>
					<xsl:call-template name="GetShortGroupString">
						<xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode"/>
						<xsl:with-param name="value" select="/data/CompInfo/CompInfo/Comp_GroupValue"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
		</xsl:variable>
	
		<fo:static-content flow-name="page-header">
			<fo:block border-top="medium solid black" border-bottom="medium solid black">
				<fo:table width="100%" table-layout="fixed">
					<fo:table-column column-number="1" column-width="20%"/>
					<fo:table-column column-number="2" column-width="20%"/>
					<fo:table-column column-number="3" column-width="60%"/> 
					<fo:table-body>
						<fo:table-row height="2.8cm">
							<!-- primary head logo -->
							<fo:table-cell>
                                <fo:block text-align="center" display-align="center" margin="4pt">
                                	<xsl:if test="string-length(/data/Event/Event/HeadLogo_A) != 0">
	                                    <fo:external-graphic height="2.3cm" width="100%" content-height="scale-to-fit" content-width="scale-to-fit">
	                                    	<xsl:attribute name="src">
	                                    		<xsl:text>url('file:///</xsl:text>
	                                    		<xsl:value-of select="translate(concat(/data/ReportInfo/ReportInfo/ImageDir, /data/Event/Event/HeadLogo_A), '\', '/')"/>
	                                    	 	<xsl:text>')</xsl:text>
	                                    	</xsl:attribute>
	                                   	</fo:external-graphic>
                                   	</xsl:if>
                                </fo:block>
							</fo:table-cell>
							
							<!-- secondary head logo -->
							<fo:table-cell>
                                <fo:block text-align="center" display-align="center" margin="4pt">
                                	<xsl:if test="string-length(/data/Event/Event/HeadLogo_B) != 0">
	                                    <fo:external-graphic height="2.3cm" width="100%" content-height="scale-to-fit" content-width="scale-to-fit">
	                                    	<xsl:attribute name="src">
	                                    		<xsl:text>url('file:///</xsl:text>
	                                    		<xsl:value-of select="translate(concat(/data/ReportInfo/ReportInfo/ImageDir, /data/Event/Event/HeadLogo_B), '\', '/')"/>
	                                    	 	<xsl:text>')</xsl:text>
	                                    	</xsl:attribute>
	                                   	</fo:external-graphic>
                                   	</xsl:if>
                                </fo:block>
							</fo:table-cell>
							<!-- Header data -->
							<fo:table-cell>
								<!-- first three lines -->
								<fo:block-container font-size="13pt" font-weight="bold">
									<fo:block>
										<xsl:apply-templates select="/data/Event/Event" mode="HeaderTitle"/>
									</fo:block>
									<fo:block>
										<fo:inline><xsl:value-of select="/data/Event/Event/Venue"/></fo:inline>
									</fo:block>
									<fo:block text-align-last="justify">
										<fo:inline text-transform="uppercase">
											<xsl:apply-templates select="/data/ReportInfo/ReportInfo/Title" mode="reportTitle"/>
										</fo:inline>
										<fo:leader leader-pattern="space"/>
										<xsl:if test="count(/data/RaceInfo) != 0">
											<fo:inline>
												<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_ShortLabel"/>
												<xsl:text> </xsl:text>
												(Re. <xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_RaceNumber"/>)
											</fo:inline>
										</xsl:if>
									</fo:block>
								</fo:block-container>
								
								<!-- last two lines -->
								<fo:block-container font-size="9pt" font-weight="bold">									
									<fo:block text-align-last="justify" line-height="22pt">
										<fo:inline>
											<xsl:value-of select="substring($race_comp_long_label, 1, 50)"/>
										</fo:inline>
										
										<!-- force empty line -->
										<fo:leader leader-pattern="space"/>

										<xsl:if test="count(/data/RoundInfo) != 0">
											<fo:inline>
												<!-- get round label -->
												<xsl:call-template name="_GetCompLongCaption">
													<xsl:with-param name="RoundCode" select="/data/RoundInfo/RoundInfo/Code"/>
												</xsl:call-template>
											</fo:inline>
										</xsl:if>
										
										<xsl:if test="count(/data/CompInfo) != 0">											
											<fo:inline>
												<xsl:value-of select="concat(/data/CompInfo/CompInfo/Comp_RoundCode, /data/CompInfo//CompInfo/Comp_Label)"/>
												<xsl:text> </xsl:text>
												<xsl:text>(#</xsl:text>
												<xsl:value-of select="/data/CompInfo/CompInfo/Comp_Number"/>
												<xsl:text>)</xsl:text>
											</fo:inline>
										</xsl:if>
									</fo:block>
									<fo:block text-align-last="justify" line-height="9pt">
										<!-- Datum -->
										<xsl:if test="count(/data/EventDay/EventDay) &gt; 0">
											<fo:inline text-transform="uppercase">
												<xsl:call-template name="GetShortWeekDay">
													<xsl:with-param name="day" select="/data/EventDay/EventDay/WeekDay"/>
												</xsl:call-template>
												<xsl:text> </xsl:text>
												<xsl:number value="/data/EventDay/EventDay/Day" format="01"/>
												<xsl:text> </xsl:text>								
												<xsl:call-template name="GetShortMonth">
													<xsl:with-param name="month" select="/data/EventDay/EventDay/Month"/>
												</xsl:call-template>
												<xsl:text> </xsl:text>
												<xsl:number value="/data/EventDay/EventDay/Year"/>

												<xsl:if test="/data/CompInfo/CompInfo/Comp_DateTime">
													<xsl:text> / </xsl:text>
													<xsl:value-of select="substring(/data/CompInfo/CompInfo/Comp_DateTime, 12, 5)"/>
												</xsl:if>
											</fo:inline>
										</xsl:if>
										
										<!-- force empty line -->
										<fo:leader leader-pattern="space"/>
										
										<!-- Renndistanz -->
										<fo:inline>
											<xsl:choose>
												<xsl:when test="count(/data/CompInfo) != 0">
													<xsl:value-of select="/data/CompInfo/CompInfo/Comp_Distance"/>
													<xsl:text> m</xsl:text>
												</xsl:when>
												<xsl:when test="count(/data/RoundInfo) != 0">
													<xsl:value-of select="/data/RoundInfo/RoundInfo/Round_Distance"/>
													<xsl:text> m</xsl:text>
												</xsl:when>
												<xsl:when test="count(/data/RaceInfo) != 0">
													<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_Distance"/>
													<xsl:text> m</xsl:text>
												</xsl:when>
											</xsl:choose>
										</fo:inline>
									</fo:block>
								</fo:block-container>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</fo:block>
			
			<!-- Korrektur/Prelimary-Logo -->
			<xsl:if test="data/ReportInfo/ReportInfo/VerMinor &gt; 0">
				<fo:block-container absolute-position="absolute" width="3cm" height="5mm" top="23.5mm" background-color="black" color="white" font-weight="bold" font-size="4mm">
					<fo:block text-align="center" text-transform="uppercase" padding-top="0.5mm">
						<xsl:if test="data/ReportInfo/ReportInfo/VerMajor &gt; 0">
							<xsl:text>korrigiert</xsl:text>
						</xsl:if>
						<xsl:if test="data/ReportInfo/ReportInfo/VerMajor = 0">
							<xsl:text>vorläufig</xsl:text>
						</xsl:if>
					</fo:block>
				</fo:block-container>

				<!-- Version number -->
				<fo:block-container absolute-position="absolute" left="3cm" width="0.8cm" height="4.7mm" top="23.75mm" background-color="silver" font-weight="bold" font-size="4mm" border="0.3mm solid black">
					<fo:block text-align="center" padding-top="0.4mm">
							<xsl:value-of select="data/ReportInfo/ReportInfo/VerMajor"/>
							<xsl:text>.</xsl:text>
							<xsl:value-of select="data/ReportInfo/ReportInfo/VerMinor"/>
					</fo:block>
				</fo:block-container>
			</xsl:if>
		</fo:static-content>	
	</xsl:template>
	
	<xsl:template match="Title" mode="reportTitle" priority="200">
		<xsl:value-of select="."/>	
	</xsl:template>

	<xsl:template match="Event" mode="HeaderTitle" priority="5">
		<xsl:value-of select="./Title"/>
	</xsl:template>

</xsl:stylesheet>
