<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:param name="race_header_show_distance" select="true()"/>

	<xsl:template match="Race" mode="header">
		<fo:block text-align-last="justify" keep-with-next="always">
			<xsl:attribute name="id">
				<xsl:text>r</xsl:text>
				<xsl:value-of select="Offer_ID"/>
			</xsl:attribute>			
			<fo:inline font-size="16pt" font-weight="bold" padding-right="0.25em">
				<xsl:text>Rennen </xsl:text>
				<xsl:value-of select="Offer_RaceNumber"/>
			</fo:inline>
			<fo:inline font-size="8pt">
				<xsl:value-of select="Offer_ShortLabel"/>
				<xsl:text> - </xsl:text>
				<xsl:value-of select="Offer_LongLabel"/>
				<xsl:text> </xsl:text>
				<xsl:value-of select="Offer_Comment"/>
			</fo:inline>
			<fo:leader leader-pattern="space"/>
			<fo:inline font-size="16pt" font-weight="bold">
				<xsl:if test="boolean($race_header_show_distance)">
					<xsl:value-of select="Offer_Distance"/>
					<xsl:text>&#x2009;m</xsl:text>
				</xsl:if>
			</fo:inline>
		</fo:block>
		<xsl:if test="string-length(Offer_Prize) &gt; 0">
			<fo:block font-weight="bold" font-size="12pt" keep-with-next="always">
				<xsl:value-of select="Offer_Prize"/>
			</fo:block>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Race" mode="schedule_info">
		<xsl:param name="pretty_print" select="false()"/>
		<fo:table width="100%" table-layout="fixed" font-size="8pt" 
		  border-top="1pt solid black" border-bottom="1pt solid black">
		  	<xsl:if test="$pretty_print = false()">
		  		<xsl:attribute name="keep-with-previous.within-page">always</xsl:attribute>
	 	  	</xsl:if>
	 	  	<xsl:if test="$pretty_print = true()">
	 	  		<xsl:attribute name="keep-with-next">always</xsl:attribute>
	 	  	</xsl:if>
			<fo:table-column column-number="1" column-width="20%"/>
			<fo:table-column column-number="2" column-width="20%"/>
			<fo:table-column column-number="3" column-width="20%"/>
			<fo:table-column column-number="4" column-width="20%"/>
			<fo:table-column column-number="5" column-width="20%"/>
		
			<fo:table-body>
				<xsl:if test="$pretty_print = false()">
					<xsl:attribute name="keep-with-previous.within-page">always</xsl:attribute>
				</xsl:if>
		 		<fo:table-row height="2.5em">
					<xsl:if test="$pretty_print = false()">
						<xsl:attribute name="keep-with-previous.within-page">always</xsl:attribute>
					</xsl:if>		 			
					<!-- Vorläufe -->
					<fo:table-cell text-align="center">
						<xsl:call-template name="round_time">
							<xsl:with-param name="round" select="number(4)"/>
							<xsl:with-param name="race" select="./Offer_ID"></xsl:with-param>
						</xsl:call-template>													
					</fo:table-cell>
					 
					<!-- Hoffnungsläufe -->
					<fo:table-cell text-align="center">
						<xsl:call-template name="round_time">
							<xsl:with-param name="round" select="number(8)"/>
							<xsl:with-param name="race" select="./Offer_ID"></xsl:with-param>
						</xsl:call-template>																		
					</fo:table-cell>
					
					<!-- Viertelfinals -->
					<fo:table-cell text-align="center">
						<xsl:call-template name="round_time">
							<xsl:with-param name="round" select="number(16)"/>
							<xsl:with-param name="race" select="./Offer_ID"></xsl:with-param>
						</xsl:call-template>
						<xsl:if test="Offer_Driven = 0">
							<fo:block padding="0.25em 0.25em">
								<xsl:text>nicht zu Stande gekommen</xsl:text>
							</fo:block>
						</xsl:if>					
					</fo:table-cell>
					
					<!-- Halbfinals -->
					<fo:table-cell text-align="center">
						<xsl:call-template name="round_time">
							<xsl:with-param name="round" select="number(32)"/>
							<xsl:with-param name="race" select="./Offer_ID"></xsl:with-param>
						</xsl:call-template>
					</fo:table-cell>
					
					<!-- Finals -->
					<fo:table-cell text-align="center">
						<xsl:call-template name="round_time">
							<xsl:with-param name="round" select="number(64)"/>
							<xsl:with-param name="race" select="./Offer_ID"></xsl:with-param>
						</xsl:call-template>					
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		
		</fo:table>		
	</xsl:template>
	
	<xsl:template name="round_time">
		<xsl:param name="round"/>
		<xsl:param name="race"/>
		<!-- THINK: replace the data selection by usage of AllRaceRoundTimes query result -->
		<xsl:variable name="infos" select="/data/Comps/Comp[Race_ID_FK=$race and Round=$round and string-length(DateTime) &gt; 0]"/>
		<xsl:variable name="info" select="$infos[1]"/>
		<xsl:variable name="comp_count" select="count($infos)"/>
		
		<fo:block-container padding="0.25em 0.25em" keep-with-previous.within-page="always">
		
			<!-- display schedule info only if required -->
			<xsl:if test="$comp_count &gt; 0">
				<fo:block keep-with-previous.within-page="always">
					<xsl:choose>
						<xsl:when test="$round = 64">
							<xsl:if test="$comp_count = 1 and $info/RoundCode = 'R'">Hauptrennen</xsl:if>
							<xsl:if test="$comp_count = 1 and $info/RoundCode = 'F'">Finale</xsl:if>
							<xsl:if test="$comp_count &gt; 1">
								<xsl:if test="$info/RoundCode = 'A'">Abteilungen</xsl:if>
								<xsl:if test="$info/RoundCode = 'R'">Hauptrennen</xsl:if>								
								<xsl:if test="$info/RoundCode = 'F'">Finale</xsl:if>
							</xsl:if>
						</xsl:when>
						<xsl:when test="$round = 32 and $info/RoundCode = 'L'">
							<xsl:text>Rangliste</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="_GetCompLongCaption">
								<xsl:with-param name="RoundCode" select="$info/RoundCode"/>
								<xsl:with-param name="Label" select="''"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="$comp_count &gt; 1">
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$comp_count"/>
						<xsl:text>)</xsl:text>
					</xsl:if>
				</fo:block>
				
				<fo:block keep-with-previous.within-page="always">
					<xsl:call-template name="GetShortWeekDay">
						<xsl:with-param name="day" select="$info/WeekDay"/>
					</xsl:call-template>
					<xsl:text>. </xsl:text>
					<xsl:value-of select="$info/Hour"/>
					<xsl:text>:</xsl:text>
					<xsl:if test="$info/Minute &lt; 10">
						<xsl:text>0</xsl:text> 
					</xsl:if>
					<xsl:value-of select="$info/Minute"/>
					<xsl:text> Uhr</xsl:text>
				</fo:block>
			</xsl:if>
			
			<xsl:if test="$comp_count = 0">
				<fo:block keep-with-previous.within-page="always"/>
			</xsl:if>
		</fo:block-container>
	</xsl:template>
	
	<xsl:template match="Comp" mode="comp_header">
		<xsl:variable name="cid" select="ID" />
		<xsl:variable name="rid" select="Race_ID_FK" />
	
		<fo:block text-align-last="justify">
			<fo:inline>
				<xsl:text>Re. </xsl:text>
				<xsl:if test="count(/data/RaceInfo) != 0">
					<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_RaceNumber" />
					<xsl:text> - </xsl:text>
					<xsl:value-of select="/data/RaceInfo/RaceInfo/Offer_ShortLabel" />
					<xsl:if test="string-length(/data/RaceInfo/RaceInfo/Offer_Comment) &gt; 0">
						<xsl:text> </xsl:text>
						<xsl:value-of select="substring(/data/RaceInfo/RaceInfo/Offer_Comment, 1, 10)" />
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="count(/data/RaceInfo) = 0">
					<xsl:value-of select="/data/Races/Race[Offer_ID=$rid][1]/Offer_RaceNumber" />
					<xsl:text> - </xsl:text>
					<xsl:value-of select="/data/Races/Race[Offer_ID=$rid][1]/Offer_ShortLabel" />
					<xsl:if test="string-length(/data/Races/Race[Offer_ID=$rid][1]/Offer_Comment) &gt; 0">
						<xsl:text> </xsl:text>
						<xsl:value-of select="substring(/data/Races/Race[Offer_ID=$rid][1]/Offer_Comment, 1, 10)" />
					</xsl:if>									
				</xsl:if>
				
				<xsl:text>, </xsl:text>
				<xsl:apply-templates select="." mode="GetLongCompCaption" />
				 
				<xsl:text> </xsl:text>
				<xsl:if test="count(/data/RaceInfo) != 0 and /data/RaceInfo/RaceInfo/Offer_GroupMode != 0">
					<xsl:call-template name="GetAbbrGroupString">
						<xsl:with-param name="mode" select="/data/RaceInfo/RaceInfo/Offer_GroupMode" />
						<xsl:with-param name="value" select="GroupValue" />
					</xsl:call-template>
				</xsl:if>

				<xsl:if test="count(/data/RaceInfo) = 0 and /data/Races/Race[Offer_ID=$rid][1]/Offer_GroupMode != 0">
					<xsl:call-template name="GetAbbrGroupString">
						<xsl:with-param name="mode" select="/data/Races/Race[Offer_ID=$rid][1]/Offer_GroupMode" />
						<xsl:with-param name="value" select="GroupValue" />
					</xsl:call-template>
				</xsl:if>
				
				<xsl:if test="Cancelled != 0">
					<xsl:text> - gestrichen</xsl:text>
				</xsl:if>
			</fo:inline>
			<fo:leader leader-pattern="space" />
			<fo:inline>
<!--
				<xsl:choose>
					<xsl:when test="count(/data/RoundInfo) != 0">
						<xsl:value-of select="/data/RoundInfo/RoundInfo/Distance"/>
					</xsl:when>

					<xsl:when test="count(/data/RaceInfo) != 0">
						<xsl:value-of select="/data/RaceInfo/RaceInfo/Distance"/>
					</xsl:when>

					<xsl:when test="count(/data/RaceInfo) = 0">
						<xsl:value-of select="/data/Comps/Comp[Race_ID_FK=$rid][1]/Comp_Distance"/>
					</xsl:when>
				</xsl:choose>
-->
				<xsl:value-of select="Distance"/>

				<xsl:text>&#x2009;m, Start: </xsl:text>
				<xsl:value-of select="concat(format-number(Hour, '00'), ':', format-number(Minute, '00'))" />
				<xsl:text> (#</xsl:text>
				<xsl:value-of select="Number" />
				<xsl:text>)</xsl:text>
			</fo:inline>
		</fo:block>	
	</xsl:template>

</xsl:stylesheet>
