<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt">

	<xsl:output method="xml" encoding="utf-8" version="1.0" omit-xml-declaration="no" indent="yes"/>
	
	<xsl:param name="show_code" select="false()"/>
	<xsl:param name="show_qrule" select="false()"/>

	<xsl:param name="default_finalround_caption" select="'Abteilungen'"/>

	<xsl:include href="./../../inc/tools.xsl"/>
	<xsl:include href="./header.xsl"/>
	<xsl:include href="./footer.xsl"/>
	
	<xsl:include href="./../../inc/rowing_tools.xsl"/>	

	<!-- Template for root document: create basic FOP body frame -->
	<xsl:template match="/">
		<xsl:variable name="footer_height">
			<xsl:choose>
				<xsl:when test="string-length(/data/Event/Event/FootLogo) != 0">3cm</xsl:when>
				<xsl:otherwise>2cm</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<fo:root font-family="Helvetica">
			<!-- Page Size Definitions -->		
			<fo:layout-master-set>
			
				<!-- A4 portrait -->
				<fo:simple-page-master master-name="A4-portrait" page-height="297mm" page-width="210mm" 
					margin-top="1.2cm" margin-bottom="0cm" margin-left="1.5cm" margin-right="1.5cm">
					<xsl:call-template name="default_page_regions">
						<xsl:with-param name="footer_height" select="$footer_height"/>
					</xsl:call-template>
				</fo:simple-page-master>
				
				<!-- A4 landscape -->
				<fo:simple-page-master master-name="A4-landscape" page-height="210mm" page-width="297mm" 
					margin-top="1.2cm" margin-bottom="0cm" margin-left="1.4cm" margin-right="1.3cm">
					<xsl:call-template name="default_page_regions">
						<xsl:with-param name="footer_height" select="$footer_height"/>
					</xsl:call-template>
				</fo:simple-page-master>

				<xsl:apply-templates select="/" mode="extra-page-masters">
					<xsl:with-param name="footer_height" select="$footer_height"/>
				</xsl:apply-templates>
				
			</fo:layout-master-set>
					
			<fo:declarations>
				<x:xmpmeta xmlns:x="adobe:ns:meta/">
					<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
						<rdf:Description rdf:about="" xmlns:dc="http://purl.org/dc/elements/1.1/">
							<!-- Dublin Core properties go here -->
							<dc:title>
								<xsl:value-of select="/data/ReportInfo/ReportInfo/Title"/>
							</dc:title>
							<dc:creator>
								<xsl:value-of select="/data/ReportInfo/ReportInfo/Creator"/>
							</dc:creator>
							<dc:description>
								<xsl:value-of select="/data/Event/Event/Title"/>
								<xsl:text>, </xsl:text>
								<xsl:value-of select="/data/Event/Event/Venue"/>
							</dc:description>
						</rdf:Description>
						<rdf:Description rdf:about="" xmlns:xmp="http://ns.adobe.com/xap/1.0/">
							<!-- XMP properties go here -->
							<xmp:CreatorTool>Aquarius MMX with Apache FOP Reporting Backend</xmp:CreatorTool>
						</rdf:Description>
						<rdf:Description rdf:about="" xmlns:pdf="http://ns.adobe.com/pdf/1.3/">
							<!-- XMP properties go here -->
							<pdf:Keywords>
								<xsl:value-of select="/data/Event/Event/Title"/>
								<xsl:text>, </xsl:text>
								<xsl:value-of select="/data/Event/Event/Venue"/>
								<xsl:text>, </xsl:text> 
								<xsl:value-of select="/data/Event/Event/Club_Name"/>
								<xsl:text>, </xsl:text>
								<xsl:value-of select="/data/ReportInfo/ReportInfo/Title"/>
							</pdf:Keywords>
						</rdf:Description>						
					</rdf:RDF>
				</x:xmpmeta>
			</fo:declarations>		
		
			<xsl:apply-templates select="/data" mode="bookmarktree"/>					
		
			<!-- Master Sequence -->
			<fo:page-sequence format="1" initial-page-number="1" id="seq-primary">
				<xsl:attribute name="master-reference">
					<xsl:apply-templates select="/data" mode="pageformat"/> 
				</xsl:attribute>

				<xsl:comment>Header</xsl:comment>
				<xsl:call-template name="PageHeader" />
				
				<xsl:comment>Footer</xsl:comment>
				<xsl:call-template name="PageFooter" />			
				
				<xsl:comment>----------------------- Body ---------------------</xsl:comment>				
				
				<fo:flow flow-name="page-region-body">
					<fo:block id="bodyHeadAnchor"/><!-- for bookmarks -->
					<xsl:call-template name="body"/>
					<xsl:call-template name="legend"/>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<xsl:template name="default_page_regions">
		<xsl:param name="footer_height"/>
		<fo:region-body region-name="page-region-body" margin-top="3cm">
			<xsl:attribute name="margin-bottom">
				<xsl:value-of select="$footer_height"/>
			</xsl:attribute>
		</fo:region-body>
		<fo:region-before extent="3cm" region-name="page-header"/>
		<fo:region-after region-name="page-footer">
			<xsl:attribute name="extent">
				<xsl:value-of select="$footer_height"/>
			</xsl:attribute>
		</fo:region-after>
	</xsl:template>

	
	<xsl:template match="/data" mode="bookmarktree" priority="5">
		<xsl:comment>bookmark tree fall-back (no tree produced)</xsl:comment>

	</xsl:template>

	<xsl:template match="/data" mode="pageformat" priority="5">
		<xsl:text>A4-portrait</xsl:text>
	</xsl:template>

	<xsl:template match="/" mode="extra-page-masters" priority="5"/>

	<xsl:template name="legend">
		<xsl:variable name="body_rtf">
			<xsl:apply-templates select="/data" mode="legend_body"/>
		</xsl:variable>
		<xsl:variable name="body" select="msxsl:node-set($body_rtf)"/>
		<xsl:if test="count($body/*)">
			<fo:block>
				<fo:footnote>
					<!-- empty reference -->
					<fo:inline/>
					<!-- abuse footnote body as variable height block at end of page (lack of \vfill-like constructs) -->
					<fo:footnote-body font-size="8pt">
						<fo:block border="medium solid black" margin-bottom="1em">
							<fo:block margin=".25em">
								<!-- en: legend -->
								<fo:block font-weight="bold">Erläuterungen</fo:block>
								<fo:block>
									<xsl:copy-of select="$body"/>
								</fo:block>
							</fo:block>
						</fo:block>
					</fo:footnote-body>
				</fo:footnote>
			</fo:block>
		</xsl:if>
	</xsl:template>

	<xsl:template match="/data" mode="legend_body" priority="5"/>

</xsl:stylesheet>
