<?xml version="1.0" encoding="UTF-8"?>
<!-- common file for start and result list summaries (C52 and C74A) -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

	<xsl:param name="use_race_sep" select="true()"/>
	<xsl:param name="use_round_sep" select="false()"/>

	<xsl:variable name="max_lanes">
		<xsl:choose>
			<xsl:when test="/data/MaxLanes/MaxLane/LaneCount &gt; 1">
				<xsl:value-of select="/data/MaxLanes/MaxLane/LaneCount"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>4</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:template name="body">
		<xsl:if test="/data/Comps/Comp">
			<fo:table table-layout="fixed" width="100%" font-size="8pt">
				<xsl:apply-templates select="/data/Comps" mode="DefineTableColumns"/>

				<fo:table-header font-weight="bold" display-align="center" text-align="center">
					<xsl:apply-templates select="/data/Comps" mode="CreateTableHeader"/>
				</fo:table-header>

				<fo:table-body>
					<xsl:apply-templates select="/data/Comps" mode="TableBodySettings"/>
					<xsl:for-each select="/data/Comps/Comp">
						<xsl:variable name="next_comp" select="current()/following-sibling::Comp[1]"/>
						<xsl:variable name="prev_comp" select="current()/preceding-sibling::Comp[1]"/>

						<xsl:if test="Dummy = 0">
							<xsl:if test="($prev_comp/Race_ID_FK != Race_ID_FK) and ($use_race_sep)">
								<xsl:apply-templates select="/data/Races/Race[Offer_ID = current()/Race_ID_FK]" mode="RaceSeparator"/>
							</xsl:if>
							<fo:table-row display-align="center">
								<xsl:apply-templates select="current()"/>
							</fo:table-row>
						</xsl:if>
						<xsl:if test="Dummy = 1">
							<fo:table-row display-align="center" height="2em" border="medium solid black" margin="0 1em">
								<fo:table-cell number-columns-spanned="5">
									<fo:block ><xsl:value-of select="Label"/></fo:block>
								</fo:table-cell>
							</fo:table-row>
						</xsl:if>

						<!--
						<xsl:if test="current()/Race_ID_FK != $next_comp/Race_ID_FK">
							<xsl:apply-templates select="/data/Races/Race[Offer_ID = current()/following-sibling::Comp/Race_ID_FK]" mode="RaceSeparator"/>
						</xsl:if>
						-->
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Comps" mode="CreateTableHeader" priority="0">
		<fo:table-row>
			<fo:table-cell number-rows-spanned="2" border="medium solid black"><fo:block>Lauf Nr.</fo:block></fo:table-cell>
			<fo:table-cell number-rows-spanned="2" border="medium solid black"><fo:block>Start-zeit</fo:block></fo:table-cell>
			<fo:table-cell number-columns-spanned="2" border="medium solid black"><fo:block>Rennen</fo:block></fo:table-cell>
			<fo:table-cell number-rows-spanned="2" border="medium solid black"><fo:block>Runde/Lauf</fo:block></fo:table-cell>
			<xsl:apply-templates select="/data/Comps" mode="ParticipantsHeaderUpper"/>
			<fo:table-cell number-rows-spanned="2" border="medium solid black"><fo:block>Ausscheid-ungssystem</fo:block></fo:table-cell>
		</fo:table-row>
		<fo:table-row>
			<fo:table-cell border="medium solid black"><fo:block>Bez.</fo:block></fo:table-cell>
			<fo:table-cell border="medium solid black"><fo:block>Nummer</fo:block></fo:table-cell>
			<xsl:apply-templates select="/data/Comps" mode="ParticipantsHeaderLower"/>
		</fo:table-row>
	</xsl:template>

	<xsl:template match="Comps" mode="DefineTableColumns" priority="0">
		<fo:table-column column-width="1cm"/>
		<fo:table-column column-width="1cm"/>
		<fo:table-column column-width="1.7cm"/>
		<fo:table-column column-width="1.2cm"/>
		<fo:table-column column-width="proportional-column-width(1)"/>
		<xsl:call-template name="iterate_table_columns"/>
		<fo:table-column column-width="proportional-column-width(1)"/>		
	</xsl:template>

	<xsl:template match="Comps" mode="ParticipantsHeaderUpper" priority="0">
		<fo:table-cell border="medium solid black">
			<xsl:attribute name="number-columns-spanned">
				<xsl:value-of select="$max_lanes"/>
			</xsl:attribute>
			<fo:block text-align="center"><xsl:apply-templates select="." mode="ParticipantsHeaderCaption"/></fo:block>
		</fo:table-cell>
	</xsl:template>

	<xsl:template match="Comps" mode="ParticipantsHeaderCaption">
		<xsl:text>Teilnehmer</xsl:text>
	</xsl:template>

	<xsl:template match="Comps" mode="ParticipantsHeaderLower" priority="2">
		<xsl:call-template name="iterate_lane_cells"/>
	</xsl:template>

	<xsl:template name="iterate_table_columns">
		<xsl:param name="lane" select="number('1')"/>

		<xsl:apply-templates select="/data/Comps" mode="DefineLaneColumn"/>

		<xsl:if test="$lane &lt; $max_lanes">
			<xsl:call-template name="iterate_table_columns">
				<xsl:with-param name="lane" select="$lane + 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Comps" mode="DefineLaneColumn" priority="0">
		<fo:table-column column-width="4.5em"/>
	</xsl:template>

	<xsl:template match="Comps" mode="TableBodySettings" priority="0"/>

	<xsl:template name="iterate_lane_cells">
		<xsl:param name="lane" select="number('1')"/>

		<fo:table-cell border="medium solid black"><fo:block text-align="center"><xsl:value-of select="$lane"/></fo:block></fo:table-cell>

		<xsl:if test="$lane &lt; $max_lanes">
			<xsl:call-template name="iterate_lane_cells">
				<xsl:with-param name="lane" select="$lane + 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template match="Race" mode="RaceSeparator" priority="0"/>

	<xsl:template match="Comp" priority="0">
		<xsl:attribute name="height">3em</xsl:attribute>
		<fo:table-cell margin="0em 0.5em"><fo:block text-align="right"><xsl:value-of select="Number"/></fo:block></fo:table-cell>
		<fo:table-cell margin="0em 0.5em">
			<fo:block text-align="right">
				<xsl:value-of select="Hour"/>
				<xsl:text>:</xsl:text>
				<xsl:if test="Minute &lt; 10"><xsl:text>0</xsl:text></xsl:if>
				<xsl:value-of select="Minute"/>
			</fo:block>
		</fo:table-cell>
		<fo:table-cell>
			<fo:block-container overflow="hidden">
				<fo:block text-align="center"><!-- wrap-option="no-wrap" -->
					<xsl:value-of select="/data/Races/Race[Offer_ID = current()/Race_ID_FK]/Offer_ShortLabel"/>
				</fo:block>
			</fo:block-container>
		</fo:table-cell>
		<fo:table-cell>
			<fo:block text-align="center">
				(<xsl:value-of select="/data/Races/Race[Offer_ID = current()/Race_ID_FK]/Offer_RaceNumber"/>)
			</fo:block>
		</fo:table-cell>
		<fo:table-cell><fo:block text-align="center"><xsl:apply-templates select="current()" mode="GetLongCompCaption"/></fo:block></fo:table-cell>
		<xsl:call-template name="CompLanes"/>
		<fo:table-cell><fo:block text-align="center"><xsl:value-of select="RuleText"/></fo:block></fo:table-cell>
	</xsl:template>

</xsl:stylesheet>
