<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:re="http://schemas.rudern.de/service/ergebnisse/2017/">

  <xsl:output method="xml" encoding="utf-8" version="1.0" omit-xml-declaration="no" indent="yes"/>

  <xsl:include href="./../inc/rowing_tools.xsl"/>

  <xsl:template match="/data">
    <re:Ergebnisse>
      <xsl:comment>
        <xsl:text>created at </xsl:text>
        <xsl:value-of select="/data/ReportInfo/ReportInfo/DateYear"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateMonth, '00')"/>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateDay, '00')"/>
        <xsl:text>, </xsl:text>
        <xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateHour, '00')"/>
        <xsl:text>:</xsl:text>
        <xsl:value-of select="format-number(/data/ReportInfo/ReportInfo/DateMinute, '00')"/>

        <xsl:text>, version </xsl:text>
        <xsl:value-of select="/data/ReportInfo/ReportInfo/VerMajor"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="/data/ReportInfo/ReportInfo/VerMinor"/>
      </xsl:comment>
      <xsl:apply-templates select="/data/Races/Race"/>
      <xsl:for-each select="/data/Referees/Referee">
        <Wettkampfrichter>
          <xsl:apply-templates select="."/>
        </Wettkampfrichter>
      </xsl:for-each>
    </re:Ergebnisse>
  </xsl:template>

  <xsl:template match="Race">
    <Rennen>
      <xsl:attribute name="Nummer">
        <xsl:value-of select="Offer_RaceNumber"/>
      </xsl:attribute>
      <xsl:attribute name="Distanz">
        <xsl:value-of select="Offer_Distance"/>
      </xsl:attribute>
      <xsl:if test="Offer_Cancelled != 0 or Offer_Driven = 0">
        <xsl:attribute name="istAusgefallen">
          <xsl:text>true</xsl:text>
        </xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="/data/Comps/Comp[Race_ID_FK = current()/Offer_ID and Cancelled = 0]">
        <xsl:with-param name="groupMode" select="Offer_GroupMode"/>
      </xsl:apply-templates>
      <xsl:apply-templates select="/data/Entries/Entrie[Entry_Race_ID_FK = current()/Offer_ID and Entry_CancelValue != 0]" mode="withDrawal">
        <xsl:sort select="Entry_Bib" data-type="number"/>
      </xsl:apply-templates>
    </Rennen>
  </xsl:template>

  <xsl:template match="Comp">
    <xsl:param name="groupMode"/>
    <Lauf>
      <xsl:attribute name="Typ">
        <xsl:choose>
          <!-- Zwischenlauf is something like a repechage -->
          <xsl:when test="RoundCode = 'Z'">H</xsl:when>
          <xsl:when test="RoundCode = 'Fk'">F</xsl:when>
          <xsl:when test="RoundCode = 'X'">B</xsl:when>
          <xsl:when test="RoundCode = 'R'">A</xsl:when>
          <xsl:when test="RoundCode = 'L'">F</xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="RoundCode"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>

      <xsl:attribute name="Nummer">
        <xsl:value-of select="HeatNumber"/>
      </xsl:attribute>

      <xsl:if test="RoundCode = 'Fk' or RoundCode = 'Z' or RoundCode = 'L' or RoundCode = 'R'">
        <xsl:attribute name="Bezeichnung">
          <xsl:choose>
            <xsl:when test="RoundCode = 'Fk'">kleines Finale</xsl:when>
            <xsl:when test="RoundCode = 'Z'">Zwischenlauf <xsl:value-of select="Label"/></xsl:when>
            <xsl:when test="RoundCode = 'L'">Rangliste</xsl:when>
            <xsl:when test="RoundCode = 'R'">Hauptrennen</xsl:when>
          </xsl:choose>
        </xsl:attribute>
      </xsl:if>

      <xsl:if test="$groupMode = 1 or $groupMode = 3">
        <xsl:attribute name="Leistungsgruppe">
          <xsl:value-of select="1 + (GroupValue mod 4)"/>
        </xsl:attribute>
      </xsl:if>

      <xsl:if test="$groupMode = 2 or $groupMode = 3">
        <xsl:attribute name="Altersklasse">
          <xsl:call-template name="GetAgeGroupValueString">
            <xsl:with-param name="group" select="floor(GroupValue div 4)"/>
          </xsl:call-template>
        </xsl:attribute>
      </xsl:if>

      <xsl:apply-templates select="/data/Results/Result[Comp_ID = current()/ID and SplitNr = 64]">
        <xsl:sort select="SortValue" data-type="number"/>
      </xsl:apply-templates>

      <xsl:for-each select="/data/CompReferees/CompReferee[Comp_ID_FK = current()/ID and Role = 'U']">
        <Schiedsrichter>
          <xsl:apply-templates select="/data/Referees/Referee[ID = current()/Referee_ID_FK]"/>
        </Schiedsrichter>
      </xsl:for-each>
    </Lauf>
  </xsl:template>

  <xsl:template match="Entrie" mode="withDrawal">
    <Abmeldung>
      <xsl:attribute name="Startnummer">
        <xsl:value-of select="Entry_Bib"/>
      </xsl:attribute>

      <xsl:call-template name="iterate_crew">
        <xsl:with-param name="eid" select="Entry_ID"/>
        <xsl:with-param name="num_rowers">
          <xsl:value-of select="/data/Races/Race[Offer_ID = current()/Entry_Race_ID_FK]/BoatClass_NumRowers + /data/Races/Race[Offer_ID = current()/Entry_Race_ID_FK]/BoatClass_Coxed"/>
        </xsl:with-param>
      </xsl:call-template>
    </Abmeldung>
  </xsl:template>

  <xsl:template match="Result">
    <xsl:variable name="eid" select="/data/Lanes/Lane[CE_ID = current()/CE_ID_FK]/CE_Entry_ID_FK"/>
    <xsl:variable name="entry" select="/data/Entries/Entrie[Entry_ID=$eid]"/>

    <Boot>
      <xsl:attribute name="Startnummer">
        <xsl:value-of select="$entry/Entry_Bib"/>
      </xsl:attribute>

      <xsl:call-template name="iterate_crew">
        <xsl:with-param name="eid" select="$eid"/>
        <xsl:with-param name="round" select="/data/Comps/Comp[ID = current()/Comp_ID]/Round"/>
        <xsl:with-param name="num_rowers">
          <xsl:value-of select="/data/Races/Race[Offer_ID = $entry/Entry_Race_ID_FK]/BoatClass_NumRowers + /data/Races/Race[Offer_ID = $entry/Entry_Race_ID_FK]/BoatClass_Coxed"/>
        </xsl:with-param>
      </xsl:call-template>

      <Ergebnis>
        <xsl:if test="Rank &gt; 0">
          <xsl:attribute name="Rang">
            <xsl:value-of select="Rank"/>
          </xsl:attribute>
        </xsl:if>

        <xsl:if test="ResultType = 'N'">
          <xsl:if test="DisplayType = 'T'">
            <xsl:attribute name="Zeit">
              <xsl:call-template name="toXmlDuration">
                <xsl:with-param name="value" select="NetTime"/>
              </xsl:call-template>
            </xsl:attribute>
          </xsl:if>
          <xsl:if test="(DisplayType = 'D' or DisplayType = 'T') and Delta &gt; 0">
            <xsl:attribute name="Delta">
              <xsl:call-template name="toXmlDuration">
                <xsl:with-param name="value" select="Delta"/>
              </xsl:call-template>
            </xsl:attribute>
          </xsl:if>
          <xsl:if test="string-length(Comment) or /data/Races/Race[Offer_ID = $entry/Entry_Race_ID_FK]/Offer_RaceType = 16">
            <!-- default comment string -->
            <xsl:attribute name="Bemerkung">
              <xsl:value-of select="Comment"/>
              <!-- stroke count races -->
              <xsl:if test="/data/Races/Race[Offer_ID = $entry/Entry_Race_ID_FK]/Offer_RaceType = 16">
                <xsl:variable name="strokes" select="substring-after(Params, '=')"/>
                <xsl:text>Schläge: </xsl:text>
                <xsl:value-of select="$strokes"/>
                <xsl:text>; Produkt: </xsl:text>
                <xsl:value-of select="DisplayValue"/>
                <xsl:text>; Frequenz: </xsl:text>
                <xsl:value-of select="format-number($strokes div (NetTime div 1000 div 60), '#.0')"/>
              </xsl:if>
            </xsl:attribute>
          </xsl:if>
        </xsl:if>

        <xsl:if test="ResultType != 'N'">
          <xsl:attribute name="Bemerkung">
            <xsl:variable name="dv">
              <xsl:apply-templates select="DisplayValue" mode="friendly"/>
            </xsl:variable>
            <xsl:value-of select="normalize-space(concat($dv, ' ', Comment))"/>
          </xsl:attribute>
        </xsl:if>
      </Ergebnis>
    </Boot>
  </xsl:template>

  <xsl:template name="iterate_crew">
    <xsl:param name="eid"/>
    <xsl:param name="round" select="64"/>
    <xsl:param name="position" select="1"/>
    <xsl:param name="num_rowers" select="1"/>

    <xsl:apply-templates select="/data/Crews/Crew[Entry_ID_FK = $eid and Pos = $position and RoundFrom &lt;= $round and RoundTo &gt;= $round][1]"/>

    <xsl:if test="$position &lt; $num_rowers">
      <xsl:call-template name="iterate_crew">
        <xsl:with-param name="eid" select="$eid"/>
        <xsl:with-param name="round" select="$round"/>
        <xsl:with-param name="num_rowers" select="$num_rowers"/>
        <xsl:with-param name="position" select="$position + 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template match="Crew">
    <Sportler>
      <xsl:attribute name="Position">
        <xsl:value-of select="Pos"/>
      </xsl:attribute>
      <xsl:if test="IsCox = 1">
        <xsl:attribute name="istSteuermann">
          <xsl:text>true</xsl:text>
        </xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="/data/Athlets/Athlet[ID = current()/Athlete_ID_FK]"/>
    </Sportler>
  </xsl:template>

  <xsl:template match="Athlet">
    <xsl:if test="Nation_IOC_Code = 'GER'">
      <xsl:if test="starts-with(ExternID_A, 'DE-')">
        <xsl:attribute name="AktivenID">
          <xsl:value-of select="ExternID_A"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:attribute name="VereinsID">
        <xsl:value-of select="/data/Clubs/Club[ID = current()/Club_ID_FK]/ExternID"/>
      </xsl:attribute>
    </xsl:if>

    <xsl:if test="Nation_IOC_Code != 'GER' or not(starts-with(ExternID_A, 'DE-'))">
      <Nachname>
        <xsl:value-of select="LastName"/>
      </Nachname>
      <Vorname>
        <xsl:value-of select="FirstName"/>
      </Vorname>
      <Jahrgang>
        <xsl:value-of select="YOB"/>
      </Jahrgang>
      <VereinsName>
        <xsl:attribute name="Kuerzel">
          <xsl:value-of select="/data/Clubs/Club[ID = current()/Club_ID_FK]/Abbr"/>
        </xsl:attribute>
        <xsl:value-of select="/data/Clubs/Club[ID = current()/Club_ID_FK]/Name"/>
      </VereinsName>
    </xsl:if>
  </xsl:template>

  <xsl:template match="Referee">
    <xsl:if test="string-length(ExternID) &gt; 0">
      <xsl:attribute name="Lizenznummer">
        <xsl:value-of select="ExternID"/>
      </xsl:attribute>
      <xsl:comment>
        <xsl:value-of select="concat(LastName, ', ', FirstName)"/>
      </xsl:comment>
    </xsl:if>
    <xsl:if test="string-length(ExternID) = 0">
      <Nachname>
        <xsl:value-of select="LastName"/>
      </Nachname>
      <Vorname>
        <xsl:value-of select="FirstName"/>
      </Vorname>
      <Herkunft>
        <xsl:value-of select="concat(City, ', ', Nation_IOC_Code)"/>
      </Herkunft>
    </xsl:if>
  </xsl:template>

  <xsl:template name="toXmlDuration">
    <xsl:param name="value"/>
    <!-- value is in milliseconds -->
    <xsl:text>PT</xsl:text>
    <xsl:if test="$value &gt;= 60 * 1000">
      <xsl:value-of select="floor($value div (60 * 1000))"/>
      <xsl:text>M</xsl:text>
    </xsl:if>
    <xsl:value-of select="format-number($value mod (60 * 1000) div 1000, '0.00')"/>
    <xsl:text>S</xsl:text>
  </xsl:template>

</xsl:stylesheet>
